@@ -22,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "Tapahtui tuntematon virhe",
     "File could not be uploaded" : "Tiedostoa ei voi lähettää",
     "Uploading …" : "Lähetetään…",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Lähetetään… ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Kyseisen kohteen lähettäminen ei ole tuettu",
     "Target folder does not exist any more" : "Kohdekansiota ei ole enää olemassa",
@@ -32,6 +34,7 @@ OC.L10N.register(
     "Move" : "Siirrä",
     "Copy" : "Kopioi",
     "Choose target folder" : "Valitse kohdekansio",
+    "Set reminder" : "Aseta muistutus",
     "Edit locally" : "Muokkaa paikallisesti",
     "Open" : "Avaa",
     "Delete file" : "Poista tiedosto",
@@ -78,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["Sisältäen %n piilotetun","Sisältäen %n piilotettua"],
     "You do not have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tähän sijaintiin",
     "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
+    "New" : "Uusi",
     "New file/folder menu" : "Uusi tiedosto/kansio -valikko",
     "Select file range" : "Valitse tiedostojoukko",
     "{used}%" : "{used} %",
@@ -97,18 +101,16 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Tallennustila on melkein täynnä ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["vastaa \"{filter}\"","vastaa \"{filter}\""],
     "View in folder" : "Näe kansiossa",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Suoralinkki kopioitiin (toimii vain niillä käyttäjillä, joilla on pääsy kyseiseen tiedostoon/kansioon)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Suora linkki kopioitu (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
     "Path" : "Polku",
     "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
     "Favorited" : "Lisätty suosikkeihin",
     "Favorite" : "Suosikki",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopioi suora linkki (toimii vain käyttäjillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopioi suora linkki (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
     "New folder" : "Uusi kansio",
     "Create new folder" : "Luo uusi kansio",
     "Upload file" : "Lähetä tiedosto",
     "Recent" : "Viimeaikaiset",
-    "This file has the tag {tag}" : "Tällä tiedostolla on tunniste {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Tällä tiedostolla on tunnisteet {firstTags} ja {lastTag}",
     "Not favorited" : "Ei suosikeissa",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
@@ -125,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Palauttanut {user}",
     "Renamed by {user}" : "Uudelleennimennyt {user}",
     "Moved by {user}" : "Siirtänyt {user}",
-    "\"remote user\"" : "\"etäkäyttäjä\"",
+    "\"remote account\"" : "\"etätili\"",
     "You created {file}" : "Loit tiedoston {file}",
     "You created an encrypted file in {file}" : "Loit salatun tiedoston {file}",
     "{user} created {file}" : "{user} loi tiedoston {file}",
@@ -154,7 +156,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Tiedosto on lisätty tai poistettu <strong>suosikeista</strong>",
     "A file or folder has been <strong>changed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Suosikkitiedostoa tai -kansiota on <strong>muutettu</strong>",
-    "All files" : "Kaikki tiedostot",
     "Upload (max. %s)" : "Lähetys (enintään %s)",
     "Accept" : "Hyväksy",
     "Reject" : "Hylkää",
@@ -168,28 +169,36 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjältä {user} valmistui.",
     "in %s" : "polussa %s",
     "File Management" : "Tiedostohallinta",
+    "Current directory path" : "Nykyisen kansion polku",
     "Reload current directory" : "Lataa nykyinen kansio uudelleen",
     "Go to the \"{dir}\" directory" : "Siirry kansioon \"{dir}\"",
+    "Drag and drop files here to upload" : "Vedä ja pudota tiedostot tähän lähettääksesi",
+    "Your have used your space quota and cannot upload files anymore" : "Olet käyttänyt tilakiintiösi, joten et voi lähettää enempää tiedostoja",
+    "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
     "Rename file" : "Nimeä tiedosto uudelleen",
     "File name" : "Tiedostonimi",
-    "A long time ago" : "Kauan aikaa sitten",
+    "Folder name" : "Kansion nimi",
     "Download file {name}" : "Lataa tiedosto {name}",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" ei ole sallittu tiedostotyyppi.",
     "{newName} already exists." : "{newName} on jo olemassa.",
+    "\"{char}\" is not allowed inside a file name." : "Merkki \"{char}\" ei ole sallittu tiedostonimessä.",
     "Name cannot be empty" : "Nimi ei voi olla tyhjä",
     "Another entry with the same name already exists" : "Toinen tietue samalla nimellä on jo olemassa",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Kohteen \"{oldName}\" uudeksi nimeksi asetettiin \"{newName}\"",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Kohdetta \"{oldName}\" ei voitu nimetä uudelleen, koska sitä ei ole enää olemassa",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{newName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
     "Could not rename \"{oldName}\"" : "Ei voitu nimetä uudelleen \"{oldName}\"",
-    "Select all" : "Valitse kaikki",
-    "Unselect all" : "Poista valinnat",
-    "ascending" : "nousevasti",
-    "descending" : "laskevasti",
-    "Sort list by {column} ({direction})" : "Järjestä luettelo sarakkeen {column} mukaan ({direction})",
     "List of files and folders." : "Luettelo tiedostoista ja kansioista.",
+    "Column headers with buttons are sortable." : "Painikkeilla varustetut sarakeotsikot ovat järjestettävissä.",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tätä luetteloa ei ole esitetty täysin suorituskykyyn liittyvistä syistä. Tiedostot esitetään sitä mukaa, kun selaat luetteloa.",
+    "File not found" : "Tiedostoa ei löytynyt",
     "Storage informations" : "Tallennustilan tietoja",
     "{usedQuotaByte} used" : "{usedQuotaByte} käytetty",
     "{relative}% used" : "{relative} % käytetty",
     "Could not refresh storage stats" : "Tallennustilan tilastoja ei voitu päivittää",
+    "Your storage is full, files can not be updated or synced anymore!" : "Tallennustila on loppu, tiedostoja ei voi enää päivittää tai synkronoida!",
+    "Create" : "Luo",
+    "A file or folder with that name already exists." : "Tiedosto tai kansio tällä nimellä on jo olemassa.",
     "Transfer ownership of a file or folder" : "Siirrä tiedoston tai kansion omistajuus",
     "Choose file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
     "Change" : "Muuta",
@@ -202,20 +211,35 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Pyyntö omistajuuden vaihdosta lähetetty",
     "Cannot transfer ownership of a file or folder you do not own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
     "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
+    "Choose file" : "Valitse tiedosto",
+    "Choose {file}" : "Valitse {file}",
     "Loading current folder" : "Ladataan nykyistä kansiota",
     "No files in here" : "Täällä ei ole tiedostoja",
     "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
     "Go to the previous folder" : "Siirry edelliseen kansioon",
     "Go back" : "Mene takaisin",
+    "Share" : "Jaa",
+    "Shared by link" : "Jaettu linkillä",
+    "Shared" : "Jaettu",
+    "Switch to list view" : "Vaihda taulukkonäkymään",
+    "Switch to grid view" : "Vaihda ruudukkonäkymään",
+    "Error during upload: {message}" : "Virhe lähettäessä: {message}",
+    "Error during upload, status code {status}" : "Virhe lähettäessä, tilakoodi {status}",
+    "Unknown error during upload" : "Tuntematon virhe lähettämisen aikana",
     "Open the files app settings" : "Avaa tiedostosovelluksen asetukset",
     "Files settings" : "Tiedostojen asetukset",
     "File cannot be accessed" : "Tiedostoa ei voi käyttää",
-    "You might not have have permissions to view it, ask the sender to share it" : "Oikeutesi eivät kenties riitä sen katseluun, pyydä lähettäjää jakamaan se",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Tiedostoa ei löytynyt tai oikeutesi eivät riitä sen katseluun. Pyydä lähettäjää jakamaan se.",
+    "Your files" : "Tiedostot",
+    "Open in files" : "Avaa tiedostosovelluksessa",
     "Sort favorites first" : "Järjestä suosikit ensiksi",
+    "Sort folders before files" : "Järjestä kansiot ennen tiedostoja",
     "Show hidden files" : "Näytä piilotetut tiedostot",
     "Crop image previews" : "Rajaa kuvien esikatseluja",
+    "Enable the grid view" : "Käytä ruudukkonäkymää",
     "Additional settings" : "Lisäasetukset",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV:in URL-osoite",
     "Copy to clipboard" : "Kopioi leikepöydälle",
     "Use this address to access your Files via WebDAV" : "Käytä tätä osoitetta yhdistääksesi tiedostosi WebDAV:in kautta",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jos sinulla on kaksivaiheinen todennus käytössä, sinun täytyy luoda uusi sovellussalasana ja käyttää sitä napsauttamalla tästä.",
@@ -224,45 +248,85 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Suosikki-tilan muuttaminen epäonnistui.",
     "Error while loading the file data" : "Virhe tiedostoa ladatessa",
     "Pick a template for {name}" : "Valtise mallipohja tiedostolle {name}",
-    "Create" : "Luo",
     "Create a new file with the selected template" : "Luo uusi tiedosto valitulla mallipohjalla",
     "Creating file" : "Luodaan tiedostoa",
     "Blank" : "Tyhjä",
     "Unable to create new file from template" : "Uutta tiedostoa mallipohjasta ei voi luoda",
     "Delete permanently" : "Poista pysyvästi",
+    "Delete and unshare" : "Poista ja lopeta jakaminen",
+    "Delete files" : "Poista tiedostot",
+    "Delete folders" : "Poista kansio",
+    "You are about to delete {count} items." : "Olet aikeissa poistaa {count} kohdetta.",
+    "Confirm deletion" : "Vahvista poistaminen",
+    "Cancel" : "Peruuta",
+    "Deletion cancelled" : "Poistaminen peruttu",
+    "Destination is not a folder" : "Kohde ei ole kansio",
+    "This file/folder is already in that directory" : "Tämä tiedosto/kansio on jo kyseisessä kansiossa",
+    "Move cancelled" : "Siirtäminen peruttu",
+    "A file or folder with that name already exists in this folder" : "Tiedosto tai kansio tällä nimellä on jo olemassa tässä kansiossa",
+    "The files are locked" : "Tiedostot on lukittu",
+    "The file does not exist anymore" : "Tiedostoa ei ole enää olemassa",
+    "Copy to {target}" : "Kopioi kohteeseen {target}",
+    "Move to {target}" : "Siirrä kohteeseen {target}",
+    "Move or copy operation failed" : "Siirto- tai kopiointitoiminto epäonnistui",
     "Open folder {displayName}" : "Avaa kansio {displayName}",
+    "Open in Files" : "Avaa tiedostosovelluksessa",
     "Open details" : "Avaa yksityiskohdat",
-    "Set up templates folder" : "Aseta mallipohjien kansio",
-    "Templates" : "Mallipohjat",
-    "Create new templates folder" : "Luo uusi mallipohjien kansio",
+    "Created new folder \"{name}\"" : "Luotu uusi kansio \"{name}\"",
+    "Filename" : "Tiedostonimi",
     "Unable to initialize the templates directory" : "Mallipohjien kansiota ei voitu alustaa",
+    "Create new templates folder" : "Luo uusi mallipohjien kansio",
+    "Templates" : "Mallipohjat",
+    "New template folder" : "Uusi mallipohjien kansio",
+    "Search in folder: {folder}" : "Etsi kansiosta: {folder}",
+    "Some files could not be uploaded" : "Joitain tiedostoja ei voitu lähettää",
+    "Files uploaded successfully" : "Tiedostot lähetetty onnistuneesti",
+    "Some files could not be moved" : "Joitain tiedostoja ei voitu siirtää",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} kansio","{folderCount} kansiota"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} tiedosto","{fileCount} tiedostoa"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 tiedosto ja {folderCount} kansio","1 tiedosto ja {folderCount} kansiota"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} tiedosto ja 1 kansio","{fileCount} tiedostoa ja 1 kansio"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} tiedostoa ja {folderCount} kansiota",
     "List of favorites files and folders." : "Luettelo suosikkitiedostoista ja -kansioista.",
     "No favorites yet" : "Ei vielä suosikkeja",
     "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
-    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
+    "All files" : "Kaikki tiedostot",
+    "List of your files and folders." : "Luettelo tiedostoistasi ja kansioistasi.",
+    "Personal Files" : "Henkilökohtaiset tiedostot",
+    "List of your files and folders that are not shared." : "Luettelo tiedostoistasi ja kansioistasi, joita ei ole jaettu.",
+    "No personal files found" : "Henkilökohtaisia tiedostoja ei löytynyt",
+    "Files that are not shared will show up here." : "Tiedostot, joita ei ole jasettu, näkyvät täällä.",
+    "List of recently modified files and folders." : "Luettelo äskettäin muokatuista tiedostoista ja kansioista.",
+    "No recently modified files" : "Ei äskettäin muokattuja tiedostoja",
+    "Files and folders you recently modified will show up here." : "Äskettäin muokkaamasi tiedostot ja kansiot näkyvät täällä.",
     "No entries found in this folder" : "Ei kohteita tässä kansiossa",
+    "Select all" : "Valitse kaikki",
     "Upload too large" : "Lähetettävä tiedosto on liian suuri",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
     "Text file" : "Tekstitiedosto",
     "New text file.txt" : "Uusi tekstitiedosto.txt",
-    "Storage invalid" : "Virheellinen tallennustila",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Suoralinkki kopioitiin (toimii vain niillä käyttäjillä, joilla on pääsy kyseiseen tiedostoon/kansioon)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopioi suora linkki (toimii vain käyttäjillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
     "You can only favorite a single file or folder at a time" : "Voit valita suosikiksi vain yhden tiedoston tai kansion kerrallaan",
-    "Unlimited" : "Rajoittamaton",
-    "Search users" : "Etsi käyttäjistä",
-    "Cancel" : "Peruuta",
-    "%s used" : "%s käytetty",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s/%2$s käytetty",
-    "Deleted files" : "Poistetut tiedostot",
+    "This file has the tag {tag}" : "Tällä tiedostolla on tunniste {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "Tällä tiedostolla on tunnisteet {firstTags} ja {lastTag}",
+    "\"remote user\"" : "\"etäkäyttäjä\"",
+    "Open folder {name}" : "Avaa kansio {name}",
+    "Unselect all" : "Poista valinnat",
+    "ascending" : "nousevasti",
+    "descending" : "laskevasti",
+    "Sort list by {column} ({direction})" : "Järjestä luettelo sarakkeen {column} mukaan ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Tätä luetteloa ei ole esitetty täysin suorituskykyyn liittyvistä syistä. Tiedostot esitetään sitä mukaa, kun selaat luetteloa.",
+    "Search for an account" : "Etsi tiliä",
+    "Choose" : "Valitse",
+    "No files or folders have been deleted yet" : "Tiedostoja tai kansioita ei ole vielä poistettu",
+    "You might not have have permissions to view it, ask the sender to share it" : "Oikeutesi eivät kenties riitä sen katseluun, pyydä lähettäjää jakamaan se",
+    "Set up templates folder" : "Aseta mallipohjien kansio",
+    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
     "Shares" : "Jaot",
     "Shared with others" : "Jaettu muille",
     "Shared with you" : "Jaettu kanssasi",
-    "Shared by link" : "Jaettu linkillä",
     "Deleted shares" : "Poistetut jaot",
-    "Pending shares" : "Odottavat jaot",
-    "Open folder {name}" : "Avaa kansio {name}",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Tätä luetteloa ei ole esitetty täysin suorituskykyyn liittyvistä syistä. Tiedostot esitetään sitä mukaa, kun selaat luetteloa.",
-    "Search for an account" : "Etsi tiliä",
-    "No files or folders have been deleted yet" : "Tiedostoja tai kansioita ei ole vielä poistettu"
+    "Pending shares" : "Odottavat jaot"
 },
 "nplurals=2; plural=(n != 1);");
