@@ -1,9 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
-    "Storage invalid" : "Nieprawidłowy magazyn",
-    "Unknown error" : "Nieznany błąd",
     "File could not be found" : "Nie można znaleźć pliku",
     "Move or copy" : "Przenieś lub kopiuj",
     "Download" : "Pobierz",
@@ -13,7 +10,6 @@ OC.L10N.register(
     "Show grid view" : "Pokaż widok siatki",
     "Home" : "Strona główna",
     "Close" : "Zamknij",
-    "Favorites" : "Ulubione",
     "Could not create folder \"{dir}\"" : "Nie można utworzyć katalogu \"{dir}\"",
     "This will stop your current uploads." : "Spowoduje to zatrzymanie wysyłania plików.",
     "Upload cancelled." : "Wysyłanie anulowane.",
@@ -26,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "Wystąpił nieznany błąd",
     "File could not be uploaded" : "Nie można przesłać pliku",
     "Uploading …" : "Wysyłanie…",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Wysyłanie… ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Wysyłanie tego elementu nie jest wspierane",
     "Target folder does not exist any more" : "Katalog docelowy już nie istnieje",
@@ -36,12 +34,13 @@ OC.L10N.register(
     "Move" : "Przenieś",
     "Copy" : "Kopiuj",
     "Choose target folder" : "Wybierz katalog docelowy",
+    "Set reminder" : "Ustaw przypomnienie",
     "Edit locally" : "Edytuj lokalnie",
     "Open" : "Otwórz",
     "Delete file" : "Usuń plik",
     "Delete folder" : "Usuń katalog",
     "Disconnect storage" : "Odłącz magazyn",
-    "Leave this share" : "Opuść udostępnienie",
+    "Leave this share" : "Opuść te udostępnienie",
     "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
     "Files" : "Pliki",
     "Details" : "Szczegóły",
@@ -53,6 +52,7 @@ OC.L10N.register(
     "Unable to determine date" : "Nie można ustalić daty",
     "This operation is forbidden" : "Ta operacja jest niedozwolona",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ten katalog jest niedostępny, sprawdź logi lub skontaktuj się z administratorem",
+    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
     "Could not move \"{file}\", target exists" : "Nie można przenieść \"{file}\" - plik o takiej nazwie już istnieje",
     "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
     "copy" : "kopia",
@@ -81,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["w tym %n ukryty","w tym %n ukryte","w tym %n ukrytych","w tym %n ukrytych"],
     "You do not have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
     "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
+    "New" : "Nowy",
     "New file/folder menu" : "Nowe menu plików/katalogów",
     "Select file range" : "Wybierz zakres plików",
     "{used}%" : "{used}%",
@@ -100,14 +101,14 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Twój magazyn jest prawie pełny ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["pasuje do \"{filter}\"","pasują do \"{filter}\"","pasują do \"{filter}\"","pasują do \"{filter}\""],
     "View in folder" : "Zobacz w katalogu",
-    "Copied!" : "Skopiowano!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Bezpośredni link został skopiowany (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
     "Path" : "Ścieżka",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
     "Favorited" : "Ulubiony",
     "Favorite" : "Ulubiony",
-    "You can only favorite a single file or folder at a time" : "Możesz dodać do ulubionych tylko pojedynczy plik lub katalog",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
     "New folder" : "Nowy katalog",
+    "Create new folder" : "Utwórz nowy katalog",
     "Upload file" : "Wyślij plik",
     "Recent" : "Ostatnie",
     "Not favorited" : "Wyłączone z ulubionych",
@@ -118,6 +119,7 @@ OC.L10N.register(
     "Removed from favorites" : "Usunięto z ulubionych",
     "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
     "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
+    "Favorites" : "Ulubione",
     "File changes" : "Zmiany w plikach",
     "Created by {user}" : "Utworzone przez {user}",
     "Changed by {user}" : "Zmienione przez {user}",
@@ -125,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Przywrócone przez {user}",
     "Renamed by {user}" : "Zmienione przez {user}",
     "Moved by {user}" : "Przeniesione przez {user}",
-    "\"remote user\"" : "\"użytkownik zdalny\"",
+    "\"remote account\"" : "\"zdalne konto\"",
     "You created {file}" : "Utworzy‭łeś {file}",
     "You created an encrypted file in {file}" : "Stworzyłeś zaszyfrowany plik w {file}",
     "{user} created {file}" : "{user} utworzy‭ł {file}",
@@ -154,8 +156,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z <strong>ulubionych</strong>",
     "A file or folder has been <strong>changed</strong>" : "Plik lub katalog został <strong>zmieniony</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Ulubiony plik lub katalog został <strong>zmieniony</strong>",
-    "All files" : "Wszystkie pliki",
-    "Unlimited" : "Brak limitu",
     "Upload (max. %s)" : "Wysyłanie (maks. %s)",
     "Accept" : "Akceptuj",
     "Reject" : "Odrzuć",
@@ -169,61 +169,184 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Przeniesienie własności {path} z {user} zostało zakończone.",
     "in %s" : "w %s",
     "File Management" : "Zarządzanie plikami",
+    "Current directory path" : "Obecna ścieżka katalogu",
+    "Reload current directory" : "Przeładuj bieżący katalog",
+    "Go to the \"{dir}\" directory" : "Przejdź do katalogu \"{dir}\"",
+    "Drag and drop files here to upload" : "Przeciągnij i upuść pliki tutaj, aby je przesłać",
+    "Your have used your space quota and cannot upload files anymore" : "Wykorzystałeś limit miejsca i nie możesz już wysyłać plików.",
+    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
+    "\"{displayName}\" action executed successfully" : "Akcja \"{displayName}\" została wykonana pomyślnie",
+    "\"{displayName}\" action failed" : "Akcja \"{displayName}\" nie powiodła się",
+    "Toggle selection for file \"{displayName}\"" : "Przełącz zaznaczenie dla pliku \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Przełącz zaznaczenie dla katalogu \"{displayName}\"",
+    "Rename file" : "Zmień nazwę pliku",
+    "File name" : "Nazwa pliku",
+    "Folder name" : "Nazwa katalogu",
+    "This node is unavailable" : "Ten węzeł jest niedostępny",
+    "Download file {name}" : "Pobierz plik {name}",
+    "\"{name}\" is not an allowed filetype." : "\"{name}\" nie jest dozwolonym typem pliku.",
+    "{newName} already exists." : "{newName} już istnieje.",
+    "\"{char}\" is not allowed inside a file name." : "\"{char}\" jest niedozwolone w nazwie pliku.",
+    "Name cannot be empty" : "Nazwa nie może być pusta",
+    "Another entry with the same name already exists" : "Inny wpis o tej samej nazwie już istnieje",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Zmieniono nazwę \"{oldName}\" na \"{newName}\"",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Nie można zmienić nazwy \"{oldName}\", już nie istnieje",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{newName}\" jest już używana w folderze \"{dir}\". Wybierz inną nazwę.",
+    "Could not rename \"{oldName}\"" : "Nie można zmienić nazwy \"{oldName}\"",
+    "Total rows summary" : "Podsumowanie wszystkich wierszy",
+    "Toggle selection for all files and folders" : "Przełącz zaznaczenie dla wszystkich plików i katalogów",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" nie powiodło się w przypadku niektórych elementów",
+    "\"{displayName}\" batch action executed successfully" : "Akcja wsadowa \"{displayName}\" została wykonana pomyślnie",
+    "List of files and folders." : "Lista plików i katalogów.",
+    "Column headers with buttons are sortable." : "Nagłówki kolumn z przyciskami są sortowalne.",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
+    "File not found" : "Nie odnaleziono pliku",
+    "Storage informations" : "Informacje o przechowywaniu",
+    "{usedQuotaByte} used" : "Wykorzystano {usedQuotaByte}",
+    "{relative}% used" : "Wykorzystano {relative}%",
+    "Could not refresh storage stats" : "Nie można odświeżyć statystyk przechowywania",
+    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Nie można już zaktualizować ani zsynchronizować plików!",
+    "Create" : "Utwórz",
+    "A file or folder with that name already exists." : "Plik lub katalog o tej nazwie już istnieje.",
     "Transfer ownership of a file or folder" : "Przenieś własność pliku lub katalogu",
     "Choose file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
     "Change" : "Zmień",
     "New owner" : "Nowy właściciel",
-    "Search users" : "Wyszukaj użytkowników",
     "Choose a file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
     "Transfer" : "Przenieś",
     "Transfer {path} to {userid}" : "Przenieś {path} do {userid}",
     "Invalid path selected" : "Wybrano nieprawidłową ścieżkę",
+    "Unknown error" : "Nieznany błąd",
     "Ownership transfer request sent" : "Wysłano żądanie przeniesienia własności",
     "Cannot transfer ownership of a file or folder you do not own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
+    "Select file or folder to link to" : "Wybierz plik lub katalog do linku",
+    "Choose file" : "Wybierz plik",
+    "Choose {file}" : "Wybierz {file}",
+    "Loading current folder" : "Ładowanie bieżącego katalogu",
+    "No files in here" : "Brak plików",
+    "Upload some content or sync with your devices!" : "Wyślij lub zsynchronizuj pliki z urządzeniami.",
+    "Go to the previous folder" : "Przejdź do poprzedniego katalogu",
+    "Go back" : "Wstecz",
+    "Share" : "Udostępnij",
+    "Shared by link" : "Udostępnione linkiem",
+    "Shared" : "Udostępnione",
+    "Switch to list view" : "Przełącz na widok listy",
+    "Switch to grid view" : "Przełącz na widok siatki",
+    "Error during upload: {message}" : "Błąd podczas wysyłania: {message}",
+    "Error during upload, status code {status}" : "Błąd podczas wysyłania, kod statusu {status}",
+    "Unknown error during upload" : "Nieznany błąd podczas wysyłania",
+    "Open the files app settings" : "Otwórz ustawienia aplikacji plików",
+    "Files settings" : "Ustawienia Plików",
+    "File cannot be accessed" : "Nie można uzyskać dostępu do pliku",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Nie znaleziono pliku lub nie masz uprawnień, aby go wyświetlić. Poproś nadawcę o udostępnienie.",
+    "Your files" : "Twoje pliki",
+    "Open in files" : "Otwórz w Plikach",
+    "Sort favorites first" : "Najpierw sortuj ulubione",
+    "Sort folders before files" : "Sortuj katalogi przed plikami",
+    "Show hidden files" : "Pokaż ukryte pliki",
+    "Crop image previews" : "Przytnij podglądy obrazów",
+    "Enable the grid view" : "Włącz widok siatki",
+    "Additional settings" : "Ustawienia dodatkowe",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "URL WebDAV",
+    "Copy to clipboard" : "Kopiuj do schowka",
+    "Use this address to access your Files via WebDAV" : "Użyj tego adresu, aby uzyskać dostęp do plików poprzez WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jeśli włączyłeś 2FA, musisz utworzyć i używać nowego hasła do aplikacji, klikając tutaj.",
+    "Clipboard is not available" : "Schowek jest niedostępny",
+    "WebDAV URL copied to clipboard" : "Adres URL WebDAV skopiowany do schowka",
     "Unable to change the favourite state of the file" : "Nie można zmienić ulubionego stanu pliku",
     "Error while loading the file data" : "Błąd podczas ładowania danych pliku",
     "Pick a template for {name}" : "Wybierz szablon dla {name}",
-    "Cancel" : "Anuluj",
-    "Create" : "Utwórz",
     "Create a new file with the selected template" : "Utwórz nowy plik z wybranym szablonem",
     "Creating file" : "Tworzenie pliku",
     "Blank" : "Pusty",
     "Unable to create new file from template" : "Nie można utworzyć nowego pliku z szablonu",
-    "Set up templates folder" : "Skonfiguruj katalog szablonów",
-    "Templates" : "Szablony",
+    "Delete permanently" : "Usuń bezpowrotnie",
+    "Delete and unshare" : "Usuń i przestań udostępniać",
+    "Leave these shares" : "Opuść udostępnienia",
+    "Disconnect storages" : "Odłącz magazyny",
+    "Delete files" : "Usuń pliki",
+    "Delete folders" : "Usuń katalogi",
+    "You are about to delete {count} items." : "Zamierzasz usunąć {count} elementów.",
+    "Confirm deletion" : "Potwierdź usunięcie",
+    "Cancel" : "Anuluj",
+    "Deletion cancelled" : "Usuwanie anulowane",
+    "Destination is not a folder" : "Miejsce docelowe nie jest katalogiem",
+    "This file/folder is already in that directory" : "Ten plik/katalog znajduje się już w tym katalogu",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nie można przenieść pliku/katalogu do tego samego katalogu lub do własnego podkatalogu",
+    "(copy)" : "(kopiuj)",
+    "(copy %n)" : "(kopiuj %n)",
+    "Move cancelled" : "Przenoszenie anulowane",
+    "A file or folder with that name already exists in this folder" : "Plik lub katalog o tej nazwie już istnieje w tym katalogu",
+    "The files are locked" : "Pliki są zablokowane",
+    "The file does not exist anymore" : "Plik już nie istnieje",
+    "Choose destination" : "Wybierz miejsce docelowe",
+    "Copy to {target}" : "Skopiuj do {target}",
+    "Move to {target}" : "Przenieś do {target}",
+    "Cancelled move or copy operation" : "Anulowano operację przenoszenia lub kopiowania",
+    "Move or copy operation failed" : "Operacja przenoszenia lub kopiowania nie powiodła się",
+    "Open folder {displayName}" : "Otwórz katalog {displayName}",
+    "Open in Files" : "Otwórz w Plikach",
+    "Open details" : "Otwórz szczegóły",
+    "Created new folder \"{name}\"" : "Utworzono nowy katalog \"{name}\"",
+    "Filename" : "Nazwa pliku",
     "Unable to initialize the templates directory" : "Nie można zainicjować katalogu szablonów",
-    "%s used" : "Wykorzystane: %s",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "Wykorzystane: %1$s z %2$s",
-    "Files settings" : "Ustawienia Plików",
-    "Show hidden files" : "Pokaż ukryte pliki",
-    "Crop image previews" : "Przytnij podglądy obrazów",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Użyj tego adresu, aby uzyskać dostęp do plików poprzez WebDAV",
-    "Toggle %1$s sublist" : "Przełącz podlistę %1$s",
-    "Toggle grid view" : "Przełącz widok siatki",
-    "No files in here" : "Brak plików",
-    "Upload some content or sync with your devices!" : "Wyślij lub zsynchronizuj pliki z urządzeniami.",
+    "Create new templates folder" : "Stwórz nowy folder z szablonami",
+    "Templates" : "Szablony",
+    "In folder" : "W katalogu",
+    "Search in folder: {folder}" : "Szukaj w katalogu: {folder}",
+    "One of the dropped files could not be processed" : "Jeden z upuszczonych plików nie mógł być przetworzony",
+    "Some files could not be uploaded" : "Nie udało się wysłać niektórych plików",
+    "Files uploaded successfully" : "Pliki przesłane pomyślnie",
+    "Some files could not be moved" : "Niektóre pliki nie mogły zostać przeniesione",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} katalog","{folderCount} katalogi","{folderCount} katalogów","{folderCount} katalogów"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} plik","{fileCount} pliki","{fileCount} plików","{fileCount} plików"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 plik i {folderCount} katalog","1 plik i {folderCount} katalogi","1 plik i {folderCount} katalogów","1 plik i {folderCount} katalogów"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} plik i 1 katalog","{fileCount} pliki i 1 katalog","{fileCount} plików i 1 katalog","{fileCount} plików i 1 katalog"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} plików i {folderCount} katalogów",
+    "List of favorites files and folders." : "Lista ulubionych plików i katalogów.",
+    "No favorites yet" : "Brak ulubionych",
+    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
+    "All files" : "Wszystkie pliki",
+    "List of your files and folders." : "Lista Twoich plików i katalogów.",
+    "Personal Files" : "Pliki osobiste",
+    "List of your files and folders that are not shared." : "Lista twoich plików i katalogów, które nie są udostępniane",
+    "No personal files found" : "Nie znaleziono plików osobistych",
+    "Files that are not shared will show up here." : "Tutaj pojawią się pliki, które nie są udostępniane.",
+    "List of recently modified files and folders." : "Lista ostatnio zmodyfikowanych plików i katalogów.",
+    "No recently modified files" : "Brak ostatnio zmodyfikowanych plików",
+    "Files and folders you recently modified will show up here." : "Tutaj pojawią się pliki i katalogi, które ostatnio zmodyfikowałeś.",
     "No entries found in this folder" : "Brak wpisów w tym katalogu",
     "Select all" : "Wybierz wszystko",
     "Upload too large" : "Wysyłany plik jest za duży",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz wysłać, przekraczają maksymalną dopuszczalną wielkość.",
-    "No favorites yet" : "Brak ulubionych",
-    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
-    "Deleted files" : "Usunięte pliki",
+    "Text file" : "Plik tekstowy",
+    "New text file.txt" : "Nowy plik tekstowy.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Bezpośredni link został skopiowany (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
+    "You can only favorite a single file or folder at a time" : "Możesz dodać do ulubionych tylko pojedynczy plik lub katalog",
+    "This file has the tag {tag}" : "Ten plik posiada etykietę {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "Ten plik posiada etykiety {firstTags} i {lastTag}",
+    "\"remote user\"" : "\"użytkownik zdalny\"",
+    "Select the row for {displayName}" : "Wybierz wiersz dla {displayName}",
+    "Open folder {name}" : "Otwórz katalog {name}",
+    "Unselect all" : "Odznacz wszystko",
+    "ascending" : "rosnąco",
+    "descending" : "malejąco",
+    "Sort list by {column} ({direction})" : "Sortuj listę według {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
+    "Search for an account" : "Wyszukaj konto",
+    "Choose" : "Wybierz",
+    "No files or folders have been deleted yet" : "Żadne pliki ani katalogi nie zostały jeszcze usunięte",
+    "You might not have have permissions to view it, ask the sender to share it" : "Możesz nie mieć uprawnień, aby go wyświetlić, poproś nadawcę o udostępnienie",
+    "Set up templates folder" : "Skonfiguruj katalog szablonów",
+    "Toggle %1$s sublist" : "Przełącz podlistę %1$s",
+    "Toggle grid view" : "Przełącz widok siatki",
     "Shares" : "Udostępnione",
     "Shared with others" : "Udostępnione innym",
     "Shared with you" : "Udostępnione dla Ciebie",
-    "Shared by link" : "Udostępnione linkiem",
     "Deleted shares" : "Usunięte udostępnienia",
     "Pending shares" : "Oczekujące udostępnienia",
-    "Text file" : "Plik tekstowy",
-    "New text file.txt" : "Nowy plik tekstowy.txt",
-    "Select" : "Wybierz",
-    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
-    "New" : "Nowy",
-    "Cannot transfer ownership of a file or folder you don't own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
-    "%s%% of %s used" : "Wykorzystane: %s%% z %s",
-    "Settings" : "Ustawienia"
+    "The files is locked" : "Pliki są zablokowane"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
