@@ -1,9 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "儲存空間暫時無法使用",
-    "Storage invalid" : "無效的儲存空間",
-    "Unknown error" : "未知錯誤",
     "File could not be found" : "找不到檔案",
     "Move or copy" : "移動或複製",
     "Download" : "下載",
@@ -13,7 +10,6 @@ OC.L10N.register(
     "Show grid view" : "顯示網格視圖",
     "Home" : "主目錄",
     "Close" : "關閉",
-    "Favorites" : "最愛",
     "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
     "This will stop your current uploads." : "這會終止目前任何的上傳。",
     "Upload cancelled." : "上傳已取消",
@@ -23,9 +19,11 @@ OC.L10N.register(
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
     "Target folder \"{dir}\" does not exist any more" : "資料夾 \"{dir}\" 不存在",
     "Not enough free space" : "空間不足",
-    "An unknown error has occurred" : "發生了未知的錯誤",
+    "An unknown error has occurred" : "發生了不詳的錯誤",
     "File could not be uploaded" : "檔案無法上傳",
     "Uploading …" : "上傳中...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "上傳中 ... （{currentNumber}／{total}）",
     "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize}（{bitrate}）",
     "Uploading that item is not supported" : "不支援上傳該項目",
     "Target folder does not exist any more" : "目標資料夾已經不存在了",
@@ -36,6 +34,7 @@ OC.L10N.register(
     "Move" : "移動",
     "Copy" : "複製",
     "Choose target folder" : "選擇目標資料夾",
+    "Set reminder" : "設定提醒",
     "Edit locally" : "在近端編輯",
     "Open" : "開啟",
     "Delete file" : "刪除檔案",
@@ -53,6 +52,7 @@ OC.L10N.register(
     "Unable to determine date" : "無法確定日期",
     "This operation is forbidden" : "此操作被禁止",
     "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
+    "Storage is temporarily not available" : "儲存空間暫時無法使用",
     "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
     "Could not move \"{file}\"" : "無法移動 \"{file}\"",
     "copy" : "複製",
@@ -81,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["包括 %n 個隱藏檔"],
     "You do not have permission to upload or create files here" : "您無權限上傳或建立檔案",
     "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
+    "New" : "新",
     "New file/folder menu" : "新檔案/資料夾選項單",
     "Select file range" : "選擇多個檔案",
     "{used}%" : "{used}%",
@@ -100,14 +101,14 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "您的儲存空間將近已滿（{usedSpacePercent}%）。",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["符合「{filter}」"],
     "View in folder" : "在資料夾中檢視",
-    "Copied!" : "已複製",
-    "Copy direct link (only works for users who have access to this file/folder)" : "複製直接連結（只對能存取的用戶有用）",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "已複製直接連結（僅適用於有權訪問此檔案/資料夾的人仕）",
     "Path" : "路徑",
     "_%n byte_::_%n bytes_" : ["%n 位元組"],
     "Favorited" : "已加入最愛",
     "Favorite" : "我的最愛",
-    "You can only favorite a single file or folder at a time" : "您一次只能為一個檔案或資料夾加星號",
+    "Copy direct link (only works for people who have access to this file/folder)" : "複製直接連結（只對能存取的人仕有用）",
     "New folder" : "新資料夾",
+    "Create new folder" : "新增資料夾",
     "Upload file" : "上傳檔案",
     "Recent" : "最新",
     "Not favorited" : "未加入至最愛",
@@ -118,6 +119,7 @@ OC.L10N.register(
     "Removed from favorites" : "已從最愛中移除",
     "You added {file} to your favorites" : "你已添加 {file} 至最愛",
     "You removed {file} from your favorites" : "你已移除 {file} 從最愛",
+    "Favorites" : "最愛",
     "File changes" : "檔案更動",
     "Created by {user}" : "由 {user} 建立",
     "Changed by {user}" : "由 {user} 改動",
@@ -125,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "由 {user} 還原",
     "Renamed by {user}" : "由 {user} 重新命名",
     "Moved by {user}" : "由 {user} 移動",
-    "\"remote user\"" : "「遠端用戶」",
+    "\"remote account\"" : "「遠端帳戶」",
     "You created {file}" : "您建立了 {file}",
     "You created an encrypted file in {file}" : "您在 {file} 建立了一個加密的檔案",
     "{user} created {file}" : "{user} 建立了 {file}",
@@ -154,8 +156,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "已將檔案添加到<strong>我的最愛</strong>收藏夾中或從其中刪除",
     "A file or folder has been <strong>changed</strong>" : "檔案或資料夾有所<strong>更改</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "收藏的檔案或資料夾有所<strong>更改</strong>",
-    "All files" : "所有檔案",
-    "Unlimited" : "無限制",
     "Upload (max. %s)" : "上傳（上限 %s）",
     "Accept" : "接受",
     "Reject" : "拒絕",
@@ -169,61 +169,195 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "來自 {user} 的 \"{path}\" 所有權轉移已經完成",
     "in %s" : "在 %s",
     "File Management" : "檔案管理",
+    "Current directory path" : "目前目錄途徑",
+    "Reload current directory" : "重新加載目前目錄",
+    "Go to the \"{dir}\" directory" : "前往「{dir}」目錄",
+    "Drag and drop files here to upload" : "將檔案拖拽到此處即可上傳",
+    "Your have used your space quota and cannot upload files anymore" : "您已用完您的空間配額，無法再上傳檔案",
+    "You don’t have permission to upload or create files here" : "您無權限上傳或建立檔案",
+    "\"{displayName}\" action executed successfully" : "成功執行 “{displayName}” 操作",
+    "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
+    "Toggle selection for file \"{displayName}\"" : "切換對檔案 \"{displayName}\" 的選擇",
+    "Toggle selection for folder \"{displayName}\"" : "切換對資料夾 \"{displayName}\" 的選擇",
+    "Rename file" : "重新命名檔案",
+    "File name" : "檔案名稱",
+    "Folder name" : "資料夾名稱",
+    "This node is unavailable" : "此節點不可用",
+    "Download file {name}" : "下載檔案 {name}",
+    "\"{name}\" is not an allowed filetype." : "「{name}」是不允許的檔案類型。",
+    "{newName} already exists." : "{newName} 已經存在。",
+    "\"{char}\" is not allowed inside a file name." : "不允許檔案名稱中出現 \"{char}\"。",
+    "Name cannot be empty" : "名稱不能空白",
+    "Another entry with the same name already exists" : "另一個同名的條目已經存在",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
+    "Could not rename \"{oldName}\", it does not exist any more" : "無法命名檔案「{oldName}」，因為此檔案已經不存在",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱「{newName}」在這資料夾「{dir}」已經被使用。請選擇其他名稱。",
+    "Could not rename \"{oldName}\"" : "無法重新命名「{oldName}」",
+    "Total rows summary" : "總列摘要",
+    "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選擇",
+    "\"{displayName}\" failed on some elements " : "“{displayName}” 在某些元素上失敗",
+    "\"{displayName}\" batch action executed successfully" : "成功執行 “{displayName}” 批處理操作",
+    "{count} selected" : "已選擇 {count} 項",
+    "List of files and folders." : "檔案與資料夾清單。",
+    "Column headers with buttons are sortable." : "具有按鈕的縱列標題可排序。",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
+    "File not found" : "找不到檔案",
+    "Storage informations" : "儲存資訊",
+    "{usedQuotaByte} used" : "已使用 {usedQuotaByte} ",
+    "{relative}% used" : "已使用 {relative}%",
+    "Could not refresh storage stats" : "無法更新儲存統計數據",
+    "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
+    "Create" : "創建",
+    "A file or folder with that name already exists." : "已存在同名的檔案或資料夾°。",
     "Transfer ownership of a file or folder" : "轉移檔案或資料夾的擁有權",
     "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Change" : "更改",
     "New owner" : "新的擁有者",
-    "Search users" : "搜尋用戶",
     "Choose a file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Transfer" : "轉移",
     "Transfer {path} to {userid}" : "轉移 \"{path}\" 給 {userid}",
     "Invalid path selected" : "所選的路徑無效",
+    "Unknown error" : "錯誤不詳",
     "Ownership transfer request sent" : "已送出擁有權轉移的請求",
     "Cannot transfer ownership of a file or folder you do not own" : "無法轉移您未擁有的檔案或是資料夾所有權",
+    "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
+    "Choose file" : "選擇檔案",
+    "Choose {file}" : "選擇 {file}",
+    "Loading current folder" : "目前資料夾加載中",
+    "No files in here" : "沒有任何檔案",
+    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
+    "Go to the previous folder" : "前往上一個資料夾",
+    "Go back" : "返回",
+    "Share" : "分享",
+    "Shared by link" : "由連結分享",
+    "Shared" : "已分享",
+    "Switch to list view" : "切換到列表檢視",
+    "Switch to grid view" : "切換到網格檢視",
+    "Error during upload: {message}" : "上傳時發生錯誤：{message}",
+    "Error during upload, status code {status}" : "上傳期間發生錯誤，狀態代碼 {status}",
+    "Unknown error during upload" : "上傳時發生未知的錯誤",
+    "Open the files app settings" : "開啟 Files 應用程式設定",
+    "Files settings" : "檔案設定",
+    "File cannot be accessed" : "檔案無法存取",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請要求寄件者分享。",
+    "Your files" : "您的檔案",
+    "Open in files" : "在「檔案」應用程式中打開",
+    "Sort favorites first" : "先排序最愛",
+    "Sort folders before files" : "將資料夾在檔案之前排序",
+    "Show hidden files" : "顯示隱藏檔",
+    "Crop image previews" : "圖片裁剪預覽",
+    "Enable the grid view" : "啟用網格檢視",
+    "Additional settings" : "其他設定",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
+    "Copy to clipboard" : "複製到剪貼板",
+    "Use this address to access your Files via WebDAV" : "用這位址使用 WebDAV 存取你的檔案。",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果您啟用了 2FA，則必須通過單擊此處創建和使用新的應用程式密碼。",
+    "Clipboard is not available" : "剪貼板不可用",
+    "WebDAV URL copied to clipboard" : "WebDAV 連結已複製到剪貼板",
     "Unable to change the favourite state of the file" : "無法更改檔案的最愛狀態",
     "Error while loading the file data" : "載入檔案資料失敗",
     "Pick a template for {name}" : "為 {name} 選擇一個模板",
-    "Cancel" : "取消",
-    "Create" : "創建",
     "Create a new file with the selected template" : "使用所選模板創建一個新檔案",
     "Creating file" : "創建檔案中",
     "Blank" : "空白",
     "Unable to create new file from template" : "無法從模板創建新檔案",
-    "Set up templates folder" : "設定範本料夾",
-    "Templates" : "模板",
+    "Delete permanently" : "永久刪除",
+    "Delete and unshare" : "刪除並取消分享",
+    "Leave these shares" : "保留這些分享",
+    "Disconnect storages" : "解除連結儲存空間",
+    "Delete files" : "刪除檔案",
+    "Delete folders" : "刪除資料夾",
+    "You are about to delete {count} items." : "您即將刪除 {count} 項。",
+    "Confirm deletion" : "確認刪除",
+    "Cancel" : "取消",
+    "Deletion cancelled" : "刪除已取消",
+    "Destination is not a folder" : "目標地不是資料夾",
+    "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
+    "(copy)" : "（複本）",
+    "(copy %n)" : "（複本 %n）",
+    "Move cancelled" : "移動已取消",
+    "A file or folder with that name already exists in this folder" : "此資料夾中已存在同名的檔案或資料夾",
+    "The files are locked" : "檔案已被上鎖",
+    "The file does not exist anymore" : "檔案已不存在",
+    "Choose destination" : "選擇目標地",
+    "Copy to {target}" : "複製到 {target}",
+    "Move to {target}" : "移動到 {target}",
+    "Cancelled move or copy operation" : "已取消移動或複製操作",
+    "Move or copy operation failed" : "移動或複製操作失敗",
+    "Open folder {displayName}" : "打開資料夾 {displayName}",
+    "Open in Files" : "在「檔案」應用程式中打開",
+    "Open details" : "開啟細節",
+    "Created new folder \"{name}\"" : "創建了新資料夾 \"{name}\"",
+    "Filename" : "檔案名稱",
     "Unable to initialize the templates directory" : "無法初始化模板目錄",
-    "%s used" : "使用了 %s 的存儲空間",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "在 %2$s 中使用了 %1$s",
-    "Files settings" : "檔案設定",
-    "Show hidden files" : "顯示隱藏檔",
-    "Crop image previews" : "圖片裁剪預覽",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "用這位址使用 WebDAV 存取你的檔案。",
-    "Toggle %1$s sublist" : "切換 %1$s 子列表",
-    "Toggle grid view" : "切換網格檢視",
-    "No files in here" : "沒有任何檔案",
-    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
+    "Create new templates folder" : "創建新範本資料夾",
+    "Templates" : "模板",
+    "New template folder" : "新範本資料夾",
+    "In folder" : "在資料夾中",
+    "Search in folder: {folder}" : "搜尋資料夾： {folder}",
+    "One of the dropped files could not be processed" : "無法處理其中一個投放的檔案",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "您的瀏覽器不支援檔案系統 API。將不會上傳目錄",
+    "No files to upload" : "沒有要上傳的檔案",
+    "Unable to create the directory {directory}" : "無法建立目錄 {directory}",
+    "Some files could not be uploaded" : "無法上傳某些檔案",
+    "Files uploaded successfully" : "成功上傳檔案",
+    "No files to process" : "沒有要處理的檔案",
+    "Some files could not be copied" : "無法複製部份檔案",
+    "Some files could not be moved" : "有些檔案無法被移動",
+    "Files copied successfully" : "檔案複製成功",
+    "Files moved successfully" : "檔案移動成功",
+    "Conflicts resolution skipped" : "已略過衝突解決",
+    "Upload cancelled" : "上傳已取消",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 個資料夾"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 個檔案"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
+    "List of favorites files and folders." : "最愛檔案與資料夾的清單。",
+    "No favorites yet" : "尚無最愛",
+    "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
+    "All files" : "所有檔案",
+    "List of your files and folders." : "您的檔案與資料夾清單。",
+    "Personal Files" : "個人檔案",
+    "List of your files and folders that are not shared." : "未分享的檔案與資料夾清單。",
+    "No personal files found" : "找不到個人檔案",
+    "Files that are not shared will show up here." : "尚未分享的檔案將會顯示在此處。",
+    "List of recently modified files and folders." : "最近修改的檔案和資料夾的清單。",
+    "No recently modified files" : "近期無修改檔案",
+    "Files and folders you recently modified will show up here." : "您最近修改的檔案和資料夾將顯示在此處。",
     "No entries found in this folder" : "在此資料夾中沒有任何項目",
     "Select all" : "全選",
     "Upload too large" : "上傳過大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
-    "No favorites yet" : "尚無最愛",
-    "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
-    "Deleted files" : "回收桶",
+    "Text file" : "文字檔",
+    "New text file.txt" : "新文字檔.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "已複製直接連結（僅適用於有權訪問此檔案/資料夾的用戶）",
+    "Copy direct link (only works for users who have access to this file/folder)" : "複製直接連結（只對能存取的用戶有用）",
+    "You can only favorite a single file or folder at a time" : "您一次只能為一個檔案或資料夾加星號",
+    "This file has the tag {tag}" : "此檔案有標籤 {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "此檔案有標籤 {firstTags} 與 {lastTag}",
+    "\"remote user\"" : "「遠端用戶」",
+    "Select the row for {displayName}" : "選擇 {displayName} 的行",
+    "Open folder {name}" : "打開資料夾 {name}",
+    "Unselect all" : "取消全選",
+    "ascending" : "升",
+    "descending" : "降",
+    "Sort list by {column} ({direction})" : "按 {column} ({direction}) 排序清單",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
+    "Search for an account" : "搜尋賬號",
+    "Choose" : "選擇",
+    "No files or folders have been deleted yet" : "尚未刪除任何檔案或資料夾",
+    "You might not have have permissions to view it, ask the sender to share it" : "您可能沒有權限檢視它，請要求寄件者分享它",
+    "Set up templates folder" : "設定範本資料夾",
+    "Toggle %1$s sublist" : "切換 %1$s 子列表",
+    "Toggle grid view" : "切換網格檢視",
     "Shares" : "分享",
     "Shared with others" : "與其他人分享",
     "Shared with you" : "與您分享",
-    "Shared by link" : "由連結分享",
     "Deleted shares" : "已刪除的分享",
     "Pending shares" : "等待分享",
-    "Text file" : "文字檔",
-    "New text file.txt" : "新文字檔.txt",
-    "Select" : "選擇",
-    "You don’t have permission to upload or create files here" : "您無權限上傳或建立檔案",
-    "New" : "新增",
-    "Cannot transfer ownership of a file or folder you don't own" : "無法轉移您未擁有的檔案或是資料夾所有權。",
-    "%s%% of %s used" : "%s 在 %s 中使用了 %%",
-    "Settings" : "設定"
+    "The files is locked" : "檔案已被上鎖"
 },
 "nplurals=1; plural=0;");
