@@ -79,6 +79,7 @@ OC.L10N.register(
     "Wrong path, file/folder does not exist" : "错误的路径，文件/文件夹不存在",
     "Could not create share" : "无法创建共享",
     "Invalid permissions" : "无效的权限 ",
+    "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
     "Group sharing is disabled by the administrator" : "群组共享已被管理员禁用",
     "Please specify a valid group" : "请指定一个有效的组",
     "Public link sharing is disabled by the administrator" : "公共链接共享已被管理员禁用",
@@ -86,7 +87,6 @@ OC.L10N.register(
     "Public upload is only possible for publicly shared folders" : "公共上传仅适用于公共共享文件夹",
     "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud 通话应用没有启用，所以通过 Nextcloud 通话应用发送%s共享密码失败。",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "共享 %1$s 失败，后端不允许类型为 %2$s 的共享",
-    "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
     "Please specify a valid federated group ID" : "请指定一个有效的联合群组 ID",
     "You cannot share to a Circle if the app is not enabled" : "如果这个应用程序不可用，您不能共享到圈子",
     "Please specify a valid circle" : "请指明一个可用圈子",
@@ -201,12 +201,10 @@ OC.L10N.register(
     "Share with {userName}" : "分享至 {userName}",
     "Share with group" : "分享至群组",
     "Share in conversation" : "分享至对话",
-    "Share with remote" : "分享至远程",
     "Share with remote group" : "分享至远程群组",
     "Share with guest" : "分享至访客",
-    "Share with" : "共享给",
-    "Save share" : "保存分享",
     "Update share" : "更新分享",
+    "Save share" : "保存分享",
     "Others with access" : "其他具有访问权限的人",
     "Toggle list of others with access to this directory" : "切换有权访问此目录的其他人的列表",
     "Toggle list of others with access to this file" : "切换有权访问此文件的其他人的列表",
@@ -283,23 +281,17 @@ OC.L10N.register(
     "No expiration date set" : "未设置失效时间",
     "Please specify a valid user" : "请指定一个有效的用户",
     "Please specify a valid federated user ID" : "请指定一个有效的联合用户 ID",
-    "Sharing %s failed because the back end does not support sciencemesh shares" : "共享 %s 失败，因为后端不支持 ScienceMesh 共享。",
-    "Reject" : "拒绝",
     "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "这个应用程序允许用户在 Nextcloud 内部共享文件。如果启用，管理员能够选择哪个组可以共享文件。然后，可用的用户能够共享文件和文件夹给 Nextcloud 中的其他用户和组。另外，如果管理员启用了共享链接功能，能够使用外部链接将文件共享给 Nextcloud 之外的其他用户。管理员也可以强制设置密码，过期日期，并且可以通过共享链接启用服务器到服务器的共享，以及从移动设备共享。\n关闭该功能将删除服务器上所有共享接收者以用同步客户端和移动应用上的共享文件和文件夹。更多信息可查阅 Nextcloud 文档。",
     "Accept user and group shares by default" : "默认接受用户和分组共享",
     "Read only" : "只读",
     "File drop (upload only)" : "文件拖放（仅上传）",
     "Upload" : "上传",
     "Bundled permissions" : "权限包",
-    "Allow creating" : "允许创建",
-    "Allow deleting" : "允许删除",
-    "Allow resharing" : "允许二次共享",
-    "Expiration date enforced" : "强制过期日期",
     "Only works for users with access to this folder" : "仅适用于有权限访问此文件夹的用户",
     "Only works for users with access to this file" : "仅适用于有权限访问此文件的用户",
-    "Password protect" : "密码保护",
     "Circle" : "圈子",
-    "Science Mesh" : "Science Mesh",
+    "Update" : "更新",
+    "Share with " : "分享给",
     "No other users with access found" : "找不到其他具有访问权限的用户",
     "No entries found in this folder" : "在此文件夹中找不到项目",
     "Name" : "名称",
@@ -310,7 +302,7 @@ OC.L10N.register(
     "the link expired" : "链接过期",
     "sharing is disabled" : "已禁用共享",
     "For more info, please ask the person who sent this link." : "如需了解更多信息，请联系发给您该链接的人。",
-    "Update" : "更新",
-    "Share with " : "分享给"
+    "Share with remote" : "分享至远程",
+    "Share with" : "共享给"
 },
 "nplurals=1; plural=0;");
