@@ -1,6 +1,7 @@
 OC.L10N.register(
     "photos",
     {
+    "Public link" : "Esteka publikoa",
     "Photos" : "Argazkiak",
     "Your memories under your control" : "Zure oroitzapenak zure kontrolpean",
     "All media" : "Fitxategi guztiak",
@@ -13,58 +14,70 @@ OC.L10N.register(
     "On this day" : "Egun honetan",
     "Shared with you" : "Zurekin partekatua",
     "Tags" : "Etiketak",
-    "Locations" : "Kokapenak",
+    "Places" : "Lekuak",
+    "Map" : "Mapa",
     "Photos settings" : "Argazkien ezarpenak",
     "Mark selection as favorite" : "Markatu hautatutakoak gogoko gisa",
     "Add selection to favorites" : "Gehitu hautatutakoak gogokoetara",
     "Remove selection from favorites" : "Kendu hautatutakoak gogokoetatik",
     "Name of the album" : "Albumaren izena",
     "Location of the album" : "Albumaren kokapena",
-    "Go back to the previous view." : "Itzuli aurreko ikuspegira.",
     "Back" : "Atzera",
-    "Go to the add collaborators view." : "Joan kolaboratzaileak gehitzeko ikuspegira.",
     "Add collaborators" : "Gehitu kolaboratzaileak",
-    "Save." : "Gorde.",
-    "Create the album." : "Sortu albuma.",
     "Save" : "Gorde",
     "Create album" : "Sortu albuma",
-    "Back to the new album form." : "Itzuli album berrien formulariora",
     "Add to Album" : "Gehitu album batera",
-    "Add selection to album {ablumName}" : "Gehitu hautapena {albumName} albumera",
+    "Add selection to album {albumName}" : "Gehitu hautapena {albumName} albumera",
+    "Shared by" : "Honek partekatua",
     "Create a new album." : "Sortu album berria.",
     "Create new album" : "Sortu album berria",
     "New album" : "Album berria",
     "_%n item_::_%n photos and videos_" : ["%n fitxategi","%n argazki eta bideo"],
-    "_Share with %n user_::_Share with %n users_" : ["Partekatu %n erabiltzailearekin","Partekatu %n erabiltzaileekin"],
     "Add people or groups who can edit your album" : "Gehitu zure albuma editatu dezaketen pertsona edo taldeak",
-    "Search for collaborators" : "Bilatu kolaboratzaileak",
     "Search people or groups" : "Bilatu erabiltzaile edo taldeak",
-    "Add {collaboratorLabel} to the collaborators list" : "Gehitu {collaboratorLabel} kolaboratzaile zerrendara",
-    "No collaborators available" : "Ez dago kolaboratzailerik eskuragarri",
+    "No recommendations. Start typing." : "Gomendiorik ez. Hasi idazten.",
+    "Group" : "Taldea",
     "Remove {collaboratorLabel} from the collaborators list" : "Kendu {collaboratorLabel} kolaboratzaile zerrendatik",
+    "Copy the public link" : "Kopiatu esteka publikoa",
     "Public link copied!" : "Esteka publikoa kopiatuta!",
     "Copy public link" : "Kopiatu esteka publikoa",
+    "Delete the public link" : "Ezabatu esteka publikoa",
+    "Create public link share" : "Sortu partekatze esteka publikoa",
     "Share via public link" : "Partekatu esteka publiko bidez",
     "Failed to fetch collaborators list." : "Ezin izan da kolaboratzaile zerrenda lortu.",
+    "Failed to update album." : "Ezin izan da albuma eguneratu.",
     "This collection does not exist" : "Bilduma hau ez da existitzen",
-    "An error occurred" : "Akats bat gertatu da",
-    "_%n photos_::_%n photos_" : ["argazki %n","%n argazki"],
+    "An error occurred" : "Errore bat gertatu da",
+    "_%n unassigned photo_::_%n unassigned photos_" : ["Esleitu gabeko argazki %n","%n esleitu gabeko argazki"],
+    "Favorite" : "Egin gogoko",
     "Select image {imageName}" : "Hautatu irudia {imageName}",
-    "The file is in the favorites" : "Fitxategia gogokoetan dago",
+    "Favorite image, open the full size \"{name}\" image" : "Irudi gogokoa, ireki \"{name}\" irudia neurri handian",
     "Open the full size \"{name}\" image" : "Ireki \"{name}\" neurri handian",
-    "There are no photos or videos yet!" : "Ez dago argazki edo bideorik oraindik!",
-    "Add to {destination}" : "Gehitu hona: {destination}",
-    "Open the \"{name}\" sub-directory" : "Ireki \"{name}\" azpi-direktorioa",
-    "Back to {folder}" : "Itzuli {folder} -(e)ra",
+    "Open the \"{name}\" folder" : "Ireki \"{name}\" karpeta",
+    "Go back" : "Atzera",
+    "Back to {folder}" : "Itzuli {folder}(e)ra",
     "Share this folder" : "Partekatu karpeta hau",
+    "Dates" : "Datak",
+    "Jump to specific date in list" : "Joan zerrendako data zehatz batera",
+    "Jump to {date}" : "Joan {date} datara",
+    "Add to {destination}" : "Gehitu hona: {destination}",
+    "There are no photos or videos yet!" : "Ez dago argazki edo bideorik oraindik!",
     "_{years} year ago_::_{years} years ago_" : ["orain dela urte {years}","orain dela {years} urte"],
     "Enable squared photos view" : "Gaitu lauki formako argazki ikuspegia",
-    "Default Photos upload and Albums location" : "Argazkien karga eta albumen kokaleku lehenetsia",
-    "Select the default location for your media" : "Hautatu zure multimediaren kokaleku lehenetsia",
-    "Invalid location selected" : "Kokaleku baliogabea hautatuta",
+    "Delete source directory" : "Ezabatu iturburuko direktorioa",
+    "All folders" : "Karpeta guztiak",
+    "Add folder" : "Gehitu karpeta",
+    "Select a source folder for your media" : "Hautatu iturburu karpeta bat zure multimedia fitxategientzat",
+    "Home" : "Etxea",
+    "Choose default Photos upload and Albums location" : "Aukeratu argazkien igoera eta albumen kokaleku lehenetsia",
+    "Choose a different folder" : "Aukeratu beste karpeta bat",
+    "Select the default upload location for your media" : "Hautatu lehenetsitako kokalekua zure multimedia fitxategiak igotzeko",
     "View" : "Ikusi",
-    "Photos directory" : "Argazkien direktorioa",
+    "Choose the folders from where photos and videos are shown." : "Aukeratu zein karpetatatik erakutsiko diren argazki eta bideoak.",
+    "Upload folder" : "Igo karpeta",
+    "Choose the folder where photos and albums are uploaded to." : "Aukeratu zein karpetatara igoko diren argazki eta albumak.",
     "_%n photo_::_%n photos_" : ["argazki %n","%n argazki"],
+    "Unselect all" : "Desautatu dena",
     "Manage collaborators for this album" : "Kudeatu album honen kolaboratzaileak",
     "Open actions menu" : "Ireki ekintzen menua",
     "Edit album details" : "Editatu albumaren xehetasunak",
@@ -74,7 +87,7 @@ OC.L10N.register(
     "Remove selection from album" : "Kendu hautatutakoak albumetik",
     "This album does not have any photos or videos yet!" : "Album honek ez du argazki edo bideorik oraindik!",
     "Add photos to this album" : "Gehitu argazkiak album honetara ",
-    "Add photos to the album" : "Gehitu argazkiak albumera",
+    "Add photos to {albumName}" : "Gehitu argazkiak {albumName}(e)ra",
     "Manage collaborators" : "Kudeatu kolaboratzaileak",
     "Save collaborators for this album." : "Gorde album honen kolaboratzaileak.",
     "Cover photo for album {albumName}" : "{albumName} albumaren azaleko argazkia",
@@ -82,44 +95,80 @@ OC.L10N.register(
     "This person could not be found" : "Ezin izan da pertsona hori aurkitu",
     "Rename person" : "Berridatzi pertsonaren izena",
     "Merge with different person" : "Bateratu beste pertsona batekin",
-    "Download selected photos" : "Deskargatu hautatutakoak argazkiak",
-    "Favorite" : "Egin gogoko",
+    "Download selected photos" : "Deskargatu hautatutako argazkiak",
     "Remove from favorites" : "Kendu gogokoetatik",
     "Remove person" : "Kendu pertsona",
     "Name of this person" : "Pertsona honen izena",
+    "Save." : "Gorde.",
     "Merge person" : "Bateratu pertsona",
+    "Move to different person" : "Mugitu beste pertsona batera",
+    "_Move photo to a different person_::_Move photos to a different person_" : ["Mugitu argazkia beste pertsona batera","Mugitu argazkiak beste pertsona batera"],
     "_Remove photo from person_::_Remove photos from person_" : ["Kendu argazkia pertsonatik","Kendu argazkiak pertsonatik"],
     "This might take some time depending on the size of your photo library." : "Honek luze jo dezake, zure argazki liburutegiaren tamainaren arabera.",
     "Recognized people will show up here" : "Ezagutu diren pertsonak hemen agertuko dira",
     "This folder does not exist" : "Karpeta hau ez da existitzen",
     "Loading folders …" : "Karpetak kargatzen ...",
     "No photos in here" : "Argazkirik ez hemen",
-    "Shared albums" : "Partekaturiko albumak",
+    "Taken on {date} at {time}" : "{date} egunean {time} orduan ateratakoa",
+    "This place does not have any photos or videos yet!" : "Toki honek ez du argazki edo bideorik oraindik!",
+    "Add photos to this place" : "Gehitu argazkiak leku honetara",
+    "Cover photo for place {placeName}" : "{placeName} tokiaren azaleko argazkia",
+    "There is no place yet!" : "Oraindik ez dago lekurik!",
     "Cover photo for shared album {albumName}." : "{albumName} album partekatuko azaleko argazkia",
     "Back to tags overview" : "Itzuli etiketen ikuspegira",
     "No photos with this tag yet" : "Ez dago etiketa hau duen argazkirik oraindik",
     "No tags yet" : "Etitketarik ez oraindik",
     "Photos with tags will show up here" : "Etiketadun argazkiak hemen erakutsiko dira",
-    "Popular tags" : "Etiketa ospetsuak",
+    "Popular tags" : "Etiketa ohikoak",
     "Add" : "Gehitu",
-    "Create a new album" : "Sortu album berri bat",
-    "Add selection to an album" : "Gehitu hautatutakoak album batera",
     "Add to album" : "Gehitu albumera",
     "Delete selection" : "Ezabatu hautatutakoak",
+    "No photos or videos in here" : "Ez dago argazki edo bideorik hemen",
+    "Unassigned faces" : "Esleitu gabeko aurpegiak",
+    "_%n photos_::_%n photos_" : ["argazki %n","%n argazki"],
+    "Failed to fetch collection." : "Ezin izan da bilduma eskuratu.",
+    "Failed to fetch collections list." : "Ezin izan da bildumen zerrenda eskuratu.",
     "Failed to fetch faces list." : "Ezin izan da aurpegien zerrenda eskuratu.",
     "All your media" : "Zure multimedia guztia",
+    "Album {title}" : "{title} albuma",
+    "Shared Albums" : "Partekatutako albumak",
+    "Shared album {title}" : "{title} partekatutako albuma",
+    "Public album {title}" : "{title} album publikoa",
     "Tagged photos" : "Etiketaturiko argazkiak",
-    "Failed to create {albumName}." : "Ezin izan da {albumName} sortu.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Ezin izan da {currentAlbumName} berrizendatu {newAlbumName} gisa.",
+    "Tagged photo {title}" : "{title} etiketaturiko argazkia",
+    "{title}'s face" : "{title}(r)en aurpegia",
+    "{startDate} to {endDate}" : "{startDate} - {endDate}",
+    "Details" : "Xehetasunak",
     "Failed to rename {oldName} to {faceName}." : "Ezin izan da {oldName} berrizendatu {faceName} gisa.",
     "Failed to delete {faceName}." : "Ezin izan da  {faceName} ezabatu.",
     "Failed to delete {fileId}." : "{fileId} ezabatzeak huts egin du.",
     "Failed to delete {fileName}." : "{fileName} ezabatzeak huts egin du.",
-    "Failed to set favorite state for {fileId}." : "Ezin izan da ezarri gogoko egoera {fileId}rako.",
-    "Failed to set favorite state for {fileName}." : "Ezin izan da ezarri gogoko egoera {fileName}rako.",
-    "Your photos" : "Zure argazkiak",
-    "Your videos" : "Zure bideoak",
-    "Your folders" : "Zure karpetak",
-    "Settings" : "Ezarpenak"
+    "Failed to set favorite state for {fileId}." : "Ezin izan da ezarri gogoko egoera {fileId}(r)entzat.",
+    "Failed to set favorite state for {fileName}." : "Ezin izan da ezarri gogoko egoera {fileName}(r)entzat.",
+    "Could not load photos folder" : "Ezin izan da argazkien karpeta kargatu",
+    "Go back to the previous view." : "Itzuli aurreko ikuspegira.",
+    "Go to the add collaborators view." : "Joan kolaboratzaileak gehitzeko ikuspegira.",
+    "Create the album." : "Sortu albuma.",
+    "Back to the new album form." : "Itzuli album berrien formulariora",
+    "_Share with %n user_::_Share with %n users_" : ["Partekatu %n erabiltzailearekin","Partekatu %n erabiltzaileekin"],
+    "Search for collaborators" : "Bilatu kolaboratzaileak",
+    "Add {collaboratorLabel} to the collaborators list" : "Gehitu {collaboratorLabel} kolaboratzaile zerrendara",
+    "No collaborators available" : "Ez dago kolaboratzailerik eskuragarri",
+    "Failed to fetch album." : "Ezin izan da albuma lortu.",
+    "The file is in the favorites" : "Fitxategia gogokoetan dago",
+    "Open the \"{name}\" sub-directory" : "Ireki \"{name}\" azpi-direktorioa",
+    "Default Photos upload and Albums location" : "Argazkien karga eta albumen kokaleku lehenetsia",
+    "Select the default location for your media" : "Hautatu zure multimediaren kokaleku lehenetsia",
+    "Invalid location selected" : "Kokaleku baliogabea hautatu da",
+    "Photos directory" : "Argazkien direktorioa",
+    "Add photos to the album" : "Gehitu argazkiak albumera",
+    "Failed to fetch albums list." : "Ezin izan da album zerrenda eskuratu.",
+    "Shared albums" : "Partekaturiko albumak",
+    "Create a new album" : "Sortu album berri bat",
+    "Add selection to an album" : "Gehitu hautatutakoak album batera",
+    "Failed to create {albumName}." : "Ezin izan da {albumName} sortu.",
+    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Ezin izan da {currentAlbumName} berrizendatu {newAlbumName} gisa.",
+    "Media folder" : "Multimedia karpeta",
+    "The source folder does not exists" : "Iturburuko karpeta ez da existitzen"
 },
 "nplurals=2; plural=(n != 1);");
