@@ -3,73 +3,84 @@ OC.L10N.register(
     {
     "Public link" : "Herkese açık bağlantı",
     "Photos" : "Fotoğraflar",
+    "On This Day" : "Şu günde",
     "Your memories under your control" : "Anılarınızın denetimi sizde",
     "All media" : "Tüm ortamlar",
     "Videos" : "Görüntüler",
     "Albums" : "Albümler",
-    "Collaborative albums" : "İşbirliği albümleri",
+    "Collaborative albums" : "İş birlikli albümler",
     "People" : "Kişiler",
     "Folders" : "Klasörler",
     "Favorites" : "Sık kullanılanlar",
     "On this day" : "Bugün",
     "Shared with you" : "Sizinle paylaşılanlar",
     "Tags" : "Etiketler",
-    "Locations" : "Konumlar",
+    "Places" : "Yerler",
+    "Map" : "Harita",
     "Photos settings" : "Fotoğraflar ayarları",
     "Mark selection as favorite" : "Seçilmişleri sık kullanılanlara ekle",
     "Add selection to favorites" : "Seçilmişleri sık kullanılanlara ekle",
     "Remove selection from favorites" : "Seçilmişleri sık kullanılanlardan çıkar",
     "Name of the album" : "Albümün adı",
     "Location of the album" : "Albümün konumu",
-    "Go back to the previous view." : "Önceki görünüme geri dön.",
     "Back" : "Geri",
-    "Go to the add collaborators view." : "Katılımcı ekleme görünümüne gider.",
     "Add collaborators" : "Katılımcı ekle",
-    "Save." : "Kaydeder.",
-    "Create the album." : "Albüm ekler.",
     "Save" : "Kaydet",
     "Create album" : "Albüm ekle",
-    "Back to the new album form." : "Albüm ekleme formuna geri döner.",
     "Add to Album" : "Albüme ekle",
     "Add selection to album {albumName}" : "Seçilmişleri {albumName} albümüne ekle",
+    "Shared by" : "Paylaşan",
     "Create a new album." : "Yeni bir albüm ekler.",
     "Create new album" : "Yeni albüm ekle",
     "New album" : "Yeni albüm",
     "_%n item_::_%n photos and videos_" : ["%n öge","%n fotoğraf ve görüntü"],
-    "_Share with %n user_::_Share with %n users_" : ["%n kullanıcı ile paylaş","%n kullanıcı ile paylaş"],
     "Add people or groups who can edit your album" : "Albümünüzü düzenleyebilecek kişi ya da grupları ekleyin",
-    "Search for collaborators" : "Katılımcı arama",
     "Search people or groups" : "Kişi ya da grup arama",
-    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesine ekle",
-    "No collaborators available" : "Seçilebilecek bir katılımcı yok",
+    "No recommendations. Start typing." : "Herhangi bir öneri yok. Yazmaya başlayın.",
+    "Group" : "Grup",
     "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesinden çıkar",
     "Copy the public link" : "Herkese açık bağlantıyı kopyala",
     "Public link copied!" : "Herkese açık bağlantı kopyalandı!",
     "Copy public link" : "Herkese açık bağlantıyı kopyala",
     "Delete the public link" : "Herkese açık bağlantıyı sil",
+    "Create public link share" : "Herkese açık paylaşılan bağlantı oluştur",
     "Share via public link" : "Herkese açık bağlantı ile paylaş",
     "Failed to fetch collaborators list." : "Katılımcıların listesi alınamadı.",
-    "Failed to fetch album." : "Albüm alınamadı",
     "Failed to update album." : "Albüm güncellenemedi",
     "This collection does not exist" : "Derleme bulunamadı",
     "An error occurred" : "Bir sorun çıktı",
-    "_%n photos_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
+    "No picture for this day" : "Bu günde çekilmiş bir fotoğraf yok",
+    "Picture taken on this day will show up here." : "Bu gün çekilmiş fotoğraflar burada görüntülenir.",
+    "More photos from this day" : "Bu gün çekilmiş diğer fotoğraflar",
+    "_%n unassigned photo_::_%n unassigned photos_" : ["%n ilişkilendirilmemiş fotoğraf","%n ilişkilendirilmemiş fotoğraf"],
+    "Favorite" : "Sık kullanılanlara ekle",
     "Select image {imageName}" : "{imageName} görselini seç",
-    "The file is in the favorites" : "Bu dosya sık kullanılar içinde",
-    "Open the full size \"{name}\" image" : "\"{name}\" fotoğrafını tam boyutunda aç",
-    "There are no photos or videos yet!" : "Henüz bir fotoğraf ya da görüntü yok!",
-    "Add to {destination}" : "{destination} üzerine ekle",
-    "Open the \"{name}\" sub-directory" : "\"{name}\" alt klasörünü aç",
+    "Favorite image, open the full size \"{name}\" image" : "Görseli öne çıkar, \"{name}\" görselini tam boyutunda aç",
+    "Open the full size \"{name}\" image" : "\"{name}\" görselini tam boyutunda aç",
+    "Open the \"{name}\" folder" : "\"{name}\" klasörünü aç",
+    "Go back" : "Geri dön",
     "Back to {folder}" : "{folder} klasörüne geri dön",
     "Share this folder" : "Bu klasörü paylaş",
+    "Dates" : "Tarihler",
+    "Jump to specific date in list" : "Listede belirli bir tarihe git",
+    "Jump to {date}" : "{date} tarihine git",
+    "Add to {destination}" : "{destination} üzerine ekle",
+    "There are no photos or videos yet!" : "Henüz bir fotoğraf ya da görüntü yok!",
     "_{years} year ago_::_{years} years ago_" : ["{years} yıl önce","{years} yıl önce"],
     "Enable squared photos view" : "Kare fotoğraf görünümü kullanılsın",
-    "Default Photos upload and Albums location" : "Varsayılan Fotoğraflar yükleme ve Albümler konumu",
-    "Select the default location for your media" : "Ortamlarınızın varsayılan konumunu seçin",
-    "Invalid location selected" : "Seçilen konum geçersiz",
+    "Delete source directory" : "Kaynak klasörü sil",
+    "All folders" : "Tüm klasörler",
+    "Select a source folder for your media" : "Ortamlarınız için bir kaynak klasör seçin",
+    "Home" : "Giriş",
+    "Choose default Photos upload and Albums location" : "Varsayılan Fotoğraflar yüklemesini ve Albümlerin konumu seçin",
+    "Choose a different folder" : "Farklı bir klasör seçin",
+    "Select the default upload location for your media" : "Ortamlarınız için varsayılan yükleme konumunu seçin",
     "View" : "Görüntüle",
-    "Photos directory" : "Fotoğraflar klasörü",
+    "Choose the folders from where photos and videos are shown." : "Fotoğraf ve videoların görüntüleneceği klasörleri seçin.",
+    "Upload folder" : "Yükleme klasörü",
+    "Choose the folder where photos and albums are uploaded to." : "Fotoğraf ve albümlerin yükleneceği klasörü seçin.",
     "_%n photo_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
+    "Unselect all" : "Tümünü bırak",
     "Manage collaborators for this album" : "Bu albümün katılımcılarını yönet",
     "Open actions menu" : "İşlemler menüsünü aç",
     "Edit album details" : "Albüm ayrıntılarını düzenle",
@@ -79,7 +90,7 @@ OC.L10N.register(
     "Remove selection from album" : "Seçilmişleri albümden kaldır",
     "This album does not have any photos or videos yet!" : "Bu albümde henüz bir fotoğraf ya da görüntü yok!",
     "Add photos to this album" : "Bu albüme fotoğraflar ekle",
-    "Add photos to the album" : "Albüme fotoğraflar ekle",
+    "Add photos to {albumName}" : "{albumName} albümüne fotoğraflar ekle",
     "Manage collaborators" : "Katılımcı yönetimi",
     "Save collaborators for this album." : "Bu albümün katılımcılarını kaydet.",
     "Cover photo for album {albumName}" : "{albumName} albümünün kapak görseli",
@@ -88,19 +99,24 @@ OC.L10N.register(
     "Rename person" : "Kişiyi yeniden adlandır",
     "Merge with different person" : "Başka bir kişi ile birleştir",
     "Download selected photos" : "Seçilmiş fotoğrafları indir",
-    "Favorite" : "Sık kullanılanlara ekle",
     "Remove from favorites" : "Sık kullanılanlardan çıkar",
     "Remove person" : "Kişiyi sil",
     "Name of this person" : "Bu kişinin adı",
+    "Save." : "Kaydeder.",
     "Merge person" : "Kişiyi birleştir",
+    "Move to different person" : "Farklı bir kişiye aktar",
+    "_Move photo to a different person_::_Move photos to a different person_" : ["Fotoğrafı başka bir kişiye aktar","Fotoğrafları başka bir kişiye aktar"],
     "_Remove photo from person_::_Remove photos from person_" : ["Fotoğrafı kişiden kaldır","Fotoğrafları kişiden kaldır"],
     "This might take some time depending on the size of your photo library." : "Bu işlemin tamamlanması fotoğraf arşivinizin boyutuna bağlı olarak biraz zaman alabilir.",
     "Recognized people will show up here" : "Tanınan kişiler burada görüntülenir",
     "This folder does not exist" : "Bu klasör bulunamadı",
     "Loading folders …" : "Klasörler yükleniyor…",
     "No photos in here" : "Burada herhangi bir fotoğraf yok",
-    "Failed to fetch albums list." : "Albümlerin listesi alınamadı.",
-    "Shared albums" : "Paylaşılmış albümler",
+    "Taken on {date} at {time}" : "{date} tarihinde {time} saatinde çekilmiş",
+    "This place does not have any photos or videos yet!" : "Bu yerde henüz bir fotoğraf ya da görüntü yok!",
+    "Add photos to this place" : "Bu yere fotoğraflar ekle",
+    "Cover photo for place {placeName}" : "{placeName} yerinin kapak görseli",
+    "There is no place yet!" : "Henüz bir yer yok!",
     "Cover photo for shared album {albumName}." : "{albumName} paylaşılmış albümünün kapak görseli.",
     "Back to tags overview" : "Etiket özetine geri dön",
     "No photos with this tag yet" : "Henüz bu şekilde etiketlenmiş bir fotoğraf yok",
@@ -108,24 +124,55 @@ OC.L10N.register(
     "Photos with tags will show up here" : "Etiketlenmiş fotoğraflar burada görüntülenir",
     "Popular tags" : "Sık kullanılan etiketler",
     "Add" : "Ekle",
-    "Create a new album" : "Yeni bir albüm ekle",
-    "Add selection to an album" : "Seçilmişleri bir albüme ekle",
     "Add to album" : "Albüme ekle",
     "Delete selection" : "Seçilmişleri sil",
+    "No photos or videos in here" : "Henüz bir fotoğraf ya da görüntü yok",
+    "Unassigned faces" : "İlişkilendirilmemiş yüzler",
+    "_%n photos_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
+    "Failed to fetch collection." : "Derleme alınamadı",
+    "Failed to fetch collections list." : "Derleme listesi alınamadı.",
     "Failed to fetch faces list." : "Yüzlerin listesi alınamadı.",
     "All your media" : "Tüm ortamlarınız",
+    "Album {title}" : "{title} albümü",
+    "Shared Albums" : "Paylaşılmış albümler",
+    "Shared album {title}" : "{title} paylaşılmış albümü",
+    "Public album {title}" : "{title} herkese açık albüm",
     "Tagged photos" : "Etiketlenmiş fotoğraflar",
-    "Failed to create {albumName}." : "{albumName} albümü oluşturulamadı.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "{currentAlbumName} albümünün adı {newAlbumName} olarak değiştirilemedi.",
+    "Tagged photo {title}" : "{title} etiketlenmiş fotoğraf",
+    "{title}'s face" : "{title} yüzü",
+    "{startDate} to {endDate}" : "{startDate} - {endDate}",
+    "Details" : "Ayrıntılar",
     "Failed to rename {oldName} to {faceName}." : "{oldName} adı {faceName} olarak değiştirilemedi.",
     "Failed to delete {faceName}." : "{faceName} silinemedi.",
     "Failed to delete {fileId}." : "{fileId} silinemedi.",
     "Failed to delete {fileName}." : "{fileName} silinemedi.",
     "Failed to set favorite state for {fileId}." : "{fileId} için sık kullanılan durumu ayarlanamadı.",
     "Failed to set favorite state for {fileName}." : "{fileName} için sık kullanılan durumu ayarlanamadı.",
-    "Your photos" : "Fotoğraflarınız",
-    "Your videos" : "Görüntüleriniz",
-    "Your folders" : "Klasörleriniz",
-    "Settings" : "Ayarlar"
+    "Could not load photos folder" : "Fotoğraflar klasörü yüklenemedi",
+    "Go back to the previous view." : "Önceki görünüme geri dön.",
+    "Go to the add collaborators view." : "Katılımcı ekleme görünümüne gider.",
+    "Create the album." : "Albüm ekler.",
+    "Back to the new album form." : "Albüm ekleme formuna geri döner.",
+    "_Share with %n user_::_Share with %n users_" : ["%n kullanıcı ile paylaş","%n kullanıcı ile paylaş"],
+    "Search for collaborators" : "Katılımcı ara",
+    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesine ekle",
+    "No collaborators available" : "Seçilebilecek bir katılımcı yok",
+    "Failed to fetch album." : "Albüm alınamadı",
+    "The file is in the favorites" : "Bu dosya sık kullanılar içinde",
+    "Open the \"{name}\" sub-directory" : "\"{name}\" alt klasörünü aç",
+    "Default Photos upload and Albums location" : "Varsayılan Fotoğraflar yükleme ve Albümler konumu",
+    "Select the default location for your media" : "Ortamlarınızın varsayılan konumunu seçin",
+    "Invalid location selected" : "Seçilen konum geçersiz",
+    "Photos directory" : "Fotoğraflar klasörü",
+    "Add photos to the album" : "Albüme fotoğraflar ekle",
+    "Failed to fetch albums list." : "Albümlerin listesi alınamadı.",
+    "Shared albums" : "Paylaşılmış albümler",
+    "Create a new album" : "Yeni bir albüm ekle",
+    "Add selection to an album" : "Seçilmişleri bir albüme ekle",
+    "Failed to create {albumName}." : "{albumName} albümü oluşturulamadı.",
+    "Failed to rename {currentAlbumName} to {newAlbumName}." : "{currentAlbumName} albümünün adı {newAlbumName} olarak değiştirilemedi.",
+    "Choose a Photos source for the timelines" : "Zaman akışları için bir fotoğraf kaynağı seçin",
+    "Media folder" : "Ortam klasörü",
+    "The source folder does not exists" : "Kaynak klasör bulunamadı"
 },
 "nplurals=2; plural=(n > 1);");
