@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Public link" : "Публічне посилання",
     "Photos" : "Світлини",
+    "On This Day" : "Цього дня",
     "Your memories under your control" : "Ваші спогади під особистим контролем",
     "All media" : "Усі зображення та відео",
     "Videos" : "Відео",
@@ -48,6 +49,9 @@ OC.L10N.register(
     "Failed to update album." : "Не вдалося оновити альбом.",
     "This collection does not exist" : "Ця колекція не існує",
     "An error occurred" : "Виникла помилка",
+    "No picture for this day" : "Відсутні зображення цього дня",
+    "Picture taken on this day will show up here." : "Зображення, які було отримано цього дня, будуть показані тут.",
+    "More photos from this day" : "Більше світлин з цього дня",
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n неідентифікована світлина","%n неідентифіковані світлини","%n неідентифікованих світлин","%n неідентифікованих світлин"],
     "Favorite" : "До улюблених",
     "Select image {imageName}" : "Виберіть зображення {imageName}",
@@ -66,13 +70,15 @@ OC.L10N.register(
     "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
     "Delete source directory" : "Вилучити каталог джерела",
     "All folders" : "Усі каталоги",
-    "Choose a different folder" : "Виберіть інший каталог",
+    "Add a Photos source for the timelines" : "Додати джерело світлин до хронології",
+    "Add folder" : "Додати теку",
     "Select a source folder for your media" : "Виберіть каталог джерела для ваших світлин чи відеозаписів",
     "Home" : "Домівка",
     "Choose default Photos upload and Albums location" : "Виберіть типове розташування для завантаження світлин та альбомів",
+    "Choose a different folder" : "Виберіть інший каталог",
     "Select the default upload location for your media" : "Виберіть типове розташування для завантаження ваших світлин чи відеозаписів",
     "View" : "Перегляд",
-    "Media folder" : "Каталог для світлин чи відеозаписів",
+    "Media folders" : "Каталоги з мультимедійним вмістом",
     "Choose the folders from where photos and videos are shown." : "Виберіть каталоги, з яких показувати світлини та відеозаписи.",
     "Upload folder" : "Завантажити каталог",
     "Choose the folder where photos and albums are uploaded to." : "Виберіть каталог, до якого завантажувати світлини та альбоми.",
@@ -103,7 +109,7 @@ OC.L10N.register(
     "Merge person" : "Об’єднати особу",
     "Move to different person" : "Перемістити до іншої особи",
     "_Move photo to a different person_::_Move photos to a different person_" : ["Передати фотографії іншому користувачу","Передати фотографії іншим користувачам","Передати фотографії іншим користувачам","Передати фотографії іншим користувачам"],
-    "_Remove photo from person_::_Remove photos from person_" : ["Видалити фото з особи","Видалити фотографії з особи","Видалити фотографії з особи","Вилучити світлини особи"],
+    "_Remove photo from person_::_Remove photos from person_" : ["Вилучити світлину особи","Вилучити світлини особи","Вилучити світлини особи","Вилучити світлини особи"],
     "This might take some time depending on the size of your photo library." : "Це може зайняти деякий час залежно від розміру вашої бібліотеки фотографій.",
     "Recognized people will show up here" : "Тут відображатимуться розпізнані люди",
     "This folder does not exist" : "Цей каталог не існує",
@@ -120,7 +126,7 @@ OC.L10N.register(
     "No tags yet" : "Ще немає міток",
     "Photos with tags will show up here" : "Світлини з мітками буде показано тут",
     "Popular tags" : "Популярні мітки",
-    "The source folder does not exists" : "Каталог джерела відсутній",
+    "One of the source folders does not exists" : "Один з каталогів джерел відсутній",
     "Add" : "Додати",
     "Add to album" : "Додати в альбом",
     "Delete selection" : "Вилучити виділення",
@@ -168,6 +174,9 @@ OC.L10N.register(
     "Create a new album" : "Створіть новий альбом",
     "Add selection to an album" : "Додайте виділене в альбом",
     "Failed to create {albumName}." : "Не вдалося створити {albumName}.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Не вдалося перейменувати {currentAlbumName} на {newAlbumName}."
+    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Не вдалося перейменувати {currentAlbumName} на {newAlbumName}.",
+    "Choose a Photos source for the timelines" : "Виберіть джерело світлин для хронології",
+    "Media folder" : "Каталог для світлин чи відеозаписів",
+    "The source folder does not exists" : "Каталог джерела відсутній"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
