@@ -133,7 +133,7 @@ OC.L10N.register(
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "In der Datenbank fehlen einige Primärschlüssel. Aufgrund der Tatsache, dass das Hinzufügen von Primärschlüsseln bei großen Tabellen einige Zeit dauern konnte, wurden sie nicht automatisch hinzugefügt. Durch Ausführen von \"occ db:add-missing-primary-keys\" können diese fehlenden Primärschlüssel manuell hinzugefügt werden, während die Instanz weiter läuft.",
     "Database pending bigint migrations" : "Datenbank mit ausstehenden Bigint-Migrationen",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Bei einigen Spalten in der Datenbank fehlt eine Konvertierung in Big Int. Da die Änderung der Spaltentypen bei großen Tabellen einige Zeit in Anspruch nehmen kann, erfolgt die Änderung nicht automatisch. Durch Ausführen von \"occ db:convert-filecache-bigint“ können diese ausstehenden Änderungen manuell durchgeführt werden. Bei der Durchführung muss die Instanz offline sein.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Diese Instanz wird im Debug-Modus ausgeführt. Aktivieren Sie dies nur für die lokale Entwicklung und nicht in Produktionsumgebungen.",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Diese Instanz wird im Debug-Modus ausgeführt. Aktiviere dies nur für die lokale Entwicklung und nicht in Produktionsumgebungen.",
     "Default phone region" : "Standard-Telefonregion",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Für deine Installation ist keine Standard-Telefonregion festgelegt. Dies ist erforderlich, um Telefonnummern in den Profileinstellungen ohne Ländercode überprüfen zu können. Um Nummern ohne Ländervorwahl zuzulassen, füge bitte „default_phone_region“ mit dem entsprechenden ISO 3166-1-Code der Region zu deiner Konfigurationsdatei hinzu.",
     "Email test" : "E-Mail-Test",
@@ -173,7 +173,6 @@ OC.L10N.register(
     "This instance is missing some required PHP modules. It is required to install them: %s." : "Dieser Instanz fehlen einige erforderliche PHP-Module. Folgende Module müssen installiert sein:%s .",
     "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Das PHP-OPcache-Modul ist nicht geladen. Für eine bessere Leistung empfiehlt es sich, das Modul in deiner PHP-Installation zu laden.",
     "PHP version" : "PHP-Version",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Du verwendest derzeit PHP %s. PHP 8.0 ist ab Nextcloud 27 veraltet. Nextcloud 28 erfordert mindestens PHP 8.1. Bitte aktualisiere so schnell wie möglich auf eine der offiziell unterstützten PHP-Versionen der PHP Gruppe.",
     "You are currently running PHP %s." : "Du benutzt aktuell PHP %s.",
     "PHP \"output_buffering\" option" : "PHP-Option \"output_buffering\"",
     "PHP configuration option \"output_buffering\" must be disabled" : "Die PHP-Konfigurationsoption \"output_buffering“ muss deaktiviert sein",
@@ -438,7 +437,7 @@ OC.L10N.register(
     "Groups (required)" : "Gruppen (erforderlich)",
     "Set user groups" : "Benutzergruppen einstellen",
     "Administered groups" : "Administrierte Gruppen",
-    "Set user as admin for …" : "Benutzer als Administratior setzen für …",
+    "Set user as admin for …" : "Benutzer als Administrator setzen für …",
     "Quota" : "Kontingent",
     "Set user quota" : "Benutzerkontingent einstellen",
     "Language" : "Sprache",
@@ -494,9 +493,7 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Die Anmeldung ohne Passwort erfordert eine sichere Verbindung.",
     "Add WebAuthn device" : "WebAuthn-Gerät hinzufügen",
     "Please authorize your WebAuthn device." : "Bitte autorisiere dein WebAuthn-Gerät.",
-    "Name your device" : "Gerät benennen",
     "Adding your device …" : "Füge dein Gerät hinzu …",
-    "Server error while trying to add WebAuthn device" : "Server-Fehler beim Versuch ein WebAuthn-Gerät hinzuzufügen",
     "Server error while trying to complete WebAuthn device registration" : "Server-Fehler beim Versuch die WebAuthn-Geräte-Registrierung abzuschließen",
     "Unnamed device" : "Unbenanntes Gerät",
     "Passwordless Authentication" : "Authentifizierung ohne Passwort",
@@ -555,8 +552,9 @@ OC.L10N.register(
     "Account documentation" : "Kontodokumentation",
     "Administration documentation" : "Administrationsdokumentation",
     "Forum" : "Forum",
-    "Nextcloud help resources" : "Nextcloud-Hilferessourcen",
     "General documentation" : "Allgemeine Dokumentation",
+    "Legal notice" : "Impressum",
+    "Privacy policy" : "Datenschutzerklärung ",
     "None/STARTTLS" : "Keine/STARTTLS",
     "SSL" : "SSL",
     "Open documentation" : "Dokumentation öffnen",
@@ -612,6 +610,7 @@ OC.L10N.register(
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Ein Hintergrundjob, der nach vom Benutzer importierten SSL-Zertifikaten sucht, läuft noch. Bitte versuche es später erneut.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Es sind einige vom Benutzer importierte SSL-Zertifikate vorhanden, die von Nextcloud 21 nicht mehr verwendet werden. Du kannst über den Befehl \"occ security:certificates:import\" in der Befehlszeile importiert werden. Ihre Pfade innerhalb des Datenverzeichnisses werden unten angezeigt.",
     "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Es wurden ungültige UUIDs von LDAP-Benutzern oder -Gruppen gefunden. Bitte überprüfe deine „UUID-Erkennung überschreiben“-Einstellungen im Expertenteil der LDAP-Konfiguration und verwende „occ ldap:update-uuid“, um sie zu aktualisieren.",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da deine Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte führe sie manuell aus, indem du occ dav:sync-system-addressbook aufrufst.",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Zwei-Faktor-Authentifizierung kann für alle Benutzer und Gruppen erzwungen werden. Dann können Benutzer, für die keine Zwei-Faktor-Authentifizierung eingerichtet ist, sich nicht am System anmelden.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Bei der Auswahl/Abwahl von Gruppen wird folgende Logik verwendet, um festzustellen, ob ein Benutzer 2FA verwenden muss: Wenn keine Gruppe ausgewählt ist, dann wird 2FA für alle Benutzer aktiviert, außer für Mitglieder der ausgenommenen Gruppen. Sind Gruppen ausgewählt, so wird 2FA für alle Mitglieder dieser Gruppen aktiviert. Ist ein Benutzer Mitglied der ausgewählten und ausgenommenen Gruppe, so hat die Auswahl Vorrang und 2FA wird aktiviert. ",
     "Enable all" : "Alle aktivieren",
@@ -637,27 +636,30 @@ OC.L10N.register(
     "You are about to remove the group {group}. The users will NOT be deleted." : "Du bist dabei die Gruppe {group} zu löschen. Die Benutzer werden NICHT gelöscht.",
     "Please confirm the group removal " : "Bitte die Löschung der Gruppe bestätigen",
     "Your profile information" : "Ihre Profilinformation",
-    "Choose profile picture from files" : "Profilbild aus Dateien auswählen",
-    "png or jpg, max. 20 MB" : "png oder jpg, max. 20 MB",
     "Your email address" : "Deine E-Mail-Adresse",
     "Additional emails" : "Zusätzliche E-Mail-Adressen ",
-    "Your location" : "Dein Ort",
     "Enable Profile" : "Profil aktivieren",
     "Your Twitter handle" : "Dein X-Handle",
     "You do not have permissions to see the details of this user" : "Du hast keine Berechtigung, um auf die Details dieses Benutzers zu sehen",
+    "Edit display name" : "Anzeigename bearbeiten",
     "Add new password" : "Neues Passwort hinzufügen",
     "Add new email address" : "Neue E-Mail-Adresse hinzufügen",
     "Set user as admin for" : "Benutzer als Administrator setzen für",
     "Select user quota" : "Kontingent auswählen",
+    "Select manager" : "Manager auswählen",
     "Toggle user actions menu" : "Menü für Benutzeraktionen umschalten",
     "Delete user" : "Benutzer löschen",
     "Wipe all devices" : "Alle Geräte löschen",
     "Disable user" : "Benutzer deaktivieren",
     "Enable user" : "Benutzer aktivieren",
     "Edit User" : "Benutzer bearbeiten",
+    "User's table" : "Benutzertabelle",
     "Will be autogenerated" : "Wird automatisch erzeugt",
+    "Select user manager" : "Benutzermanager wählen",
     "Add a new user" : "Neuen Benutzer hinzufügen",
     "No users in here" : "Keine Benutzer vorhanden",
+    "Name your device" : "Gerät benennen",
+    "Server error while trying to add WebAuthn device" : "Server-Fehler beim Versuch ein WebAuthn-Gerät hinzuzufügen",
     "{license}-licensed" : "{license}-Lizenziert",
     "by {author}\n{license}" : "von {author}\n{license}",
     "Enter group name" : "Gruppenname eingeben",
@@ -670,7 +672,7 @@ OC.L10N.register(
     "Send email to new user" : "E-Mail an neuen Benutzer senden",
     "Not saved" : "Nicht gespeichert",
     "Twitter" : "X",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Nicht verfügbar, da das Federation für dein Konto dekativiert ist. Wende dich an deinen Administratior, wenn du Fragen hast.",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Nicht verfügbar, da Federation für dein Konto deaktiviert ist. Wende dich an deinen Administrator, wenn du Fragen hast.",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nicht verfügbar, da die Veröffentlichung benutzerspezifischer Daten auf dem Lookup-Server nicht zulässig ist. Wende dich bei Fragen an deinen Systemadministrator",
     "Show to logged in users only" : "Nur für angemeldete Benutzer sichtbar",
     "Enable untested app" : "Ungetestete App aktivieren",
@@ -682,15 +684,8 @@ OC.L10N.register(
     "Exclude groups from creating link shares:" : "Gruppen von der Erstellung von Link-Freigaben ausschließen:",
     "Exclude groups from sharing" : "Gruppen von Freigaben ausschließen",
     "These groups will still be able to receive shares, but not to initiate them." : "Diese Gruppen können weiterhin Freigaben empfangen, aber selbst keine mehr initiieren.",
-    "Allow username autocompletion in share dialog" : "Automatische Vervollständigung der Benutzernamen im Teilen-Dialog erlauben",
-    "Allow username autocompletion to users within the same groups" : "Automatische Vervollständigung der Benutzernamen auf Benutzer innerhalb der gleichen Gruppen erlauben",
-    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da deine Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte führe sie manuell aus, indem du occ dav:sync-system-addressbook aufrufst.",
-    "Edit display name" : "Anzeigename bearbeiten",
-    "Select manager" : "Manager auswählen",
-    "User's table" : "Benutzertabelle",
-    "Select user manager" : "Benutzermanager wählen",
     "Old user imported certificates" : "Alte vom Benutzer importierte Zertifikate",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "In dieser Instanz fehlen einige empfohlene PHP-Module. Für eine verbesserte Leistung und bessere Kompatibilität wird dringend empfohlen, sie zu installieren: %s.",
+    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Du verwendest derzeit PHP %s. PHP 8.0 ist ab Nextcloud 27 veraltet. Nextcloud 28 erfordert mindestens PHP 8.1. Bitte aktualisiere so schnell wie möglich auf eine der offiziell unterstützten PHP-Versionen der PHP Gruppe.",
     "Rating: {score}/10" : "Bewertung: {score}/10",
     "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Du bist dabei die Gruppe \"{group}\" zu löschen. Die Benutzer werden NICHT gelöscht.",
     "No users" : "Keine Benutzer",
@@ -701,6 +696,7 @@ OC.L10N.register(
     "Send welcome email to new users" : "Begrüßungs-E-Mail an neue Benutzer senden",
     "User management" : "Benutzerverwaltung",
     "Creating group …" : "Erstelle Gruppe …",
-    "User group: {group}" : "Benutzergruppe: {group}"
+    "User group: {group}" : "Benutzergruppe: {group}",
+    "Nextcloud help resources" : "Nextcloud-Hilferessourcen"
 },
 "nplurals=2; plural=(n != 1);");
