@@ -1,16 +1,17 @@
 OC.L10N.register(
     "text",
     {
+    "Translate" : "Орчуулга",
     "Guest" : "Зочин",
     "Saved" : "Хадгалах",
-    "Translate" : "Орчуулга",
+    "Cancel" : "Цуцлах",
+    "URL" : "URL",
     "to" : "Дуусах нь",
     "Replace" : "Солих",
+    "Edit" : "засварлах",
     "Source code" : "эх үүсвэр талын код",
-    "Unsupported image type" : "Дэмжигдэхгүй зургийн төрөл байна",
     "Undo" : "буцах",
     "Info" : "Info",
-    "Warning" : "Warning",
-    "Edit" : "засварлах"
+    "Warning" : "Warning"
 },
 "nplurals=2; plural=(n != 1);");
