@@ -12,6 +12,9 @@ OC.L10N.register(
     "The given color is invalid" : "The given colour is invalid",
     "Disable-user-theming should be true or false" : "Disable-user-theming should be true or false",
     "Saved" : "Saved",
+    "Invalid app given" : "Invalid app given",
+    "Invalid type for setting \"defaultApp\" given" : "Invalid type for setting \"defaultApp\" given",
+    "Invalid setting key" : "Invalid setting key",
     "The file was uploaded" : "The file was uploaded",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
@@ -21,11 +24,12 @@ OC.L10N.register(
     "Could not write file to disk" : "Could not write file to disk",
     "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
     "No file uploaded" : "No file uploaded",
-    "Failed to clean up the old administration theming images folder" : "Failed to clean up the old administration theming images folder",
-    "Failed to clean up the old administration image folder" : "Failed to clean up the old administration image folder",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "You are already using a custom theme. Theming app settings might be overwritten by that.",
     "Theming" : "Theming",
     "Appearance and accessibility" : "Appearance and accessibility",
+    "PHP Imagick module" : "PHP Imagick module",
+    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module.",
+    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it.",
     "Dark theme with high contrast mode" : "Dark theme with high contrast mode",
     "Enable dark high contrast mode" : "Enable dark high contrast mode",
     "Similar to the high contrast mode, but with dark colours." : "Similar to the high contrast mode, but with dark colours.",
@@ -68,40 +72,44 @@ OC.L10N.register(
     "User settings" : "User settings",
     "Disable user theming" : "Disable user theming",
     "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on.",
-    "Keyboard shortcuts" : "Keyboard shortcuts",
-    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
-    "Disable all keyboard shortcuts" : "Disable all keyboard shortcuts",
+    "Appearance and accessibility settings" : "Appearance and accessibility settings",
     "Background" : "Background",
     "Customization has been disabled by your administrator" : "Customization has been disabled by your administrator",
     "Set a custom background" : "Set a custom background",
+    "Keyboard shortcuts" : "Keyboard shortcuts",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
+    "Disable all keyboard shortcuts" : "Disable all keyboard shortcuts",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level.",
     "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!",
+    "Current selected app: {app}, position {position} of {total}" : "Current selected app: {app}, position {position} of {total}",
+    "Move up" : "Move up",
+    "Move down" : "Move down",
     "Custom background" : "Custom background",
     "Default background" : "Default background",
     "Change color" : "Change colour",
     "No background" : "No background",
     "Select a background from your files" : "Select a background from your files",
+    "Select background" : "Select background",
+    "No background has been selected" : "No background has been selected",
     "Theme selection is enforced" : "Theme selection is enforced",
-    "Select a custom color" : "Select a custom colour",
+    "Navigation bar settings" : "Navigation bar settings",
+    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo.",
+    "The default app can not be changed because it was configured by the administrator." : "The default app can not be changed because it was configured by the administrator.",
+    "The app order was changed, to see it in action you have to reload the page." : "The app order was changed, to see it in action you have to reload the page.",
+    "Reset default app order" : "Reset default app order",
+    "Could not set the app order" : "Could not set the app order",
+    "Could not reset the app order" : "Could not reset the app order",
+    "Default app" : "Default app",
+    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked.",
+    "Use custom default app" : "Use custom default app",
+    "Global default app" : "Global default app",
+    "Global default apps" : "Global default apps",
+    "Default app priority" : "Default app priority",
+    "If an app is not enabled for a user, the next app with lower priority is used." : "If an app is not enabled for a user, the next app with lower priority is used.",
+    "Could not set global default apps" : "Could not set global default apps",
     "Reset to default" : "Reset to default",
     "Upload" : "Upload",
     "Remove background image" : "Remove background image",
-    "Loading preview…" : "Loading preview…",
-    "Admin" : "Admin",
-    "Error uploading the file" : "Error uploading the file",
-    "Name cannot be empty" : "Name cannot be empty",
-    "Migrate and clean up admin theming images" : "Migrate and clean up admin theming images",
-    "Failed to clean up the old admin theming images folder" : "Failed to clean up the old admin theming images folder",
-    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
-    "Pick from Files" : "Pick from Files",
-    "Default image" : "Default image",
-    "Custom color" : "Custom colour",
-    "Plain background" : "Plain background",
-    "Insert from {productName}" : "Insert from {productName}",
-    "Open documentation" : "Open documentation",
-    "https://…" : "https://…",
-    "Upload new login background" : "Upload new login background",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box.",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and colour."
+    "Select a custom color" : "Select a custom colour"
 },
 "nplurals=2; plural=(n != 1);");
