@@ -3,13 +3,14 @@ OC.L10N.register(
     {
     "The given name is too long" : "输入的名称过长",
     "The given web address is too long" : "输入的地址过长",
-    "The given web address is not a valid URL" : "提供的web地址不是一个合法的URL",
+    "The given web address is not a valid URL" : "提供的 web 地址不是一个合法的 URL",
     "The given legal notice address is too long" : "提供的法律通告地址太长",
-    "The given legal notice address is not a valid URL" : "提供的法律通告地址不是一个合法的URL",
+    "The given legal notice address is not a valid URL" : "提供的法律通告地址不是一个合法的 URL",
     "The given privacy policy address is too long" : "提供的隐私政策地址太长",
-    "The given privacy policy address is not a valid URL" : "提供的隐私政策地址不是一个合法的URL",
+    "The given privacy policy address is not a valid URL" : "提供的隐私政策地址不是一个合法的 URL",
     "The given slogan is too long" : "输入的标语过长",
     "The given color is invalid" : "提供的颜色无效",
+    "Disable-user-theming should be true or false" : "Disable-user-theming 应该是 true 或者 false",
     "Saved" : "已保存",
     "The file was uploaded" : "文件已上传",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传的文件超出了 php.ini 中的 upload_max_filesize 的值",
@@ -20,13 +21,12 @@ OC.L10N.register(
     "Could not write file to disk" : "无法写入文件到磁盘",
     "A PHP extension stopped the file upload" : "PHP 扩展停止了文件上传。",
     "No file uploaded" : "文件没有上传",
-    "Cleanup old theming cache" : "清理旧主题缓存",
-    "Failed to delete folder: \"%1$s\", error: %2$s" : "删除文件夹 %1$s 时发生错误：%2$s",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "你已经在使用一个自定义的主题。主题应用的设置可能会被其覆盖。",
     "Theming" : "主题",
     "Appearance and accessibility" : "外观和可访问性",
+    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP 模块“imagick”没有被启用，尽管已启用了主题程序。为了使收藏图标正常生成，您需要安装并启用这个模块。",
     "Dark theme with high contrast mode" : "高对比度深色主题",
-    "Enable dark high contrast mode" : "使用深色高对比度模式",
+    "Enable dark high contrast mode" : "使用高对比度深色模式",
     "Similar to the high contrast mode, but with dark colours." : "类似高对比度模式，但是使用深色色调。",
     "Dark theme" : "深色主题",
     "Enable dark theme" : "启用深色主题",
@@ -36,7 +36,7 @@ OC.L10N.register(
     "Using the default system appearance." : "使用系统默认外观。",
     "Dyslexia font" : "阅读障碍字体",
     "Enable dyslexia font" : "启用阅读障碍字体",
-    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic是一款免费的字样/字体，这款字体的设计目的是缓解由阅读障碍引起的一些常见阅读错误。",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic 是一款免费的字样/字体，这款字体的设计目的是缓解由阅读障碍引起的一些常见阅读错误。",
     "High contrast mode" : "高对比度模式",
     "Enable high contrast mode" : "启用高对比度模式",
     "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "使用高对比度模式。图像质量会下降，但清晰度会提升。",
@@ -67,31 +67,24 @@ OC.L10N.register(
     "User settings" : "用户设置",
     "Disable user theming" : "禁用用户自定义主题",
     "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "除了您在此处对实例外观进行的定制外，实例上的用户也可以选择他们自己的背景和主题色。启用此选项可阻止用户自定义外观。",
-    "Keyboard shortcuts" : "键盘快捷键",
-    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "某些情况下，键盘快捷键会干扰无障碍浏览工具。该设置可禁用所有键盘快捷键，以便您控制这些工具的焦点。启用该设置将同时禁用所有应用中的快捷键。",
-    "Disable all keyboard shortcuts" : "禁用所有键盘快捷键",
     "Background" : "背景",
     "Customization has been disabled by your administrator" : "管理员已禁用自定义功能",
     "Set a custom background" : "选择自定义背景",
+    "Keyboard shortcuts" : "键盘快捷键",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "某些情况下，键盘快捷键会干扰无障碍浏览工具。该设置可禁用所有键盘快捷键，以便您控制这些工具的焦点。启用该设置将同时禁用所有应用中的快捷键。",
+    "Disable all keyboard shortcuts" : "禁用所有键盘快捷键",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "无障碍访问对我们非常重要。 我们遵循网络标准，并进行检查以确保所有内容都可以在没有鼠标或辅助软件（例如屏幕阅读器）的情况下使用。 我们的目标是达到 {guidelines} Web 内容可访问性指南 {linkend} 2.1 中的 AA 级别，并另外通过高对比度主题达到 AAA 级别。",
-    "Pick from Files" : "从文件中挑选",
-    "Default image" : "默认图片",
-    "Custom color" : "自定义颜色",
-    "Plain background" : "纯色背景",
-    "Insert from {productName}" : "从 {productName} 插入",
+    "Move up" : "上移",
+    "Move down" : "下移",
+    "Custom background" : "自定义背景",
+    "Default background" : "默认背景",
+    "Change color" : "更改颜色",
+    "No background" : "没有背景",
+    "Select a background from your files" : "从文件中选择背景",
     "Theme selection is enforced" : "主题由管理员指定",
-    "Select a custom color" : "自定义颜色",
     "Reset to default" : "重置为默认设置",
     "Upload" : "上传",
     "Remove background image" : "删除背景图片",
-    "Loading preview…" : "正在加载预览...",
-    "Admin" : "管理",
-    "Name cannot be empty" : "名称不能为空",
-    "Open documentation" : "打开文档",
-    "https://…" : "https://…",
-    "Login image" : "登录图片",
-    "Upload new login background" : "上传新登录背景",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "安装支持 SVG 图像的 PHP 扩展 Imagemagick，以根据上传的 logo 和颜色自动生成图标。",
-    "Error uploading the file" : "上传文件时出错"
+    "Select a custom color" : "自定义颜色"
 },
 "nplurals=1; plural=0;");
