@@ -42,19 +42,21 @@ OC.MimeType = {
 		var icon = mimeType.replace(new RegExp('/', 'g'), '-');
 
 		// Generate path
-		if (mimeType === 'dir' && $.inArray('folder', files) !== -1) {
+		if (mimeType === 'dir' && files.includes('folder')) {
 			return 'folder';
-		} else if (mimeType === 'dir-shared' && $.inArray('folder-shared', files) !== -1) {
+		} else if (mimeType === 'dir-encrypted' && files.includes('folder-encrypted')) {
+			return 'folder-encrypted';
+		} else if (mimeType === 'dir-shared' && files.includes('folder-shared')) {
 			return 'folder-shared';
-		} else if (mimeType === 'dir-public' && $.inArray('folder-public', files) !== -1) {
+		} else if (mimeType === 'dir-public' && files.includes('folder-public')) {
 			return 'folder-public';
-		} else if (mimeType === 'dir-external' && $.inArray('folder-external', files) !== -1) {
+		} else if ((mimeType === 'dir-external' || mimeType === 'dir-external-root') && files.includes('folder-external')) {
 			return 'folder-external';
-		} else if ($.inArray(icon, files) !== -1) {
+		} else if (files.includes(icon)) {
 			return icon;
-		} else if ($.inArray(icon.split('-')[0], files) !== -1) {
+		} else if (files.includes(icon.split('-')[0])) {
 			return icon.split('-')[0];
-		} else if ($.inArray('file', files) !== -1) {
+		} else if (files.includes('file')) {
 			return 'file';
 		}
 
@@ -68,7 +70,7 @@ OC.MimeType = {
 	 * @return {string} Url to the icon for mimeType
 	 */
 	getIconUrl: function(mimeType) {
-		if (_.isUndefined(mimeType)) {
+		if (typeof mimeType === 'undefined') {
 			return undefined;
 		}
 
@@ -82,8 +84,8 @@ OC.MimeType = {
 		// First try to get the correct icon from the current theme
 		var gotIcon = null;
 		var path = '';
-		if (OC.theme.folder !== '' && $.isArray(OC.MimeTypeList.themes[OC.theme.folder])) {
-			path = OC.webroot + '/themes/' + OC.theme.folder + '/core/img/filetypes/';
+		if (OC.theme.folder !== '' && Array.isArray(OC.MimeTypeList.themes[OC.theme.folder])) {
+			path = OC.getRootPath() + '/themes/' + OC.theme.folder + '/core/img/filetypes/';
 			var icon = OC.MimeType._getFile(mimeType, OC.MimeTypeList.themes[OC.theme.folder]);
 
 			if (icon !== null) {
@@ -91,7 +93,7 @@ OC.MimeType = {
 				path += icon;
 			}
 		}
-		if(OCA.Theming) {
+		if(OCA.Theming && gotIcon === null) {
 			path = OC.generateUrl('/apps/theming/img/core/filetypes/');
 			path += OC.MimeType._getFile(mimeType, OC.MimeTypeList.files);
 			gotIcon = true;
@@ -99,7 +101,7 @@ OC.MimeType = {
 
 		// If we do not yet have an icon fall back to the default
 		if (gotIcon === null) {
-			path = OC.webroot + '/core/img/filetypes/';
+			path = OC.getRootPath() + '/core/img/filetypes/';
 			path += OC.MimeType._getFile(mimeType, OC.MimeTypeList.files);
 		}
 
