@@ -96,6 +96,8 @@ OC.L10N.register(
     "More apps" : "Více aplikací",
     "Currently open" : "Nyní otevřeno",
     "_{count} notification_::_{count} notifications_" : ["{count} upozornění","{count} upozornění","{count} upozornění","{count} upozornění"],
+    "No" : "Ne",
+    "Yes" : "Ano",
     "Custom date range" : "Uživatelsky určené datumové rozmezí",
     "Pick start date" : "Vybrat datum začátku",
     "Pick end date" : "Vybrat datum konce",
@@ -196,8 +198,6 @@ OC.L10N.register(
     "{name} version {version} and above" : "{name} verze {version} a novější",
     "Settings menu" : "Nabídka nastavení",
     "Avatar of {displayName}" : "Zástupný obrázek {displayName}",
-    "No" : "Ne",
-    "Yes" : "Ano",
     "Choose {file}" : "Zvolit {file}",
     "Choose" : "Vybrat",
     "Copy to {target}" : "Zkopírovat do {target}",
@@ -205,7 +205,6 @@ OC.L10N.register(
     "Move to {target}" : "Přesunout do {target}",
     "Move" : "Přesunout",
     "OK" : "OK",
-    "Error loading message template: {error}" : "Chyba při načítání šablony zprávy: {error}",
     "read-only" : "pouze pro čtení",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} souborový konflikt","{count} souborové konflikty","{count} souborových konfliktů","{count} souborové konflikty"],
     "One file conflict" : "Jeden konflikt souboru",
@@ -359,7 +358,6 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tato instance %s se právě nachází v režimu údržby a ta může chvíli trvat.",
     "This page will refresh itself when the instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude tato instance opět dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Pokud se tato zpráva objevuje trvale nebo nečekaně, obraťte se na správce systému.",
-    "Please try again" : "Zkuste to znovu",
     "The user limit of this instance is reached." : "Bylo dosaženo limitu počtu uživatelů této instance.",
     "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Pokud chcete zvýšit limit počtu uživatelů, zadejte klíč svého předplatného. To vám zpřístupní také veškeré další přínosy, které Nextcloud Enterprise poskytuje a je velmi doporučováno pro provozování ve firmách.",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Váš webový server ještě není správně nastaven, pro umožnění synchronizace souborů, rozhraní WebDAV pravděpodobně není funkční.",
@@ -372,7 +370,9 @@ OC.L10N.register(
     "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Doposud jste nenastavili či neověřili jste nastavení pro e-mailový server. Přejděte do {mailSettingsStart}Základních nastavení{mailSettingsEnd} a nastavte je. Poté použijte tlačítko „Odeslat e-mail“ níže ve formuláři a svá nastavení ověřte.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaše databáze není spuštěná s úrovní izolace transakcí „READ COMMITTED“. Toto může způsobit problémy při paralelním spouštění více akcí současně.",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Modul PHP „fileinfo“ chybí. Důrazně se doporučuje zapnout tento modul pro zajištění lepšího zjišťování MIME typů.",
+    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Vaše vzdálená adresa byla identifikována jako „{remoteAddress}“ a rychlost vyřizování požadavků z ní je v tuto chvíli omezována kvůli zamezení přetěžování útokem hádání hesel (bruteforce). Pokud vzdálená adresa není vaše, může se jednat o indikaci, že není správně nastavena proxy. Podrobnosti jsou k dispozici v {linkstart}dokumentaci ↗{linkend}.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transakční zamykání souborů je vypnuto, což může vést k problémům při souběžném přístupu. Abyste se jim vyhli, zapněte v config.php volbu „filelocking.enabled“. Další informace naleznete v {linkstart}dokumentaci ↗{linkend}.",
+    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "Databáze je používaná pro transakční zamykání souborů. Pokud chcete vylepšit výkon, nastavte memcache (pokud je k dispozici). Další informace naleznete v {linkstart}dokumentaci ↗{linkend}.",
     "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Zajistěte, aby volba „overwrite.cli.url„ v souboru config.php byla nastavena na URL adresu, přes kterou uživatelé přistupují k této instanci Nextcloud. Doporučení: „{suggestedOverwriteCliURL}“. Pokud tomu tak nebude, může docházet k problémům při vytváření URL prostřednictvím plánovače cron. (ačkoli je možné, že doporučená URL není tou, kterou uživatelé zpravidla používají pro přístup k této instanci Nextcloud. Nejlepší je toto v každém případě překontrolovat.)",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Vaše instalace nemá nastavenou žádnou výchozí oblast telefonu. To je nutné k ověření telefonních čísel v nastavení profilu bez kódu země. Chcete-li povolit čísla bez kódu země, přidejte do svého souboru s nastaveními řetězec „default_phone_region“ s příslušným {linkstart} kódem ISO 3166-1 {linkend} regionu.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nebylo možné vykonat naplánovanou úlohu z příkazového řádku. Objevily se následující technické chyby:",
@@ -382,6 +382,7 @@ OC.L10N.register(
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nebyla nastavena mezipaměť v paměti. Pokud je dostupná, nastavte ji pro zlepšení výkonu. Další informace lze nalézt v naší {linkstart}dokumentaci ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP nenalezlo žádný použitelný zdroj náhodnosti, což je silně nedoporučeno z důvodu zabezpečení. Bližší informace naleznete v {linkstart}dokumentaci ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Nyní používáte PHP {version}. Abyste mohli využívat {linkstart}aktualizace, zlepšující výkonnost a zabezpečení, poskytované autory PHP↗{linkend}, přejděte na jeho novější verzi. A to tak rychle, jak to vámi využívaná distribuce operačního systému umožňuje.",
+    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "Od Nextcloud 27 je PHP 8.0 už označeno jako zastaralé. Nextcloud 28 pak už může vyžadovat alespoň PHP 8.1. Co možná nejdříve přejděte na  {linkstart}některou z oficiálně podporovaných verzí PHP, poskytovaných PHP Group ↗{linkend}.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nastavení hlaviček reverzní proxy není správné nebo přistupujete na Nextcloud z důvěryhodné proxy. Pokud nepřistupujete k Nextcloud z důvěryhodné proxy, potom je toto bezpečností chyba a může útočníkovi umožnit falšovat IP adresu, kterou NextCloud vidí. Další informace lze nalézt v naší {linkstart}dokumentaci ↗{linkend}.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Je nastaven memcached jako distribuovaná cache, ale je nainstalovaný nesprávný PHP modul „memcache“. \\OC\\Memcache\\Memcached podporuje pouze „memcached“ a ne „memcache“. Podívejte se na {linkstart}memcached wiki pro oba moduly ↗{linkend}..",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Některé soubory neprošly kontrolou integrity. Podrobnosti ohledně řešení tohoto problém lze nalézt v {linkstart1}dokumentaci↗{linkend}. ({linkstart2}Seznam neplatných souborů…{linkend} / {linkstart3}Znovu ověřit…{linkend})",
@@ -409,6 +410,7 @@ OC.L10N.register(
     "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Tato instance používá jako hlavní úložiště objektové úložiště, založené na protokolu S3. Nahrané soubory jsou dočasně ukládány na server a proto je doporučeno mít 50 GB volného prostoru v adresáři temp pro PHP. Podrobnosti o umístění a prostoru, který je k dispozici naleznete v záznamu událostí. Pro navýšení kapacit nasměrujte v php.ini na jiný adresář nebo zvyšte kapacitu stávajícího umístění.",
     "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Dočasná složka této instance ukazuje na buď neexistující nebo pro zápis nepřístupnou složku.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "K vámi využívané instanci sice přistupujete přes zabezpečené připojení, nicméně tato vytváří nezabezpečené URL adresy. To s nejvyšší pravděpodobností znamená, že se nacházíte za reverzní proxy a proměnné v jejím nastavení, ohledně procesu přepisování, nejsou správně nastavené. Přečtete si tomu věnovanou {linkstart}stránku v dokumentaci ↗{linkend}.",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Tato instance je spuštěná v ladicím režimu. Toto zapínejte pouze pro lokální vývoj a nikoli v produkčních prostředích.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Váš datový adresář a soubory jsou pravděpodobně přístupné z Internetu. Soubor .htaccess nefunguje. Je důrazně doporučeno nastavit váš webový server tak, aby  tento adresář už nebyl dostupný z Internetu, nebo byl přesunut mimo prostor, zpřístupňovaný webovým serverem.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ není nastavena ve shodě s „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ není nastavena ve shodě s „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
@@ -420,12 +422,11 @@ OC.L10N.register(
     "Wrong username or password." : "Nesprávné uživatelské jméno nebo heslo.",
     "User disabled" : "Uživatelský účet znepřístupněn",
     "Username or email" : "Uživ. jméno nebo e-mail",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Na e-mailovou adresu, vedenou k tomuto účtu, byla odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, podívejte se také do složek s nevyžádanou poštou (spam) a/nebo požádejte svého místního správce o pomoc.",
-    "If it is not there ask your local administrator." : "Pokud se tam nenachází, zeptejte se svého místního správce.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Pokud tento účet existuje, byla na jeho e-mailovou adresu odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, podívejte se také do složek s nevyžádanou poštou (spam) a/nebo požádejte svého místního správce o pomoc.",
     "Start search" : "Zahájit vyhledávání",
-    "Press enter to start searching" : "Vyhledávání zahájíte stisknutím klávesy Enter",
     "Open settings menu" : "Otevřít nabídku s nataveními",
     "Settings" : "Nastavení",
+    "Avatar of {fullName}" : "Avatar {fullName}",
     "Show all contacts …" : "Zobrazit všechny kontakty…",
     "No files in here" : "Nejsou zde žádné soubory",
     "New folder" : "Nová složka",
@@ -439,6 +440,7 @@ OC.L10N.register(
     "\"{name}\" is not an allowed filetype" : "„{name}“ není povolený typ souboru",
     "{newName} already exists" : "{newName} už existuje",
     "Error loading file picker template: {error}" : "Chyba při načítání šablony výběru souborů: {error}",
+    "Error loading message template: {error}" : "Chyba při načítání šablony zprávy: {error}",
     "Show list view" : "Zobrazit v seznamu",
     "Show grid view" : "Zobrazit v mřížce",
     "Pending" : "Čekající",
@@ -450,19 +452,12 @@ OC.L10N.register(
     "Confirm" : "Potvrdit",
     "Failed to authenticate, try again" : "Ověření se nezdařilo, zkuste to znovu",
     "Users" : "Uživatelé",
-    "The page could not be found on the server." : "Stránka nebyla na serveru nalezena.",
     "Username" : "Uživatelské jméno",
     "Database user" : "Uživatel databáze",
     "Confirm your password" : "Potvrdit heslo",
     "App token" : "Token aplikace",
     "Alternative log in using app token" : "Alternativní přihlášení pomocí tokenu aplikace",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Použijte aktualizační příkazový řádek, protože máte velkou instanci s více než 50 uživateli.",
-    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Vaše vzdálená adresa byla identifikována jako „{remoteAddress}“ a rychlost vyřizování požadavků z ní je v tuto chvíli omezována kvůli zamezení přetěžování útokem hádání hesel (bruteforce). Pokud vzdálená adresa není vaše, může se jednat o indikaci, že není správně nastavena proxy. Podrobnosti jsou k dispozici v {linkstart}dokumentaci ↗{linkend}.",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "Databáze je používaná pro transakční zamykání souborů. Pokud chcete vylepšit výkon, nastavte memcache (pokud je k dispozici). Další informace naleznete v {linkstart}dokumentaci ↗{linkend}.",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "Od Nextcloud 27 je PHP 8.0 už označeno jako zastaralé. Nextcloud 28 pak už může vyžadovat alespoň PHP 8.1. Co možná nejdříve přejděte na  {linkstart}některou z oficiálně podporovaných verzí PHP, poskytovaných PHP Group ↗{linkend}.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Tato instance je spuštěná v ladicím režimu. Toto zapínejte pouze pro lokální vývoj a nikoli v produkčních prostředích.",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Pokud tento účet existuje, byla na jeho e-mailovou adresu odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, podívejte se také do složek s nevyžádanou poštou (spam) a/nebo požádejte svého místního správce o pomoc.",
-    "Avatar of {fullName}" : "Avatar {fullName}",
     "Apps and Settings" : "Aplikace a natavení"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
