@@ -35,8 +35,10 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite mygtuką slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite nuorodą slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
     "Reset your password" : "Atkurkite savo slaptažodį",
+    "Internal error" : "Vidinė klaida",
+    "Could not detect language" : "Nepavyko aptikti kalbos",
+    "Unable to translate" : "Nepavyko išversti",
     "Nextcloud Server" : "Nextcloud serveris",
-    "The user limit of this instance is reached." : "Yra pasiekta šio egzemplioriaus naudotojų riba.",
     "Learn more ↗" : "Sužinokite daugiau ↗",
     "Preparing update" : "Ruošiamas atnaujinimas",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -44,7 +46,6 @@ OC.L10N.register(
     "Repair info:" : "Pataisymo informacija:",
     "Repair warning:" : "Taisymo įspėjimas:",
     "Repair error:" : "Taisymo klaida:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Automatinis atnaujinimas išjungtas config.php faile. Naudokite komandinės eilutės atnaujinimo įrankį.",
     "Turned on maintenance mode" : "Įjungta techninės priežiūros veiksena",
     "Turned off maintenance mode" : "Išjungta techninės priežiūros veiksena",
     "Maintenance mode is kept active" : "Techninės priežiūros veiksena yra aktyvi",
@@ -59,13 +60,6 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nesuderinama)",
     "The following apps have been disabled: %s" : "Šios programėlės buvo išjungtos: %s",
     "Already up to date" : "Naudojama naujausia versija",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Buvo neįmanoma įvykdyti cron užduotį per komandų eilutę. Atsirado šios techninės klaidos:",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Lentelėje „{tableName}“ trūksta nebūtino stulpelio „{columnName}“.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Šiame egzemplioriuje trūksta kai kurių rekomenduojamų PHP modulių. Pagerintam našumui ir geresniam suderinamumui yra primygtinai rekomenduojama juos įdiegti.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Tai ypač rekomenduojama failų sinchronizavimui naudojant darbalaukio kliento programą.",
-    "The PHP memory limit is below the recommended value of 512MB." : "PHP atminties riba yra žemiau rekomenduojamos 512MB reikšmės.",
     "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Išsamesnei informacijai, žiūrėkite {linkstart}dokumentaciją ↗{linkend}.",
     "unknown text" : "nežinomas tekstas",
@@ -84,17 +78,20 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
     "More apps" : "Daugiau programėlių",
     "_{count} notification_::_{count} notifications_" : ["{count} pranešimas","{count} pranešimai","{count} pranešimų","{count} pranešimas"],
+    "No" : "Ne",
+    "Yes" : "Taip",
     "Log in" : "Prisijungti",
     "Logging in …" : "Prisijungiama …",
     "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
     "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
+    "Temporary error" : "Laikina klaida",
+    "Please try again." : "Bandykite dar kartą.",
     "An internal error occurred." : "Įvyko vidinė klaida.",
     "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
     "Password" : "Slaptažodis",
-    "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
-    "User disabled" : "Naudotojas išjungtas",
+    "Log in to {productName}" : "Prisijunkite prie {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
-    "Username or email" : "Naudotojas arba el. paštas",
+    "Log in with a device" : "Prisijungti naudojant įrenginį",
     "Your account is not setup for passwordless login." : "Jūsų paskyra nėra nustatyta prisijungimui be slaptažodžio.",
     "Browser not supported" : "Naršyklė nepalaikoma",
     "Passwordless authentication is not supported in your browser." : "Tapatybės nustatymas be slaptažodžio nėra palaikomas jūsų naršyklėje.",
@@ -109,55 +106,50 @@ OC.L10N.register(
     "Loading apps …" : "Įkeliamos programėlės…",
     "Installing apps …" : "Įdiegiamos programėlės…",
     "App download or installation failed" : "Programėlės atsisiuntimas ar įdiegimas patyrė nesėkmę",
+    "Cannot install this app because it is not compatible" : "Nepavyksta įdiegti šios programėlės, nes ji yra nesuderinama",
+    "Cannot install this app" : "Nepavyksta įdiegti šios programėlės",
     "Skip" : "Praleisti",
     "Install recommended apps" : "Įdiegti rekomenduojamas programėles",
     "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
+    "Search contacts" : "Ieškoti adresatų",
+    "Reset search" : "Atstatyti paiešką",
+    "Search contacts …" : "Ieškoti adresatų…",
+    "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
+    "No contacts found" : "Adresatų nerasta",
+    "Show all contacts" : "Rodyti visus adresatus",
+    "Install the Contacts app" : "Įdiegti adresatų programėlę",
+    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
+    "Looking for {term} …" : "Ieškoma {term} ...",
+    "Search for {name} only" : "Ieškoti tik {name}",
+    "Start typing to search" : "Rašykite norėdami atlikti paiešką",
+    "Loading more results …" : "Įkeliama daugiau rezultatų…",
+    "Load more results" : "Įkelti daugiau rezultatų",
+    "Search" : "Ieškoti",
+    "No results for {query}" : "{query} negrąžino jokių rezultatų",
+    "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių"],
     "Forgot password?" : "Pamiršote slaptažodį?",
-    "Log in with a device" : "Prisijungti naudojant įrenginį",
     "Back" : "Atgal",
     "Edit Profile" : "Taisyti profilį",
     "The headline and about sections will show up here" : "Čia bus rodoma santrauka apie jus bei kita su jumis susijusi informacija",
     "You have not added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
     "{user} has not added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos",
-    "Reset search" : "Atstatyti paiešką",
-    "Search for {name} only" : "Ieškoti tik {name}",
-    "No results for {query}" : "{query} negrąžino jokių rezultatų",
-    "Start typing to search" : "Norėdami atlikti paiešką, pradėkite rašyti",
-    "Loading more results …" : "Įkeliama daugiau rezultatų…",
-    "Load more results" : "Įkelti daugiau rezultatų",
-    "Search" : "Ieškoti",
-    "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių"],
     "Search {types} …" : "Ieškoti {types}…",
-    "Settings" : "Nustatymai",
-    "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
-    "Search contacts …" : "Ieškoti adresatų…",
-    "No contacts found" : "Adresatų nerasta",
-    "Show all contacts …" : "Rodyti visus adresatus...",
-    "Install the Contacts app" : "Įdiegti adresatų programėlę",
-    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
-    "Looking for {term} …" : "Ieškoma {term} ...",
-    "No" : "Ne",
-    "Yes" : "Taip",
-    "No files in here" : "Čia failų nėra",
-    "New folder" : "Naujas aplankas",
-    "No more subfolders in here" : "Čia daugiau nebėra poaplankių",
-    "Name" : "Pavadinimas",
-    "Size" : "Dydis",
-    "Modified" : "Pakeista",
-    "\"{name}\" is an invalid file name." : "„{name}“ yra neteisingas failo pavadinimas.",
-    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
-    "\"/\" is not allowed inside a file name." : "Failo pavadinime simbolis „/“ draudžiamas.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" yra neleistinas failo tipas",
-    "{newName} already exists" : "{newName} jau yra",
+    "Date" : "Data",
+    "Today" : "Šiandien",
+    "Not found" : "Nerasta",
+    "People" : "Žmonės",
+    "Searching …" : "Ieškoma…",
+    "Supported versions" : "Palaikomos versijos",
+    "Settings menu" : "Nustatymų meniu",
     "Choose" : "Pasirinkti",
+    "Copy to {target}" : "Kopijuoti į {target}",
     "Copy" : "Kopijuoti",
+    "Move to {target}" : "Perkelti į {target}",
     "Move" : "Perkelti",
-    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
     "OK" : "Gerai",
-    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
     "read-only" : "tik skaitymui",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} failų konfliktas","{count} failų konfliktai","{count} failų konfliktų","{count} failų konfliktas"],
     "One file conflict" : "Vieno failo konfliktas",
@@ -170,16 +162,7 @@ OC.L10N.register(
     "(all selected)" : "(visi pažymėti)",
     "({count} selected)" : "({count} pažymėtų)",
     "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
-    "Show list view" : "Rodyti sąrašo rodinį",
-    "Show grid view" : "Rodyti tinklelio rodinį",
-    "Pending" : "Vykdoma",
-    "Copy to {folder}" : "Kopijuoti į {folder}",
-    "Move to {folder}" : "Perkelti į {folder}",
-    "Saving …" : "Įrašoma …",
-    "Authentication required" : "Reikalingas tapatybės nustatymas",
-    "This action requires you to confirm your password" : "Šis veiksmas reikalauja, kad įvestumėte savo slaptažodį",
-    "Confirm" : "Patvirtinti",
-    "Failed to authenticate, try again" : "Nepavyko nustatyti tapatybės, bandykite dar kartą",
+    "Saving …" : "Įrašoma…",
     "seconds ago" : "prieš keletą sekundžių",
     "Connection to server lost" : "Ryšys su serveriu nutrūko",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
@@ -209,7 +192,6 @@ OC.L10N.register(
     "Collaborative tags" : "Bendradarbiavimo žymės",
     "No tags found" : "Nerasta jokių žymių",
     "Personal" : "Asmeniniai",
-    "Users" : "Naudotojai",
     "Apps" : "Programėlės",
     "Admin" : "Administravimas",
     "Help" : "Pagalba",
@@ -239,7 +221,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
     "Create an <strong>admin account</strong>" : "Sukurkite <strong>administratoriaus paskyrą</strong>",
-    "Username" : "Naudotojo vardas",
     "Show password" : "Rodyti slaptažodį",
     "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
     "Storage & database" : "Saugykla ir duomenų bazė",
@@ -248,7 +229,6 @@ OC.L10N.register(
     "Only %s is available." : "Yra prieinama tik %s.",
     "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
     "For more details check out the documentation." : "Išsamesnei informacijai, žiūrėkite dokumentaciją.",
-    "Database user" : "Duomenų bazės naudotojas",
     "Database password" : "Duomenų bazės slaptažodis",
     "Database name" : "Duomenų bazės pavadinimas",
     "Database tablespace" : "Duomenų bazės loginis saugojimas",
@@ -265,17 +245,12 @@ OC.L10N.register(
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Sistemos veikimui reikalingas JavaScript palaikymas. Prašome {linkstart}įjungti JavaScript palaikymą{linkend} ir atnaujinti puslapį.",
     "Skip to main content" : "Pereiti į pagrindinį turinį",
     "Skip to navigation of app" : "Pereiti į programėlės naršymą",
+    "Go to %s" : "Pereiti į %s",
     "Get your own free account" : "Gaukite nemokamą asmeninę paskyrą",
-    "Contacts" : "Adresatai",
-    "Contacts menu" : "Adresatų meniu",
-    "Open settings menu" : "Atverti nustatymų meniu",
-    "Confirm your password" : "Patvirtinkite savo slaptažodį",
     "Connect to your account" : "Prisijunkite prie paskyros",
     "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeigu nebandote nusistatyti naujo įrenginio ar programėlės, tuomet kažkas bando jus apgauti, kad suteiktumėte jam prieigą prie savo duomenų. Tokiu atveju netęskite ir, vietoj to, susisiekite su savo sistemos administratoriumi.",
-    "App token" : "Išorinės sistemos įskiepio kodas",
     "Grant access" : "Suteikti prieigą",
-    "Alternative log in using app token" : "Alternatyvus prisijungimas naudojant programėlės atpažinimo raktą",
     "Account access" : "Paskyros prieiga",
     "Currently logged in as %1$s (%2$s)." : "Šiuo metu prisijungta kaip %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros.",
@@ -285,7 +260,6 @@ OC.L10N.register(
     "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
     "Email address" : "El. pašto adresas",
     "Password sent!" : "Slaptažodis išsiųstas!",
-    "Go to %s" : "Pereiti į %s",
     "Two-factor authentication" : "Dviejų faktorių tapatybės nustatymas",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nepavyko įkelti bent vieno iš jūsų įjungtų dviejų faktorių tapatybės nustatymo metodų. Susisiekite su savo administratoriumi.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Susisiekite su savo administratoriumi dėl pagalbos. ",
@@ -307,7 +281,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Naudodami didesnius diegimus ir norėdami išvengti laukimo laiko, vietoj to, savo diegimo kataloge galite paleisti šią komandą:",
     "Detailed logs" : "Išsamūs žurnalai",
     "Update needed" : "Reikalingas atnaujinimas",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Naudokite komandų eilutės atnaujinimo programą, nes turite didelį egzempliorių su daugiau nei 50 naudotojų.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Prireikus pagalbos, žiūrėkite  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciją</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Suprantu, kad atnaujinimui naudodamas vartotojo aplinką, rizikuoju, kad sistemos darbas sutriks ir prisijungę vartotojai gali netekti duomenų, turiu atsarginę duomenų kopiją ir žinau, kaip atstatyti duomenis nesėkmės atveju.",
     "Upgrade via web on my own risk" : "Atnaujinti per interneto naršyklę prisiimant riziką",
@@ -315,16 +288,51 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s egzempliorius šiuo metu yra techninės priežiūros veiksenoje, kas savo ruožtu gali šiek tiek užtrukti.",
     "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi, jei šis pranešimas nedingsta arba, jei jis pasirodė netikėtai.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: Tikrinama lentelė %s",
-    "restricted" : "apribota",
-    "invisible" : "nematoma",
-    "File not found" : "Failas nerastas",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Nepavyko serveryje rasti dokumento. Galbūt, viešinys buvo ištrintas arba pasibaigė jo galiojimo laikas?",
-    "More" : "Daugiau",
-    "More apps menu" : "Daugiau programėlių meniu",
-    "Settings menu" : "Nustatymų meniu",
-    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
-    "You haven't added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
-    "{user} hasn't added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos"
+    "The user limit of this instance is reached." : "Yra pasiekta šio egzemplioriaus naudotojų riba.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Buvo neįmanoma įvykdyti cron užduotį per komandų eilutę. Atsirado šios techninės klaidos:",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
+    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Lentelėje „{tableName}“ trūksta nebūtino stulpelio „{columnName}“.",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Šiame egzemplioriuje trūksta kai kurių rekomenduojamų PHP modulių. Pagerintam našumui ir geresniam suderinamumui yra primygtinai rekomenduojama juos įdiegti.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Tai ypač rekomenduojama failų sinchronizavimui naudojant darbalaukio kliento programą.",
+    "The PHP memory limit is below the recommended value of 512MB." : "PHP atminties riba yra žemiau rekomenduojamos 512MB reikšmės.",
+    "Account name or email" : "Paskyros vardas ar el. paštas",
+    "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
+    "User disabled" : "Naudotojas išjungtas",
+    "Username or email" : "Naudotojas arba el. paštas",
+    "Open settings menu" : "Atverti nustatymų meniu",
+    "Settings" : "Nustatymai",
+    "Show all contacts …" : "Rodyti visus adresatus…",
+    "No files in here" : "Čia failų nėra",
+    "New folder" : "Naujas aplankas",
+    "No more subfolders in here" : "Čia daugiau nebėra poaplankių",
+    "Name" : "Pavadinimas",
+    "Size" : "Dydis",
+    "Modified" : "Pakeista",
+    "\"{name}\" is an invalid file name." : "„{name}“ yra neteisingas failo pavadinimas.",
+    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
+    "\"/\" is not allowed inside a file name." : "Failo pavadinime simbolis „/“ draudžiamas.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" yra neleistinas failo tipas",
+    "{newName} already exists" : "{newName} jau yra",
+    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
+    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
+    "Show list view" : "Rodyti sąrašo rodinį",
+    "Show grid view" : "Rodyti tinklelio rodinį",
+    "Pending" : "Vykdoma",
+    "Home" : "Namai",
+    "Copy to {folder}" : "Kopijuoti į {folder}",
+    "Move to {folder}" : "Perkelti į {folder}",
+    "Authentication required" : "Reikalingas tapatybės nustatymas",
+    "This action requires you to confirm your password" : "Šis veiksmas reikalauja, kad įvestumėte savo slaptažodį",
+    "Confirm" : "Patvirtinti",
+    "Failed to authenticate, try again" : "Nepavyko nustatyti tapatybės, bandykite dar kartą",
+    "Users" : "Naudotojai",
+    "Username" : "Naudotojo vardas",
+    "Database user" : "Duomenų bazės naudotojas",
+    "Confirm your password" : "Patvirtinkite savo slaptažodį",
+    "App token" : "Išorinės sistemos įskiepio kodas",
+    "Alternative log in using app token" : "Alternatyvus prisijungimas naudojant programėlės atpažinimo raktą",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Naudokite komandų eilutės atnaujinimo programą, nes turite didelį egzempliorių su daugiau nei 50 naudotojų.",
+    "Apps and Settings" : "Programėlės ir nustatymai"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
