@@ -5,10 +5,9 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "Toto je obvykle možné vyřešit udělením webovému serveru oprávnění k zápisu do adresáře s nastaveními.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ale, pokud chcete mít soubor config.php pouze pro čtení, nastavte  v něm volbu „config_is_read_only“ na hodnotu true.",
     "See %s" : "Viz %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Soubory aplikace %1$s nebyly nahrazeny řádně. Ověřte, že se jedná o verzi, která je kompatibilní se serverem.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplikace %1$s není přítomná nebo její verze není kompatibilní s tímto serverem. Zkontrolujte složku s aplikacemi. ",
     "Sample configuration detected" : "Bylo zjištěno setrvání u předváděcího nastavení",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Pravděpodobně byla zkopírována nastavení ze vzorových souborů. Toto není podporováno a může poškodit vaši instalaci. Před prováděním změn v souboru config.php si přečtěte dokumentaci",
-    "404" : "404",
     "The page could not be found on the server." : "Stránka nebyla na serveru nalezena.",
     "%s email verification" : "%s ověřování e-mailem",
     "Email verification" : "Ověřování e-mailem",
@@ -37,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Jsou podporovány následující systémy: %s",
     "Server version %s or higher is required." : "Je potřeba verze serveru %s nebo novější.",
     "Server version %s or lower is required." : "Je potřeba verze serveru %s nebo starší.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Aby mohl přistupovat k tomuto nastavení je třeba, aby přihlášený uživatel byl správce, dílčí správce nebo obdržel speciální oprávnění",
-    "Logged in user must be an admin or sub admin" : "Je třeba, aby přihlášený uživatel byl správcem či správcem pro dílčí oblast",
-    "Logged in user must be an admin" : "Je třeba, aby přihlášený uživatel byl správce",
     "Wiping of device %s has started" : "Vymazávání ze zařízení %s zahájeno",
     "Wiping of device »%s« has started" : "Vymazávání ze zařízení „%s“ zahájeno",
     "»%s« started remote wipe" : "„%s“ zahájilo vymazávání na dálku",
@@ -56,7 +52,9 @@ OC.L10N.register(
     "Unknown filetype" : "Neznámý typ souboru",
     "Invalid image" : "Neplatný obrázek",
     "Avatar image is not square" : "Profilový obrázek není čtvercový",
+    "Files" : "Soubory",
     "View profile" : "Zobrazit profil ",
+    "Local time: %s" : "Místní čas: %s",
     "today" : "dnes",
     "tomorrow" : "zítra",
     "yesterday" : "včera",
@@ -80,7 +78,7 @@ OC.L10N.register(
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s identifikátorem: %s neexistuje. Povolte ho v nastavení aplikací, nebo se obraťte na správce.",
     "File already exists" : "Soubor už existuje",
     "Invalid path" : "Neplatný popis umístění",
-    "Failed to create file from template" : "Vytvoření souboru ze šablony selhalo",
+    "Failed to create file from template" : "Vytvoření souboru ze šablony se nezdařilo",
     "Templates" : "Šablony",
     "File name is a reserved word" : "Název souboru je rezervované slovo",
     "File name contains at least one invalid character" : "Název souboru obsahuje přinejmenším jeden neplatný znak",
@@ -91,7 +89,6 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikaci „%s“ nelze nainstalovat, protože není kompatibilní s touto verzí serveru.",
     "__language_name__" : "Čeština",
     "This is an automatically sent email, please do not reply." : "Toto je automaticky odesílaný e-mail, neodpovídejte na něj.",
-    "Help" : "Nápověda",
     "Appearance and accessibility" : "Vzhled a zpřístupnění",
     "Apps" : "Aplikace",
     "Personal settings" : "Osobní nastavení",
@@ -101,6 +98,8 @@ OC.L10N.register(
     "Users" : "Uživatelé",
     "Email" : "E-mail",
     "Mail %s" : "Poslat e-mail %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "Zobrazit %s na fediverse",
     "Phone" : "Telefon",
     "Call %s" : "Zavolat %s",
     "Twitter" : "Twitter",
@@ -110,28 +109,23 @@ OC.L10N.register(
     "Address" : "Adresa",
     "Profile picture" : "Profilový obrázek",
     "About" : "O uživateli",
-    "Full name" : "Celé jméno",
+    "Display name" : "Zobrazované jméno",
     "Headline" : "Nadpis",
     "Organisation" : "Organizace",
     "Role" : "Role",
-    "Unknown user" : "Neznámý uživatel",
     "Additional settings" : "Další nastavení",
-    "Enter the database username and name for %s" : "Zadejte uživatelské jméno v databázi a název pro %s",
-    "Enter the database username for %s" : "Zadejte uživatelské jméno v databázi pro %s",
     "Enter the database name for %s" : "Zadejte název databáze pro %s",
     "You cannot use dots in the database name %s" : "V názvu databáze %s není možné použít tečky",
-    "MySQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do MySQL",
     "You need to enter details of an existing account." : "Je třeba zadat podrobnosti existujícího účtu.",
     "Oracle connection could not be established" : "Spojení s Oracle nemohlo být navázáno",
-    "Oracle username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do Oracle",
-    "PostgreSQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do PostgreSQL",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "macOS není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
     "For the best results, please consider using a GNU/Linux server instead." : "Místo toho zvažte pro nejlepší funkčnost použití GNU/Linux serveru.",
-    "Set an admin username." : "Nastavte uživatelské jméno správce.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá se, že tato instance %s je provozována v 32-bitovém PHP prostředí a v php.ini je nastavena volba open_basedir. Toto povede k problémům se soubory většími než 4 GB a silně není doporučováno.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraňte z php.ini nastavení volby open_basedir nebo přejděte na 64-bitové PHP.",
     "Set an admin password." : "Nastavte heslo pro účet správce.",
     "Cannot create or write into the data directory %s" : "Nedaří se vytvořit nebo zapisovat do datového adresáře %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Je třeba, aby podpůrná vrstva pro sdílení %s implementovala  rozhraní OCP\\Share_Backend",
-    "Sharing backend %s not found" : "Úložiště sdílení %s nenalezeno",
+    "Sharing backend %s not found" : "Podpůrná vrstva pro sdílení %s nenalezena",
     "Sharing backend for %s not found" : "Úložiště sdílení pro %s nenalezeno",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s sdílí „%2$s“ a dodává:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s sdílí „%2$s“ a dodává",
@@ -145,12 +139,12 @@ OC.L10N.register(
     "Expiration date is in the past" : "Datum skončení platnosti je v minulosti",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Datum vypršení nelze nastavit na více než %n den do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti","Datum vypršení nelze nastavit na více než %n dnů do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti"],
     "Sharing is only allowed with group members" : "Je povoleno pouze sdílení s členy skupiny",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sdílení %s se nezdařilo, protože tato položka už je sdílena s uživatelem %s",
     "%1$s shared »%2$s« with you" : "%1$s vám sdílí „%2$s“",
     "%1$s shared »%2$s« with you." : "%1$s vám nasdílel(a) „%2$s“.",
     "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
     "The requested share does not exist anymore" : "Požadované sdílení už neexistuje",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Bylo dosaženo limitu počtu uživatelů a uživatel proto nebyl vytvořen. Podrobnosti viz upozornění pro vás.",
+    "The requested share comes from a disabled user" : "Požadované sdílení pochází od vypnutého uživatelského účtu",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Uživatel nebyl vytvořen protože bylo dosaženo limitu počtu uživatelů. Více se dozvíte v upozorněních.",
     "Could not find category \"%s\"" : "Nedaří se nalézt kategorii „%s“",
     "Sunday" : "neděle",
     "Monday" : "pondělí",
@@ -197,15 +191,7 @@ OC.L10N.register(
     "Oct." : "říj.",
     "Nov." : "list.",
     "Dec." : "pro.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, a „_.@-'“",
-    "A valid username must be provided" : "Je třeba zadat platné uživatelské jméno",
-    "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
-    "Username must not consist of dots only" : "Uživatelské jméno se nemůže skládat pouze ze samých teček",
-    "Username is invalid because files already exist for this user" : "Uživatelské jméno není platné, protože protože pro tohoto uživatele už existují soubory",
     "A valid password must be provided" : "Je třeba zadat platné heslo",
-    "The username is already being used" : "Uživatelské jméno už je využíváno",
-    "Could not create user" : "Nepodařilo se vytvořit uživatele",
-    "User disabled" : "Uživatel zakázán",
     "Login canceled by app" : "Přihlášení zrušeno aplikací",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikaci „%1$s“ nelze nainstalovat, protože nejsou splněny následující závislosti: %2$s",
     "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
@@ -232,18 +218,12 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Úprava tohoto nastavení v php.ini umožní Nextcloud opět zprovoznit",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastaveno na <code>%s</code> namísto očekávané hodnoty <code>0</code>.",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pro nápravu nastavte v souboru php.ini parametr <code>mbstring.func_overload</code> na <code>0</code>.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Je zapotřebí verze softwarové knihovny libxml2 přinejmenším 2.7.0. Nyní je nainstalována verze %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Tento problém opravíte instalací novější verze knihovny libxml2 a restartem webového serveru.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je patrně nastaveno tak, aby odstraňovalo bloky komentářů. Toto bude mít za následek znepřístupnění mnoha důležitých aplikací.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
-    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly jsou nainstalovány, ale stále se tváří jako chybějící?",
+    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly jsou nainstalovány, přesto jsou uváděny jako chybějící?",
     "Please ask your server administrator to restart the web server." : "Požádejte správce serveru, který využíváte o restart webového serveru.",
     "The required %s config variable is not configured in the config.php file." : "Požadovaná proměnná nastavení %s není v souboru s nastaveními config.php nastavena.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Požádejte správce serveru, který využíváte, aby zkontroloval nastavení serveru.",
-    "PostgreSQL >= 9 required." : "Je vyžadováno PostgreSQL verze 9 a novější.",
-    "Please upgrade your database version." : "Aktualizujte verzi vámi využívané databáze.",
-    "Your data directory is readable by other users." : "Váš adresář data je čitelný ostatním uživatelům.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Změňte práva na 0770, aby obsah adresáře nemohl být vypisován ostatními uživateli.",
     "Your data directory must be an absolute path." : "Je třeba, aby váš adresář data byl zadán jako úplný popis umístění.",
     "Check the value of \"datadirectory\" in your configuration." : "Zkontrolujte hodnotu „datadirectory“ ve svém nastavení.",
     "Your data directory is invalid." : "Váš adresář data není platný.",
@@ -259,31 +239,38 @@ OC.L10N.register(
     "Storage connection error. %s" : "Chyba připojení úložiště. %s",
     "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
     "Storage connection timeout. %s" : "Překročen časový limit připojování k úložišti. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Toto je obvykle možné vyřešit udělením webovému serveru oprávnění k zápisu do adresáře s nastaveními.",
-    "%s enter the database username and name." : "%s zadejte databázové uživatelské jméno a jméno.",
-    "%s enter the database username." : "Zadejte uživatelské jméno %s databáze.",
-    "%s enter the database name." : "Zadejte název databáze pro %s databázi.",
-    "%s you may not use dots in the database name" : "V názvu databáze %s není možné používat tečky.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá se, že tato instance %s je provozována v 32-bitovém PHP prostředí a v php.ini je nastavena volba open_basedir. Toto povede k problémům se soubory většími než 4 GB a silně není doporučováno.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraňte z php.ini nastavení volby open_basedir nebo přejděte na 64-bitové PHP.",
-    "The user limit has been reached and the user was not created." : "Bylo dosaženo limitu počtu uživatelů a uživatel proto nebyl vytvořen.",
-    "Cannot read file" : "Nelze přečíst soubor",
-    "Cannot write into \"config\" directory" : "Nelze zapisovat do adresáře „config“",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
-    "Cannot write into \"apps\" directory" : "Nedaří se zapisovat do adresáře „apps“",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Toto je obvykle možné napravit udělením přístupu ke čtení adresáře s aplikací pro webový server nebo vypnutím katalogu s aplikacemi v souboru s nastaveními.",
-    "Cannot create \"data\" directory" : "Nedaří se vytvořit adresář „data“",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Oprávnění lze obvykle napravit umožněním zápisu do kořene webu pro účet, pod kterým je provozován webový server. Viz %s.",
-    "Setting locale to %s failed" : "Nastavení místních a jazykových nastavení na %s se nezdařilo",
-    "Please install one of these locales on your system and restart your webserver." : "Do svého systému nainstalujte alespoň jeden z těchto jazyků a restartujte webový server.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastaveno na „%s“ namísto očekávané hodnoty „0“",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pro nápravu nastavte v souboru php.ini parametr <code>mbstring.func_overload</code> na <code>0</code>",
-    "PostgreSQL >= 9 required" : "Je vyžadováno PostgreSQL verze 9 a novější",
-    "Please upgrade your database version" : "Aktualizujte verzi vámi využívané databáze",
-    "Your data directory is readable by other users" : "Váš adresář data je čitelný ostatním uživatelům",
-    "Your data directory must be an absolute path" : "Je třeba, aby váš adresář data byl zadán jako úplný popis umístění",
-    "Check the value of \"datadirectory\" in your configuration" : "Zkontrolujte hodnotu „datadirectory“ ve svém nastavení",
-    "Your data directory is invalid" : "Váš adresář data není plantý"
+    "Free prompt" : "Prompt zdarma",
+    "Runs an arbitrary prompt through the language model." : "Spouští libovolnou výzvu skrze jazykový model.",
+    "Generate headline" : "Vytvořit nadpis",
+    "Generates a possible headline for a text." : "Vytvoří možný nadpis pro text.",
+    "Summarize" : "Stručný souhrn",
+    "Summarizes text by reducing its length without losing key information." : "Vytvoří stručný souhrn textu tím, že zkrátí jeho délku aniž by byly ztraceny klíčové informace",
+    "Extract topics" : "Vyzískat témata",
+    "Extracts topics from a text and outputs them separated by commas." : "Vyzíská témata z textu a vypíše je oddělované čárkami.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Aby mohl přistupovat k tomuto nastavení je třeba, aby přihlášený uživatel byl správce, dílčí správce nebo obdržel speciální oprávnění",
+    "Logged in user must be an admin or sub admin" : "Je třeba, aby přihlášený uživatel byl správcem či správcem pro dílčí oblast",
+    "Logged in user must be an admin" : "Je třeba, aby přihlášený uživatel byl správce",
+    "Help" : "Nápověda",
+    "Unknown user" : "Neznámý uživatel",
+    "Enter the database username and name for %s" : "Zadejte uživatelské jméno v databázi a název pro %s",
+    "Enter the database username for %s" : "Zadejte uživatelské jméno v databázi pro %s",
+    "MySQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do MySQL",
+    "Oracle username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do Oracle",
+    "PostgreSQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do PostgreSQL",
+    "Set an admin username." : "Nastavte uživatelské jméno správce.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Sdílení %s se nezdařilo, protože tato položka už je sdílena s uživatelem %s",
+    "The username is already being used" : "Uživatelské jméno už je využíváno",
+    "Could not create user" : "Nepodařilo se vytvořit uživatele",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, mezery  a „_.@-'“",
+    "A valid username must be provided" : "Je třeba zadat platné uživatelské jméno",
+    "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
+    "Username must not consist of dots only" : "Uživatelské jméno se nemůže skládat pouze ze samých teček",
+    "Username is invalid because files already exist for this user" : "Uživatelské jméno není platné, protože protože pro tohoto uživatele už existují soubory",
+    "User disabled" : "Uživatel zakázán",
+    "PostgreSQL >= 9 required." : "Je vyžadováno PostgreSQL verze 9 a novější.",
+    "Please upgrade your database version." : "Aktualizujte verzi vámi využívané databáze.",
+    "Your data directory is readable by other users." : "Váš adresář data je čitelný ostatním uživatelům.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Změňte práva na 0770, aby obsah adresáře nemohl být vypisován ostatními uživateli."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
