@@ -19,6 +19,8 @@ OC.L10N.register(
     "Unknown filetype" : "Tundmatu failitüüp",
     "Invalid image" : "Vigane pilt",
     "Avatar image is not square" : "Avatari pilt pole ruut",
+    "Files" : "Failid",
+    "View profile" : "Vaata profiili",
     "today" : "täna",
     "tomorrow" : "homme",
     "yesterday" : "eile",
@@ -31,6 +33,11 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n tund tagasi","%n tundi tagasi"],
     "in a few seconds" : "mõne sekundi jooksul",
     "seconds ago" : "sekundit tagasi",
+    "Empty file" : "Tühi fail",
+    "File already exists" : "Fail on juba olemas",
+    "Invalid path" : "Vigane kataloogirada",
+    "Failed to create file from template" : "Ei saa luua mallist faili",
+    "Templates" : "Mallid",
     "File name is a reserved word" : "Failinimi sisaldab keelatud sõna",
     "File name contains at least one invalid character" : "Faili nimesonvähemalt üks keelatud märk",
     "File name is too long" : "Faili nimi on liiga pikk",
@@ -38,30 +45,34 @@ OC.L10N.register(
     "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
     "__language_name__" : "Eesti",
     "This is an automatically sent email, please do not reply." : "See on automaatselt saadetud e-kiri, palun ära vasta.",
-    "Help" : "Abi",
     "Apps" : "Rakendused",
+    "Personal settings" : "Isiklikud seaded",
+    "Administration settings" : "Administreerimise seaded",
     "Settings" : "Seaded",
     "Log out" : "Logi välja",
     "Users" : "Kasutajad",
-    "Unknown user" : "Tundmatu kasutaja",
+    "Email" : "Epost",
+    "Phone" : "Telefon",
+    "Twitter" : "Twitter",
+    "Website" : "Veebileht",
+    "Address" : "Aadress",
+    "Profile picture" : "Profiili pilt",
+    "About" : "Info",
+    "Display name" : "Kuvatav nimi",
+    "Organisation" : "Organisatsioon",
+    "Role" : "Roll",
     "Additional settings" : "Lisaseaded",
-    "%s enter the database username and name." : "%s sisesta andmebaasi kasutajatunnus ja nimi.",
-    "%s enter the database username." : "%s sisesta andmebaasi kasutajatunnus.",
-    "%s enter the database name." : "%s sisesta andmebaasi nimi.",
-    "%s you may not use dots in the database name" : "%s punktide kasutamine andmebaasi nimes pole lubatud",
     "You need to enter details of an existing account." : "Sa pead sisestama olemasoleva konto andmed.",
     "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
-    "Oracle username and/or password not valid" : "Oracle kasutajatunnus ja/või parool pole õiged",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL kasutajatunnus ja/või parool pole õiged",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
     "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
-    "Set an admin username." : "Määra admin kasutajanimi.",
     "Set an admin password." : "Määra admini parool.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
     "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
     "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
     "Open »%s«" : "Ava »%s«",
     "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
+    "Cannot increase permissions of %s" : "Ei saa %s õigusi suurendada",
     "Expiration date is in the past" : "Aegumise kuupäev on minevikus",
     "Click the button below to open it." : "Vajuta allolevat nuppu, et see avada.",
     "The requested share does not exist anymore" : "Soovitud jagamist enam ei eksisteeri",
@@ -111,14 +122,7 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dets.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kasutajanimes on lubatud ainult järgmised sümbolid: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
-    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
-    "Username contains whitespace at the beginning or at the end" : "Kasutajanime alguses või lõpus on tühik",
-    "Username must not consist of dots only" : "Kasutajanimi ei tohi koosneda ainult punktidest",
     "A valid password must be provided" : "Sisesta nõuetele vastav parool",
-    "The username is already being used" : "Kasutajanimi on juba kasutuses",
-    "Could not create user" : "Ei saanud kasutajat luua",
-    "User disabled" : "Kasutaja deaktiveeritud",
     "a safe home for all your data" : "turvaline koht sinu andmetele",
     "File is currently busy, please try again later" : "Fail on hetkel kasutuses, proovi hiljem uuesti",
     "Application is not enabled" : "Rakendus pole sisse lülitatud",
@@ -127,26 +131,26 @@ OC.L10N.register(
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
     "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
     "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
+    "PHP setting \"%s\" is not set to \"%s\"." : "PHP seade \"%s\" ei ole \"%s\".",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
     "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav",
+    "Your data directory is invalid." : "Sinu andmekataloog on vigane",
     "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
     "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Tavaliselt saab selle lahendada andes veebiserverile seatete kataloogile \"config\" kirjutusõigused",
-    "Can't create or write into the data directory %s" : "Ei suuda luua või kirjutada andmete kataloogi %s",
-    "Invalid Federated Cloud ID" : "Vigane liitpilve ID",
-    "Can’t increase permissions of %s" : "Ei saa %s õigusi suurendada",
-    "Files can’t be shared with delete permissions" : "Faile ei saa jagada kustutamise õigusega",
-    "Files can’t be shared with create permissions" : "Faile ei saa jagada loomise õigusega",
-    "Can’t set expiration date more than %s days in the future" : "Ei sa määrata aegumise kuupäeva rohkem kui %s päeva tulevikus",
-    "Can't read file" : "Faili lugemine ebaõnnestus",
-    "Cannot write into \"config\" directory" : "Ei saa kirjutada \"config\" kataloogi",
-    "Cannot write into \"apps\" directory" : "Ei saa kirjutada \"apps\" kataloogi!",
-    "Cannot create \"data\" directory" : "Ei suuda luua \"data\" kataloogi",
-    "Setting locale to %s failed" : "Lokaadi %s määramine ebaõnnestus.",
-    "Please install one of these locales on your system and restart your webserver." : "Palun paigalda mõni neist lokaatides oma süsteemi ning taaskäivita veebiserver.",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 on nõutav",
-    "Please upgrade your database version" : "Palun uuenda oma andmebaasi versiooni"
+    "Help" : "Abi",
+    "Unknown user" : "Tundmatu kasutaja",
+    "Oracle username and/or password not valid" : "Oracle kasutajatunnus ja/või parool pole õiged",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL kasutajatunnus ja/või parool pole õiged",
+    "Set an admin username." : "Määra admin kasutajanimi.",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud kasutajaga %s",
+    "The username is already being used" : "Kasutajanimi on juba kasutuses",
+    "Could not create user" : "Ei saanud kasutajat luua",
+    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
+    "Username contains whitespace at the beginning or at the end" : "Kasutajanime alguses või lõpus on tühik",
+    "Username must not consist of dots only" : "Kasutajanimi ei tohi koosneda ainult punktidest",
+    "User disabled" : "Kasutaja deaktiveeritud",
+    "Please upgrade your database version." : "Palun uuenda oma andmebaasi versioon",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav"
 },
 "nplurals=2; plural=(n != 1);");
