@@ -23,6 +23,7 @@ OC.L10N.register(
     "Enterprise bundle" : "Pack pour entreprise",
     "Groupware bundle" : "Pack Groupware",
     "Hub bundle" : "Pack Nextcloud Hub",
+    "Public sector bundle" : "Bundle du secteur public",
     "Social sharing bundle" : "Pack pour partage social",
     "PHP %s or higher is required." : "PHP %s ou supérieur est requis.",
     "PHP with a version lower than %s is required." : "PHP avec une version antérieure à %s est requis.",
@@ -92,7 +93,7 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'application « %s » ne peut être installée car elle n'est pas compatible avec cette version du serveur.",
     "__language_name__" : "Français",
     "This is an automatically sent email, please do not reply." : "Ceci est un e-mail envoyé automatiquement, veuillez ne pas y répondre.",
-    "Help" : "Aide",
+    "Help & privacy" : "Aide & confidentialité",
     "Appearance and accessibility" : "Apparence et accessibilité",
     "Apps" : "Applications",
     "Personal settings" : "Paramètres personnels",
@@ -147,7 +148,7 @@ OC.L10N.register(
     "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
     "Files cannot be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
     "Files cannot be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
-    "Expiration date is in the past" : "La date d'expiration est dans le passé",
+    "Expiration date is in the past" : "La date d’expiration est dans le passé",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossible de définir la date d'expiration à dans plus de %n jour","Impossible de définir la date d'expiration à dans plus de %n jours","Impossible de définir la date d'expiration à dans plus de %n jours"],
     "Sharing is only allowed with group members" : "Le partage n'est que possible qu'avec les membres du groupe",
     "Sharing %s failed, because this item is already shared with the account %s" : "Impossible de partager %s car il est déjà partagé avec le compte %s",
@@ -258,7 +259,7 @@ OC.L10N.register(
     "Could not obtain lock type %d on \"%s\"." : "Impossible d'obtenir le verrouillage de type %d sur « %s ».",
     "Storage unauthorized. %s" : "Espace de stockage non autorisé. %s",
     "Storage incomplete configuration. %s" : "Configuration de l'espace de stockage incomplète. %s",
-    "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
+    "Storage connection error. %s" : "Erreur de connexion à l’espace stockage. %s",
     "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
     "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
     "Free prompt" : "Prompt",
@@ -266,33 +267,30 @@ OC.L10N.register(
     "Generate headline" : "Générer un titre",
     "Generates a possible headline for a text." : "Génère un titre possible pour un texte.",
     "Summarize" : "Résumer",
-    "Summarizes text by reducing its length without losing key information." : "Résume un texte en réduisant sa longueur sans perdre d'informations essentielles.",
+    "Summarizes text by reducing its length without losing key information." : "Résume un texte en réduisant sa longueur sans perdre d’informations essentielles.",
     "Extract topics" : "Extraire des thèmes",
     "Extracts topics from a text and outputs them separated by commas." : "Extrait les thèmes d'un texte et les restitue séparés par des virgules.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Les fichiers de l'application %1$s n'ont pas été remplacés correctement. Veuillez vérifier que c'est une version compatible avec le serveur.",
     "404" : "404",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utilisateur connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
     "Logged in user must be an admin or sub admin" : "L'utilisateur connecté doit être administrateur ou sous-administrateur",
     "Logged in user must be an admin" : "L'utilisateur connecté doit être un administrateur",
-    "Full name" : "Nom complet",
+    "Help" : "Aide",
     "Unknown user" : "Utilisateur inconnu",
     "Enter the database username and name for %s" : "Entrez le nom d'utilisateur et le nom de la base de données pour %s",
     "Enter the database username for %s" : "Entrez le nom d'utilisateur de la base de données pour %s",
-    "MySQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base MySQL non valide(s)",
+    "MySQL username and/or password not valid" : "Nom d’utilisateur et/ou mot de passe de la base MySQL non valide(s)",
     "Oracle username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base Oracle non valide(s)",
     "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
     "Set an admin username." : "Spécifiez un nom d'utilisateur pour l'administrateur.",
     "Sharing %s failed, because this item is already shared with user %s" : "Impossible de partager %s car il est déjà partagé avec l'utilisateur %s",
-    "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
+    "The username is already being used" : "Ce nom d’utilisateur est déjà utilisé",
     "Could not create user" : "Impossible de créer l'utilisateur",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", espaces et \"_.@-'\"",
-    "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
-    "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
+    "A valid username must be provided" : "Un nom d’utilisateur valide doit être saisi",
+    "Username contains whitespace at the beginning or at the end" : "Le nom d’utilisateur contient des espaces au début ou à la fin",
     "Username must not consist of dots only" : "Le nom d'utilisateur ne doit pas être composé uniquement de points",
-    "Username is invalid because files already exist for this user" : "Ce nom d'utilisateur n'est pas valide car des fichiers existent déjà pour cet utilisateur",
+    "Username is invalid because files already exist for this user" : "Ce nom d’utilisateur n’est pas valide car des fichiers existent déjà pour cet utilisateur",
     "User disabled" : "Utilisateur désactivé",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 au moins est requis. Actuellement %s est installé.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Pour régler ce problème, mettez à jour votre version de libxml2 et redémarrez votre serveur web.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 requis.",
     "Please upgrade your database version." : "Veuillez mettre à jour votre gestionnaire de base de données.",
     "Your data directory is readable by other users." : "Votre répertoire est lisible par d'autres utilisateurs.",
