@@ -5,9 +5,10 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s konfiguráciou.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Alebo, ak preferujete ponechať súbor config.php iba na čítanie, nastavte v ňom parameter \"config_is_read_only\" na true.",
     "See %s" : "Pozri %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Súbory aplikácie %1$s neboli správne nahradené. Uistite sa, že to je verzia kompatibilná so serverom.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplikácia %1$s nie je prítomná alebo má nekompatibilnú verziu s týmto serverom. Prosím, skontrolujte adresár aplikácií.",
     "Sample configuration detected" : "Detekovaná bola vzorová konfigurácia",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Zistilo sa, že konfigurácia bola skopírovaná zo vzorových súborov. Takáto konfigurácia nie je podporovaná a môže poškodiť vašu inštaláciu. Prečítajte si dokumentáciu pred vykonaním zmien v config.php",
+    "The page could not be found on the server." : "Stránka nebola nájdená na serveri.",
     "%s email verification" : "%s overenie e-mailu",
     "Email verification" : "Overenie e-mailu",
     "Click the following button to confirm your email." : "Kliknite na tlačítko pre potvrdenie vašeho e-mailu.",
@@ -22,6 +23,7 @@ OC.L10N.register(
     "Enterprise bundle" : "Enterprise balíček",
     "Groupware bundle" : "Balíček groupware",
     "Hub bundle" : "Sada pre centrum aktivity (hub)",
+    "Public sector bundle" : "Balík pre verejný sektor",
     "Social sharing bundle" : "Balíček sociálneho zdieľania",
     "PHP %s or higher is required." : "Požadovaná verzia PHP %s alebo vyššia.",
     "PHP with a version lower than %s is required." : "PHP je vyžadované vo vyššej verzii ako %s.",
@@ -35,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Podporované sú nasledujúce platformy: %s",
     "Server version %s or higher is required." : "Je vyžadovaná verzia servera %s alebo vyššia.",
     "Server version %s or lower is required." : "Je vyžadovaná verzia servera %s alebo nižšia.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prihlásený používateľ musí byť správcom, podadministrátorom alebo musí mať špeciálne právo na prístup k tomuto nastaveniu",
-    "Logged in user must be an admin or sub admin" : "Prihlásený používateľ musí byť správcom alebo správcom pre čiastkovú oblasť.",
-    "Logged in user must be an admin" : "Prihlásený používateľ musí byť správca",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Prihlásený účet musí byť správcom, podadministrátorom alebo musí mať špeciálne právo na prístup k tomuto nastaveniu.",
+    "Logged in account must be an admin or sub admin" : "Prihlásený účet musí byť správcom alebo sub správcom.",
+    "Logged in account must be an admin" : "Prihlásený účet musí byť správcom",
     "Wiping of device %s has started" : "Začalo sa mazanie zariadenia %s",
     "Wiping of device »%s« has started" : "Začalo sa mazanie zariadenia „%s“",
     "»%s« started remote wipe" : "„%s“ začalo mazanie na diaľku",
@@ -54,7 +56,9 @@ OC.L10N.register(
     "Unknown filetype" : "Neznámy typ súboru",
     "Invalid image" : "Chybný obrázok",
     "Avatar image is not square" : "Obrázok avatara nie je štvorcový",
+    "Files" : "Súbory",
     "View profile" : "Zobraziť profil",
+    "Local time: %s" : "Miestny čas: %s",
     "today" : "dnes",
     "tomorrow" : "zajtra",
     "yesterday" : "včera",
@@ -89,7 +93,6 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikácia \"%s\" nie je kompatibilná s verziou servera, preto nemôže byť nainštalovaná.",
     "__language_name__" : "Slovenčina",
     "This is an automatically sent email, please do not reply." : "Toto je automaticky odosielaný e-mail, prosím, neodpovedajte.",
-    "Help" : "Pomoc",
     "Appearance and accessibility" : "Vzhľad a správanie",
     "Apps" : "Aplikácie",
     "Personal settings" : "Osobné nastavenia",
@@ -99,6 +102,8 @@ OC.L10N.register(
     "Users" : "Používatelia",
     "Email" : "E-mail",
     "Mail %s" : "Pošta pre %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "Zobraziť %s na fediverse",
     "Phone" : "Telefón",
     "Call %s" : "Zavolať %s",
     "Twitter" : "Twitter",
@@ -108,24 +113,26 @@ OC.L10N.register(
     "Address" : "Adresa",
     "Profile picture" : "Profilový obrázok",
     "About" : "O aplikácii",
-    "Full name" : "Celé meno",
-    "Headline" : "Titulok",
+    "Display name" : "Zobrazované meno",
+    "Headline" : "Titul",
     "Organisation" : "Organizácia",
     "Role" : "Rola",
-    "Unknown user" : "Neznámy používateľ",
+    "Unknown account" : "Neznámy účet",
     "Additional settings" : "Ďalšie nastavenia",
-    "Enter the database username and name for %s" : "Zadajte užívateľské meno a názov databázy pre %s",
-    "Enter the database username for %s" : "Zadajte užívateľské meno databázy pre %s",
+    "Enter the database Login and name for %s" : "Zadajte prihlasovacie meno a názov databázy pre %s",
+    "Enter the database Login for %s" : "Zadajte prihlasovacie meno databázy pre %s",
     "Enter the database name for %s" : "Zadajte názov databázy pre %s",
     "You cannot use dots in the database name %s" : "V názve databázy %s nemôžete používať bodky",
-    "MySQL username and/or password not valid" : "Neplatné užívateľské meno a/alebo heslo do MySQL",
+    "MySQL Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo do MySQL je neplatné",
     "You need to enter details of an existing account." : "Musíte zadať údaje existujúceho účtu.",
     "Oracle connection could not be established" : "Nie je možné pripojiť sa k Oracle",
-    "Oracle username and/or password not valid" : "Používateľské meno a/alebo heslo pre Oracle databázu je neplatné",
-    "PostgreSQL username and/or password not valid" : "Používateľské meno a/alebo heslo pre PostgreSQL databázu je neplatné",
+    "Oracle Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre Oracle databázu je neplatné",
+    "PostgreSQL Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre PostgreSQL databázu je neplatné",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použite ho na vlastné riziko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Pre dosiahnutie najlepších výsledkov, prosím zvážte použitie GNU/Linux servera.",
-    "Set an admin username." : "Zadajte používateľské meno administrátora.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
+    "Set an admin Login." : "Nastaviť prihlasovacie meno administrátora.",
     "Set an admin password." : "Zadajte heslo administrátora.",
     "Cannot create or write into the data directory %s" : "Nemožno vytvoriť alebo zapisovať do priečinka dát %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend pre sprístupnenie %s musí implementovať rozhranie OCP\\Share_Backend",
@@ -143,11 +150,13 @@ OC.L10N.register(
     "Expiration date is in the past" : "Dátum konca platnosti je v minulosti",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nie je možné nastaviť dátum konca platnosti viac ako %s deň v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti"],
     "Sharing is only allowed with group members" : "Zdieľanie je možné iba s členmi skupiny",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sprístupnenie %s zlyhalo, táto položka už je používateľovi %s zozdieľaná",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Zdieľanie %s zlyhalo, pretože táto položka už je užívateľovi %s zozdieľaná.",
     "%1$s shared »%2$s« with you" : "%1$s vám sprístupnil »%2$s«",
     "%1$s shared »%2$s« with you." : "%1$s vám sprístupnil »%2$s«.",
     "Click the button below to open it." : "Pre otvorenie klienta kliknite na tlačítko nižšie.",
     "The requested share does not exist anymore" : "Požadované sprístupnenie už neexistuje",
+    "The requested share comes from a disabled user" : "Požadované zdieľanie pochádza od zakázaného užívateľa.",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Bol dosiahnutý limit používateľov a používateľ nebol vytvorený. Pozrite sa do upozornení pre viac informácií.",
     "Could not find category \"%s\"" : "Nemožno nájsť danú kategóriu \"%s\"",
     "Sunday" : "Nedeľa",
     "Monday" : "Pondelok",
@@ -194,15 +203,15 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "V mene používateľa je možné použiť iba nasledovné znaky: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
-    "A valid username must be provided" : "Musíte zadať platné používateľské meno",
-    "Username contains whitespace at the beginning or at the end" : "Meno používateľa obsahuje na začiatku, alebo na konci medzeru",
-    "Username must not consist of dots only" : "Používateľské meno sa nesmie skladať len z bodiek",
-    "Username is invalid because files already exist for this user" : "Používateľské meno je neplatné, pretože pre tohto používateľa už existujú súbory",
     "A valid password must be provided" : "Musíte zadať platné heslo",
-    "The username is already being used" : "Meno používateľa je už použité",
-    "Could not create user" : "Nepodarilo sa vytvoriť používateľa",
-    "User disabled" : "Používateľ zakázaný",
+    "The Login is already being used" : "Prihlasovacie meno sa už používa",
+    "Could not create account" : "Nepodarilo sa vytvoriť účet",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V prihlasovacom mene je možné použiť iba nasledovné znaky: \"a-z\", \"A-Z\", \"0-9\", medzery a \"_.@-'\"",
+    "A valid Login must be provided" : "Musíte zadať platné prihlasovacie meno.",
+    "Login contains whitespace at the beginning or at the end" : "Prihlasovacie meno obsahuje medzeru na začiatku alebo na konci.",
+    "Login must not consist of dots only" : "Prihlasovacie meno sa nesmie skladať len z bodiek",
+    "Login is invalid because files already exist for this user" : "Prihlasovacie meno je neplatné, pretože pre tohto užívateľa už existujú súbory.",
+    "Account disabled" : "Účet bol zakázaný",
     "Login canceled by app" : "Prihlásenie bolo zrušené aplikáciou",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikáciu \"%1$s\" nie je možné inštalovať, pretože nie sú splnené nasledovné závislosti: %2$s",
     "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
@@ -229,18 +238,14 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Použitím týchto nastavení v php.ini dovolí Nextcloudu sa znova spustiť",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastavený na <code>%s</code>, namiesto predpokladanej hodnoty <code>0</code>.",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vyžadovaná verzia libxml2 je 2.7.0 a vyššia. Momentálne je nainštalovaná verzia %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Pre vyriešenie tohto problému aktualizujte prosím verziu libxml2 a reštartujte webový server.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je zjavne nastavené, aby odstraňovalo bloky vloženej dokumentácie. To zneprístupní niekoľko základných aplikácií.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "To je pravdepodobne spôsobené cache/akcelerátorom ako napr. Zend OPcache alebo eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly boli nainštalované, ale stále sa tvária, že chýbajú?",
     "Please ask your server administrator to restart the web server." : "Prosím, požiadajte administrátora vášho servera o reštartovanie webového servera.",
     "The required %s config variable is not configured in the config.php file." : "Požadovaná konfiguračná premenná %s nie je nakonfigurovaná v súbore config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Požiadajte správcu servera, aby skontroloval konfiguráciu Nextcloud.",
-    "PostgreSQL >= 9 required." : "Vyžadované PostgreSQL >= 9.",
-    "Please upgrade your database version." : "Prosím, aktualizujte verziu svojej databázy.",
-    "Your data directory is readable by other users." : "Váš priečinok s dátami je prístupný na čítanie ostatným užívateľom.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Prosím, zmeňte oprávnenia na 0770, aby tento priečinok nemohli ostatní používatelia otvoriť.",
+    "Your data directory is readable by other people." : "Váš adresár s dátami je prístupný na čítanie ostatným ľuďom.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Prosím, zmeňte oprávnenia na 0770, aby tento adresár nemohli ostatní ľudia otvoriť.",
     "Your data directory must be an absolute path." : "Priečinok s dátami musí byť zadaný ako absolútna cesta.",
     "Check the value of \"datadirectory\" in your configuration." : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii.",
     "Your data directory is invalid." : "Priečinok pre dáta je neplatný.",
@@ -256,31 +261,38 @@ OC.L10N.register(
     "Storage connection error. %s" : "Chyba pripojenia k úložisku. %s",
     "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
     "Storage connection timeout. %s" : "Vypršanie pripojenia k úložisku. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s nastaveniami.",
-    "%s enter the database username and name." : "%s zadajte používateľské meno a meno databázy",
-    "%s enter the database username." : "Zadajte používateľské meno %s databázy.",
-    "%s enter the database name." : "Zadajte názov databázy pre %s databázy.",
-    "%s you may not use dots in the database name" : "V názve databázy %s nemôžete používať bodky",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
-    "The user limit has been reached and the user was not created." : "Bol dosiahnutý limit používateľov a používateľ nebol vytvorený.",
-    "Cannot read file" : "Nemožno čítať súbor.",
-    "Cannot write into \"config\" directory" : "Nie je možné zapisovať do priečinka \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do adresára s konfiguráciou. Viď %s",
-    "Cannot write into \"apps\" directory" : "Nie je možné zapisovať do priečinka \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s aplikáciami alebo vypnutím katalógu s aplikáciami v súbore s nastaveniami.",
-    "Cannot create \"data\" directory" : "Nie je možné vytvoriť priečinok \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového adresára. Viď %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Oprávnenia je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového priečinka. Viď %s.",
-    "Setting locale to %s failed" : "Nastavenie locale na %s zlyhalo",
-    "Please install one of these locales on your system and restart your webserver." : "Prosím, nainštalujte si aspoň jeden z týchto jazykov so svojho systému a reštartujte webserver.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastavený na \"%s\", namiesto predpokladanej hodnoty \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini",
-    "PostgreSQL >= 9 required" : "Vyžadované PostgreSQL >= 9",
-    "Please upgrade your database version" : "Prosím, aktualizujte verziu svojej databázy",
-    "Your data directory is readable by other users" : "Váš priečinok s dátami je prístupný na čítanie ostatným používateľom",
-    "Your data directory must be an absolute path" : "Priečinok s dátami musí byť zadaný ako absolútna cesta",
-    "Check the value of \"datadirectory\" in your configuration" : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii",
-    "Your data directory is invalid" : "Priečinok s dátami je neplatný"
+    "Free prompt" : "Bezplatný formulár",
+    "Runs an arbitrary prompt through the language model." : "Spúšťa ľubovoľný príkaz cez jazykový model.",
+    "Generate headline" : "Generovať nadpis",
+    "Generates a possible headline for a text." : "Generuje možný nadpis pre text.",
+    "Summarize" : "Zhrnutie",
+    "Summarizes text by reducing its length without losing key information." : "Zhrňuje text tým, že znižuje jeho dĺžku bez straty kľúčových informácií.",
+    "Extract topics" : "Extrahovať témy",
+    "Extracts topics from a text and outputs them separated by commas." : "Extrahuje témy z textu a vypisuje ich oddelené čiarkami.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prihlásený používateľ musí byť správcom, podadministrátorom alebo musí mať špeciálne právo na prístup k tomuto nastaveniu",
+    "Logged in user must be an admin or sub admin" : "Prihlásený používateľ musí byť správcom alebo správcom pre čiastkovú oblasť.",
+    "Logged in user must be an admin" : "Prihlásený používateľ musí byť správca",
+    "Help" : "Pomoc",
+    "Unknown user" : "Neznámy používateľ",
+    "Enter the database username and name for %s" : "Zadajte užívateľské meno a názov databázy pre %s",
+    "Enter the database username for %s" : "Zadajte užívateľské meno databázy pre %s",
+    "MySQL username and/or password not valid" : "Neplatné užívateľské meno a/alebo heslo do MySQL",
+    "Oracle username and/or password not valid" : "Používateľské meno a/alebo heslo pre Oracle databázu je neplatné",
+    "PostgreSQL username and/or password not valid" : "Používateľské meno a/alebo heslo pre PostgreSQL databázu je neplatné",
+    "Set an admin username." : "Zadajte používateľské meno administrátora.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Sprístupnenie %s zlyhalo, táto položka už je používateľovi %s zozdieľaná",
+    "The username is already being used" : "Meno používateľa je už použité",
+    "Could not create user" : "Nepodarilo sa vytvoriť používateľa",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V mene užívateľa je možné použiť iba nasledovné znaky: \"a-z\", \"A-Z\", \"0-9\", medzery a \"_.@-'\"",
+    "A valid username must be provided" : "Musíte zadať platné používateľské meno",
+    "Username contains whitespace at the beginning or at the end" : "Meno používateľa obsahuje na začiatku, alebo na konci medzeru",
+    "Username must not consist of dots only" : "Používateľské meno sa nesmie skladať len z bodiek",
+    "Username is invalid because files already exist for this user" : "Používateľské meno je neplatné, pretože pre tohto používateľa už existujú súbory",
+    "User disabled" : "Používateľ zakázaný",
+    "PostgreSQL >= 9 required." : "Vyžadované PostgreSQL >= 9.",
+    "Please upgrade your database version." : "Prosím, aktualizujte verziu svojej databázy.",
+    "Your data directory is readable by other users." : "Váš priečinok s dátami je prístupný na čítanie ostatným užívateľom.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Prosím, zmeňte oprávnenia na 0770, aby tento priečinok nemohli ostatní používatelia otvoriť."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
