@@ -2,10 +2,18 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Не могу да уписујем у „config“ директоријум!",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Ово обично може да се поправи тако што се веб серверу дозволи упис у config директоријум.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Али, ако радије желите да фајл config.php може само да се чита, онда у њему поставите опцију „config_is_read_only” на true.",
     "See %s" : "Погледајте %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Фајлови апликације „%1$s“ нису правилно замењени. Проверите да ли је верзија компатибилна са сервером.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Не постоји апликација %1$s или њена верзија није компатибилна са овим сервером. Молимо вас да проверите директоријум са апликацијама.",
     "Sample configuration detected" : "Откривен је пример подешавања",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Откривено је да је прекопиран пример подешавања. Ово може покварити инсталацију и није подржано. Прочитајте документацију пре вршења промена у фајлу config.php",
+    "The page could not be found on the server." : "На серверу не може да се пронађе ова страница.",
+    "%s email verification" : "%s потврђивање и-мејла",
+    "Email verification" : "Потврђивање и-мејла",
+    "Click the following button to confirm your email." : "Кликните на наредно дугме да потврдите свој и-мејл.",
+    "Click the following link to confirm your email." : "Кликните на следећи линк да потврдите свој и-мејл.",
+    "Confirm your email" : "Потврдите свој и-мејл",
     "Other activities" : "Остале активности",
     "%1$s and %2$s" : "%1$s и %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
@@ -15,6 +23,7 @@ OC.L10N.register(
     "Enterprise bundle" : "Комплет за предузећа",
     "Groupware bundle" : "Комплет за радне тимове",
     "Hub bundle" : "Чвориште пакета",
+    "Public sector bundle" : "Пакет за јавни сектор",
     "Social sharing bundle" : "Комплет за друштвене мреже",
     "PHP %s or higher is required." : "Потребан је PHP %s или новији.",
     "PHP with a version lower than %s is required." : "Потребна је PHP верзија старија од верзије %s.",
@@ -28,8 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Подржане су следеће платформе: %s",
     "Server version %s or higher is required." : "Потребна је верзија сервера %s или виша.",
     "Server version %s or lower is required." : "Потребна је верзија сервера %s или нижа.",
-    "Logged in user must be an admin or sub admin" : "Пријављени корисник мора бити администратор или подадминистратор",
-    "Logged in user must be an admin" : "Пријављени корисник мора бити администратор",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Пријављени налог мора бити админ, подадмин или мора да поседује специјално право да приступи овом подешавању",
+    "Logged in account must be an admin or sub admin" : "Пријављени налог мора бити админ или подадмин",
+    "Logged in account must be an admin" : "Пријављени налог мора бити админ",
     "Wiping of device %s has started" : "Започето брисање уређаја %s",
     "Wiping of device »%s« has started" : "Удаљено брисање уређаја „%s“ је почело",
     "»%s« started remote wipe" : "„%s“ је започео удаљено брисање",
@@ -46,7 +56,9 @@ OC.L10N.register(
     "Unknown filetype" : "Непознат тип фајла",
     "Invalid image" : "Неисправна слика",
     "Avatar image is not square" : "Слика аватара није квадратна",
+    "Files" : "Фајлови",
     "View profile" : "Погледај профил",
+    "Local time: %s" : "Локално време: %s",
     "today" : "данас",
     "tomorrow" : "сутра",
     "yesterday" : "јуче",
@@ -69,6 +81,9 @@ OC.L10N.register(
     "Empty file" : "Празан фајл",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул са идентификацијом: %s не постоји. Омогућите га у подешавањима апликација или контактирајте администратора.",
     "File already exists" : "Фајл већ постоји",
+    "Invalid path" : "Неисправна путања",
+    "Failed to create file from template" : "Није успело креирање фајла из шаблона",
+    "Templates" : "Шаблони",
     "File name is a reserved word" : "Назив фајла је резервисана реч",
     "File name contains at least one invalid character" : "Назив фајла садржи бар један недозвољен знак",
     "File name is too long" : "Назив фајла је предугачак",
@@ -78,33 +93,49 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Апликација \"%s\" не може бити инсталирана јер није компатибилна са овом верзијом сервера.",
     "__language_name__" : "Српски",
     "This is an automatically sent email, please do not reply." : "Ово је аутоматски генерисана порука, не одговарајте на њу.",
-    "Help" : "Помоћ",
+    "Help & privacy" : "Помоћ и приватност",
+    "Appearance and accessibility" : "Изглед и приступачност",
     "Apps" : "Апликације",
+    "Personal settings" : "Лична подешавања",
+    "Administration settings" : "Административна подешавања",
     "Settings" : "Поставке",
     "Log out" : "Одјава",
     "Users" : "Корисници",
     "Email" : "Е-пошта",
+    "Mail %s" : "Пошта %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "Погледај %s на fediverse",
     "Phone" : "Телефон",
+    "Call %s" : "Позив %s",
     "Twitter" : "Твитер",
+    "View %s on Twitter" : "Погледај %s на Твитеру",
     "Website" : "Веб страна",
+    "Visit %s" : "Посети %s",
     "Address" : "Адреса",
     "Profile picture" : "Слика профила",
     "About" : "О програму",
-    "Full name" : "Пуно име",
+    "Display name" : "Име за приказ",
     "Headline" : "Наслов",
-    "Unknown user" : "Непознат корисник",
+    "Organisation" : "Организација",
+    "Role" : "Улога",
+    "Unknown account" : "Непознати налог",
     "Additional settings" : "Додатне поставке",
-    "MySQL username and/or password not valid" : "MySQL корисничко име и/или лозинка нису исправни",
+    "Enter the database Login and name for %s" : "Унесите име за пријаву на базу података и назив за %s",
+    "Enter the database Login for %s" : "Унесите име за пријаву на базу података за %s",
+    "Enter the database name for %s" : "Унесите назив базе података за %s",
+    "You cannot use dots in the database name %s" : "У називу базе података не можете да користите тачке %s",
+    "MySQL Login and/or password not valid" : "MySQL име за пријаву и/или лозинка нису исправни",
     "You need to enter details of an existing account." : "Потребно је да унесете детаље постојећег налога.",
     "Oracle connection could not be established" : "Веза са базом података Oracle не може бити успостављена",
-    "Oracle username and/or password not valid" : "Oracle корисничко име и/или лозинка нису исправни",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничко име и/или лозинка нису исправни",
+    "Oracle Login and/or password not valid" : "Oracle име за пријаву и/или лозинка нису исправни",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL име за пријаву и/или лозинка нису исправни",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Мек ОС Икс није подржан и %s неће радити исправно на овој платформи. Користите га на сопствени ризик!",
     "For the best results, please consider using a GNU/Linux server instead." : "За најбоље резултате, размотрите употребу ГНУ/Линукс сервера.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Изгледа да %s ради у 32-битном PHP окружењу а open_basedir је подешен у php.ini фајлу. То може довести до проблема са фајловима већим од 4 GB, те стога није препоручљиво.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Уклоните open_basedir поставку из php.ini фајла или пређите на 64-битни PHP.",
-    "Set an admin username." : "Поставите име за администратора.",
+    "Set an admin Login." : "Поставите име за пријаву админа.",
     "Set an admin password." : "Поставите лозинку за администратора.",
+    "Cannot create or write into the data directory %s" : "Не може да се креира или уписује у директоријум са подацима %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Позадина дељења %s мора користити корисничко окружење OCP\\Share_Backend",
     "Sharing backend %s not found" : "Позадина за дељење %s није пронађена",
     "Sharing backend for %s not found" : "Позадина за дељење за %s није пронађена",
@@ -115,12 +146,18 @@ OC.L10N.register(
     "%1$s via %2$s" : "%1$s преко %2$s",
     "You are not allowed to share %s" : "Није вам дозвољено да делите %s",
     "Cannot increase permissions of %s" : "Не могу да повећам привилегије за %s",
+    "Files cannot be shared with delete permissions" : "Фајлови не могу да се деле са дозволама за брисање",
+    "Files cannot be shared with create permissions" : "Фајлови не могу да се деле са дозволама за креирање",
     "Expiration date is in the past" : "Датум истека је у прошлости",
-    "Sharing %s failed, because this item is already shared with user %s" : "Дељење %s није успело зато што се ова ставка већ дели са корисником %s",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Датум истека не може да се постави више од %n дан у будућност","Датум истека не може да се постави више од %n дана у будућност","Датум истека не може да се постави више од %n дана у будућност"],
+    "Sharing is only allowed with group members" : "Дељење је дозвољено само са члановима групе",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Дељење %s није успело зато што се ова ставка већ дели са налогом %s",
     "%1$s shared »%2$s« with you" : "%1$s је поделио „%2$s“ са Вама",
     "%1$s shared »%2$s« with you." : "%1$s је поделио „%2$s“ са Вама.",
     "Click the button below to open it." : "Кликните дугме испод да га отворите.",
     "The requested share does not exist anymore" : "Захтевано дељење више не постоји",
+    "The requested share comes from a disabled user" : "Захтевано дељење долази од искљученог корисника",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Корисник није креиран јер је достигнуто ограничење броја корисника. За више детаља, погледајте своја обавештења.",
     "Could not find category \"%s\"" : "Не могу да пронађем категорију „%s“.",
     "Sunday" : "Недеља",
     "Monday" : "Понедељак",
@@ -167,35 +204,52 @@ OC.L10N.register(
     "Oct." : "Окт.",
     "Nov." : "Нов.",
     "Dec." : "Дец.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "У корисничком имену су дозвољени само следећи карактери: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
-    "A valid username must be provided" : "Морате унети исправно корисничко име",
-    "Username contains whitespace at the beginning or at the end" : "Корисничко име садржи белине на почетку или на крају",
-    "Username must not consist of dots only" : "Корисничко име не могу бити само тачке",
-    "Username is invalid because files already exist for this user" : "Корисничко име није исправно пошто већ постоје фајлови за овог корисника",
     "A valid password must be provided" : "Морате унети исправну лозинку",
-    "The username is already being used" : "Корисничко име се већ користи",
-    "Could not create user" : "Не могу да направим корисника",
-    "User disabled" : "Корисник онемогућен",
+    "The Login is already being used" : "Ово име за пријаву се већ користи",
+    "Could not create account" : "Налог није могао да се креира ",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "У имену за пријаву су дозвољени само следећи карактери: „a-z”, „A-Z”, „0-9”, размаци и „_.@-'",
+    "A valid Login must be provided" : "Морате да унесете исправно име за пријаву",
+    "Login contains whitespace at the beginning or at the end" : "Име за пријаву садржи белине на почетку или на крају",
+    "Login must not consist of dots only" : "Име за пријаву не може да се састоји само од тачака",
+    "Login is invalid because files already exist for this user" : "Име за пријаву није исправно пошто већ постоје фајлови овог корисника",
+    "Account disabled" : "Налог је искључен",
     "Login canceled by app" : "Пријава отказана од стране апликације",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликација „%1$s“ не може бити инсталирана јер следеће зависности нису испуњене: %2$s",
     "a safe home for all your data" : "сигурно место за све Ваше податке",
     "File is currently busy, please try again later" : "Фајл је тренутно заузет, покушајте поново касније",
+    "Cannot download file" : "Фајл не може да се преузме",
     "Application is not enabled" : "Апликација није укључена",
     "Authentication error" : "Грешка при провери идентитета",
     "Token expired. Please reload page." : "Жетон је истекао. Поново учитајте страницу.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Нема драјвера базе података (скулајт, мајскул или постгрескул).",
+    "Cannot write into \"config\" directory." : "Не може да се упише у „config директоријум.",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у config директоријум. Погледајте %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом. Погледајте %s",
+    "Cannot write into \"apps\" directory." : "Не може да се упише у „apps” директоријум.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у apps директоријум или тако што се искључи Продавница апликација у config фајлу.",
+    "Cannot create \"data\" directory." : "Не може да се креира „data” директоријум.",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у корени директоријум. Погледајте %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Проблем са дозволама обично може да се поправи тако што се веб серверу дозволи право уписа у корени директоријум. Погледајте %s.",
+    "Your data directory is not writable." : "У ваш директоријум са подацима не може да се упише.",
+    "Setting locale to %s failed." : "Није успело постављање локалитета на %s.",
+    "Please install one of these locales on your system and restart your web server." : "Молимо вас да на свој систем инсталирате један од следећих локалитета и поново покренете свој веб сервер.",
     "PHP module %s not installed." : "PHP модул %s није инсталиран.",
     "Please ask your server administrator to install the module." : "Замолите администратора вашег сервера да инсталира тај модул.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставка „%s“ није постављена на „%s“.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Некстклауд ће прорадити поново када прилагодите ово подашавање у php.ini фајлу",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Потребан је бар libxml2 2.7.0. Тренутно је инсталиран %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Да поправите овај проблем, ажурирајте верзију библиотеке libxml2 и рестартујте веб сервер.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> је постављено на <code>%s</code> уместо на очекивану вредност <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Да бисте исправили овај проблем, поставите <code>mbstring.func_overload</code> на <code>0</code> у свом php.ini фајлу.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP је очигледно подешен да склања уметнуте doc блокове. То ће учинити неколико кључних апликација недоступним.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модули су инсталирани али се и даље воде као недостајући?",
     "Please ask your server administrator to restart the web server." : "Замолите вашег администратора сервера да поново покрене веб сервер.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Промените дозволе у 0770 како директоријуми не би могли бити излистани од стране других корисника.",
+    "The required %s config variable is not configured in the config.php file." : "У config.php фајлу није подешена потребна config променљива %s.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Молимо вас да замолите свог систем администратора да провери Некстклауд конфигурацију.",
+    "Your data directory is readable by other people." : "Ваш директоријум са подацима могу да читају друге особе.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Молимо вас да промените дозволе у 0770 тако да друге особе немају право да прикажу његов садржај.",
+    "Your data directory must be an absolute path." : "Ваш директоријум са подацима мора бити апсолутна путања.",
+    "Check the value of \"datadirectory\" in your configuration." : "Проверите вредност „datadirectory” у својој конфигурацији.",
+    "Your data directory is invalid." : "Ваш директоријум са подацима је неисправан.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Уверите се да фајл \".ocdata\" постоји у корену директоријума са подацима.",
     "Action \"%s\" not supported or implemented." : "Радња \"%s\" није подржана или имплементирана.",
     "Authentication failed, wrong token or provider ID given" : "Неуспела провера идентитета, добијен погрешан токен или ID провајдера",
@@ -208,26 +262,38 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка приликом повезивања на складиште. %s",
     "Storage is temporarily not available" : "Складиште привремено није  доступно",
     "Storage connection timeout. %s" : "Истекло је време за повезивање на складиште. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Ово се обично може средити давањем права веб серверу да пише у директоријум са подешавањима.",
-    "%s enter the database username and name." : "%s унеси корисничко име базе података и име.",
-    "%s enter the database username." : "%s унеси корисничко име базе података.",
-    "%s enter the database name." : "%s унеси име базе података.",
-    "%s you may not use dots in the database name" : "%s не можете користити тачке у имену базе података",
-    "Cannot write into \"config\" directory" : "Не могу уписивати у директоријуму „config“",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ово се обично може средити давањем права писања веб серверу за директоријум са подешавањима. Погледајте %s",
-    "Cannot write into \"apps\" directory" : "Не могу уписивати у директоријуму „apps“",
-    "Cannot create \"data\" directory" : "Не могу да направим \"data\" директоријум",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ово се обично може поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Привилегије се обично могу поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
-    "Setting locale to %s failed" : "Постављање локалитета на %s није успело",
-    "Please install one of these locales on your system and restart your webserver." : "Инсталирајте неки од ових локалитета на ваш систем и поново покрените веб сервер.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload је постављено на „%s“ уместо на очекивану вредност „0“",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Да би решили овај проблем поставите <code>mbstring.func_overload</code> на <code>0</code> у фајлу php.ini",
-    "PostgreSQL >= 9 required" : "Захтеван је ПостгреСкул >= 9",
-    "Please upgrade your database version" : "Надоградите ваше издање базе",
-    "Your data directory is readable by other users" : "Директоријум са подацима је читљив од стране других корисника система",
-    "Your data directory must be an absolute path" : "Директоријум са подацима мора бити апсолутна путања",
-    "Check the value of \"datadirectory\" in your configuration" : "Проверите податак за \"datadirectory\" у вашој конфигурацији",
-    "Your data directory is invalid" : "Директоријум са подацима није исправан"
+    "Free prompt" : "Произвољни захтев",
+    "Runs an arbitrary prompt through the language model." : "Извршава произвољни захтев кроз језички модел.",
+    "Generate headline" : "Генериши линију наслова",
+    "Generates a possible headline for a text." : "Генерише могућу насловну линију текста.",
+    "Summarize" : "Резимирај",
+    "Summarizes text by reducing its length without losing key information." : "Резимира текст тако што га скраћује без губитка кључних информација.",
+    "Extract topics" : "Издвој теме",
+    "Extracts topics from a text and outputs them separated by commas." : "Издваја теме из текста и исписује их раздвојене запетама.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Пријављени корисник мора бити админ, под админ или да поседује специјално право да приступи овом подешавању",
+    "Logged in user must be an admin or sub admin" : "Пријављени корисник мора бити администратор или подадминистратор",
+    "Logged in user must be an admin" : "Пријављени корисник мора бити администратор",
+    "Help" : "Помоћ",
+    "Unknown user" : "Непознат корисник",
+    "Enter the database username and name for %s" : "Унесите корисничко име базе података и назив за %s",
+    "Enter the database username for %s" : "Унесите корисничко име базе података за %s",
+    "MySQL username and/or password not valid" : "MySQL корисничко име и/или лозинка нису исправни",
+    "Oracle username and/or password not valid" : "Oracle корисничко име и/или лозинка нису исправни",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничко име и/или лозинка нису исправни",
+    "Set an admin username." : "Поставите име за администратора.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Дељење %s није успело зато што се ова ставка већ дели са корисником %s",
+    "The username is already being used" : "Корисничко име се већ користи",
+    "Could not create user" : "Не могу да направим корисника",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "У корисничком имену су дозвољени само следећи карактери: „a-z”, „A-Z”, „0-9”, размаци и „_.@-'",
+    "A valid username must be provided" : "Морате унети исправно корисничко име",
+    "Username contains whitespace at the beginning or at the end" : "Корисничко име садржи белине на почетку или на крају",
+    "Username must not consist of dots only" : "Корисничко име не могу бити само тачке",
+    "Username is invalid because files already exist for this user" : "Корисничко име није исправно пошто већ постоје фајлови за овог корисника",
+    "User disabled" : "Корисник онемогућен",
+    "PostgreSQL >= 9 required." : "Потребан је PostgreSQL >= 9.",
+    "Please upgrade your database version." : "Молимо вас да ажурирате верзију базе података.",
+    "Your data directory is readable by other users." : "Ваш директоријум са подацима могу да читају остали корисници.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Промените дозволе у 0770 како директоријуми не би могли бити излистани од стране других корисника."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
