@@ -2,9 +2,10 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Kan inte skriva till \"config\" katalogen!",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till config-katalogen.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Men, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den.",
     "See %s" : "Se %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Filerna i appen %1$s ersattes inte korrekt. Kontrollera att det är en version som är kompatibel med servern.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Appen %1$s finns inte eller har en icke-kompatibel version med denna server. Kontrollera appkatalogen.",
     "Sample configuration detected" : "Exempel-konfiguration detekterad",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har upptäckts att provkonfigurationen har kopierats. Detta kan bryta din installation och stöds inte. Läs dokumentationen innan du utför ändringar på config.php",
     "The page could not be found on the server." : "Sidan kunde inte hittas på servern.",
@@ -22,6 +23,7 @@ OC.L10N.register(
     "Enterprise bundle" : "Företagspaketet",
     "Groupware bundle" : "Gruppvarupaket",
     "Hub bundle" : "Hub-paket",
+    "Public sector bundle" : "Paket för offentlig sektor",
     "Social sharing bundle" : "Kommunikationspaket",
     "PHP %s or higher is required." : "PHP %s eller högre krävs.",
     "PHP with a version lower than %s is required." : "PHP med version lägre än %s krävs.",
@@ -35,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Följande plattformar stöds: %s",
     "Server version %s or higher is required." : "Serverversion %s eller nyare krävs.",
     "Server version %s or lower is required." : "Serverversion %s eller äldre krävs.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Inloggad användare måste vara en admin, sub-admin eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
-    "Logged in user must be an admin or sub admin" : "Inloggad användare måste vara administratör eller del-administratör",
-    "Logged in user must be an admin" : "Inloggad användare måste vara administratör",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Inloggat konto måste vara en admin, underadministratör eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
+    "Logged in account must be an admin or sub admin" : "Inloggat konto måste vara en admin eller underadministratör",
+    "Logged in account must be an admin" : "Inloggat konto måste vara admin",
     "Wiping of device %s has started" : "Rensning av enhet %s har startat",
     "Wiping of device »%s« has started" : "Rensning av enhet »%s« har startat",
     "»%s« started remote wipe" : "»%s« startade fjärrensning",
@@ -54,7 +56,9 @@ OC.L10N.register(
     "Unknown filetype" : "Okänd filtyp",
     "Invalid image" : "Ogiltig bild",
     "Avatar image is not square" : "Profilbilden är inte fyrkantig",
+    "Files" : "Filer",
     "View profile" : "Visa profil",
+    "Local time: %s" : "Lokal tid: %s",
     "today" : "idag",
     "tomorrow" : "imorgon",
     "yesterday" : "igår",
@@ -75,7 +79,7 @@ OC.L10N.register(
     "in a few seconds" : "om några sekunder",
     "seconds ago" : "sekunder sedan",
     "Empty file" : "Tom fil",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med ID: %s finns inte längre. Vänligen aktivera det i dina appinställningar eller kontakta din administratör.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulen med ID: %s finns inte. Aktivera den i appinställningar eller kontakta din administratör.",
     "File already exists" : "Filen existerar redan",
     "Invalid path" : "Ogiltig sökväg",
     "Failed to create file from template" : "Kunde skapa fil från mall",
@@ -89,7 +93,6 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan inte installeras eftersom den inte är kompatibel med den här versionen av servern.",
     "__language_name__" : "Svenska",
     "This is an automatically sent email, please do not reply." : "Detta är ett automatiskt e-postmeddelande, du kan därmed inte svara på det.",
-    "Help" : "Hjälp",
     "Appearance and accessibility" : "Utseende och tillgänglighet",
     "Apps" : "Appar",
     "Personal settings" : "Personlig information",
@@ -99,6 +102,8 @@ OC.L10N.register(
     "Users" : "Användare",
     "Email" : "E-post",
     "Mail %s" : "Skicka e-post %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "Visa %s på fediverse",
     "Phone" : "Telefon",
     "Call %s" : "Ring %s",
     "Twitter" : "Twitter",
@@ -108,20 +113,26 @@ OC.L10N.register(
     "Address" : "Adress",
     "Profile picture" : "Profilbild",
     "About" : "Om",
-    "Full name" : "Fullständigt namn",
+    "Display name" : "Visningsnamn",
     "Headline" : "Rubrik",
     "Organisation" : "Organisation",
     "Role" : "Roll",
-    "Unknown user" : "Okänd användare",
+    "Unknown account" : "Okänt konto",
     "Additional settings" : "Övriga inställningar",
-    "MySQL username and/or password not valid" : "MySQL-användarnamn och/eller lösenord är felaktigt",
+    "Enter the database Login and name for %s" : "Ange databas-inloggning och namn för %s",
+    "Enter the database Login for %s" : "Ange databas-inloggning för %s",
+    "Enter the database name for %s" : "Ange databasnamn för %s",
+    "You cannot use dots in the database name %s" : "Du kan inte använda punkter i databasnamnet %s",
+    "MySQL Login and/or password not valid" : "MySQL-inloggning och/eller lösenord är felaktigt",
     "You need to enter details of an existing account." : "Du måste ange inloggningsuppgifter av ett aktuellt konto.",
     "Oracle connection could not be established" : "Oracle-anslutning kunde inte etableras",
-    "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
+    "Oracle Login and/or password not valid" : "Oracle-inloggning och/eller lösenord är felaktigt",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL-inloggning och/eller lösenord är felaktigt",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
     "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
-    "Set an admin username." : "Ange ett användarnamn för administratören.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
+    "Set an admin Login." : "Ange en admin-inloggning.",
     "Set an admin password." : "Ange ett administratörslösenord.",
     "Cannot create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delningsgränssnittet %s måste implementera gränssnittet OCP\\Share_Backend",
@@ -132,18 +143,20 @@ OC.L10N.register(
     "»%s« added a note to a file shared with you" : "»%s« la till en kommentar till en fil delad med dig",
     "Open »%s«" : "Öppna »%s«",
     "%1$s via %2$s" : "%1$s via %2$s",
-    "You are not allowed to share %s" : "Du har inte rätt att dela %s",
+    "You are not allowed to share %s" : "Du tillåts inte att dela %s",
     "Cannot increase permissions of %s" : "Kan inte höja behörigheter av %s",
     "Files cannot be shared with delete permissions" : "Filer kan inte delas med rättighet att radera",
     "Files cannot be shared with create permissions" : "Filer kan inte delas med rättighet att skapa",
     "Expiration date is in the past" : "Utgångsdatum är i det förflutna",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan inte sätta ett utgångsdatum längre fram än %n dag","Kan inte sätta ett utgångsdatum längre fram än %n dagar"],
     "Sharing is only allowed with group members" : "Delning är endast tillåten med gruppmedlemmar",
-    "Sharing %s failed, because this item is already shared with user %s" : "Delning av %s misslyckades eftersom detta redan är delat med användaren %s",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Delning av %s misslyckades, eftersom det här objektet redan delas med kontot %s",
     "%1$s shared »%2$s« with you" : "%1$s delade »%2$s« med dig",
     "%1$s shared »%2$s« with you." : "%1$s delade »%2$s« med dig.",
     "Click the button below to open it." : "Klicka på knappen nedan för att öppna det.",
     "The requested share does not exist anymore" : "Den begärda delningen finns inte mer",
+    "The requested share comes from a disabled user" : "Den begärda delningen kommer från en inaktiverad användare",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Användaren skapades inte eftersom användargränsen har nåtts. Kontrollera dina aviseringar för att läsa mer.",
     "Could not find category \"%s\"" : "Kunde inte hitta kategorin \"%s\"",
     "Sunday" : "Söndag",
     "Monday" : "Måndag",
@@ -190,35 +203,52 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Endast följande tecken är tillåtna i användarnamnet: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
-    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
-    "Username contains whitespace at the beginning or at the end" : "Användarnamnet består av ett mellanslag i början eller i slutet",
-    "Username must not consist of dots only" : "Användarnamnet får inte innehålla enbart punkter",
-    "Username is invalid because files already exist for this user" : "Användarnamnet är ogiltigt eftersom det redan finns filer för den här användaren",
     "A valid password must be provided" : "Ett giltigt lösenord måste anges",
-    "The username is already being used" : "Användarnamnet används redan",
-    "Could not create user" : "Kunde inte skapa användare",
-    "User disabled" : "Användare inaktiverad",
+    "The Login is already being used" : "Inloggningen används redan",
+    "Could not create account" : "Kunde inte skapa konto",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Endast följande tecken är tillåtna i en inloggning: \"a-z\", \"A-Z\", \"0-9\", mellanslag och \"_.@-'\"",
+    "A valid Login must be provided" : "En giltig inloggning måste anges",
+    "Login contains whitespace at the beginning or at the end" : "Inloggningen innehåller blanksteg i början eller slutet",
+    "Login must not consist of dots only" : "Inloggningen får inte innehålla enbart punkter",
+    "Login is invalid because files already exist for this user" : "Inloggningen är ogiltigt eftersom det redan finns filer för den här användaren",
+    "Account disabled" : "Konto inaktiverat",
     "Login canceled by app" : "Inloggningen avbruten av appen",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan inte installeras eftersom följande beroenden inte är uppfyllda: %2$s",
     "a safe home for all your data" : "ett säkert hem för all din data",
     "File is currently busy, please try again later" : "Filen är för tillfället upptagen, försök igen senare",
+    "Cannot download file" : "Kan inte ladda ner fil",
     "Application is not enabled" : "Applikationen är inte aktiverad",
     "Authentication error" : "Fel vid autentisering",
     "Token expired. Please reload page." : "Token har löpt ut. Uppdatera sidan.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Inga databasdrivrutiner (sqlite, mysql, eller postgresql) installerade.",
+    "Cannot write into \"config\" directory." : "Kan inte skriva i \"config\"-katalogen.",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till config-katalogen. Se %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Eller, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den. Se %s",
+    "Cannot write into \"apps\" directory." : "Kan inte skriva till \"apps\"-katalogen.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till \"apps\"-katalogen eller stänga av appbutiken i konfigurationsfilen.",
+    "Cannot create \"data\" directory." : "Kan inte skapa \"data\"-katalog.",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Behörigheter kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s.",
+    "Your data directory is not writable." : "Din datakatalog är inte skrivbar.",
+    "Setting locale to %s failed." : "Inställning av språk till %s misslyckades.",
+    "Please install one of these locales on your system and restart your web server." : "Installera en av dessa locales på ditt system och starta om din webbserver.",
     "PHP module %s not installed." : "PHP-modulen %s är inte installerad.",
     "Please ask your server administrator to install the module." : "Be serveradministratören att installera modulen.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-inställning \"%s\" är inte inställd på \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Att ändra denna inställning i php.ini kommer göra så att Nextcloud fungerar igen",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 är det minsta som krävs. För närvarande är %s installerat.",
-    "To fix this issue update your libxml2 version and restart your web server." : "För att åtgärda detta problem uppdatera libxml2 versionen och starta om din webbserver.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> är satt till <code>%s</code> istället för förväntade värdet <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : " För att åtgärda detta problemet, sätt<code>mbstring.func_overload</code> till <code>0</code> i din php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP är tydligen inställt för att tömma \"inline doc blocks\". Detta kommer att göra flera kärnprogram otillgängliga.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Detta orsakas troligtvis av en cache/accelerator som t ex Zend OPchache eller eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har installerats, men de listas fortfarande som saknade?",
     "Please ask your server administrator to restart the web server." : "Be din serveradministratör att starta om webbservern.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare.",
+    "The required %s config variable is not configured in the config.php file." : "Den nödvändiga konfigurationsvariabeln %s är inte konfigurerad i filen config.php.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Be din serveradministratör att kontrollera Nextcloud-konfigurationen.",
+    "Your data directory is readable by other people." : "Din datakatalog kan läsas av andra användare.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare.",
+    "Your data directory must be an absolute path." : "Din datakatalog måste vara en absolut sökväg.",
+    "Check the value of \"datadirectory\" in your configuration." : "Kontrollera värdet på \"datadirectory\" i din konfiguration.",
+    "Your data directory is invalid." : "Din datakatalog är ogiltig.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Säkerställ att du har filen \".ocdata\" i huvudkatalogen för din data.",
     "Action \"%s\" not supported or implemented." : "Åtgärd \"%s\" stöds inte eller är inte implementerad.",
     "Authentication failed, wrong token or provider ID given" : "Autentisering misslyckades, felaktig token eller leverantörs-ID",
@@ -231,31 +261,36 @@ OC.L10N.register(
     "Storage connection error. %s" : "Lagringsutrymme lyckas inte ansluta. %s",
     "Storage is temporarily not available" : "Lagringsutrymme är för tillfället inte tillgängligt",
     "Storage connection timeout. %s" : "Lagringsutrymme lyckas inte ansluta \"timeout\". %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till config-katalogen.",
-    "%s enter the database username and name." : "%s ange användarnamn och namn för databasen.",
-    "%s enter the database username." : "%s ange databasanvändare.",
-    "%s enter the database name." : "%s ange databasnamn",
-    "%s you may not use dots in the database name" : "%s du får inte använda punkter i databasnamnet",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
-    "The user limit has been reached and the user was not created." : "Maximala användarantalet har uppnåtts och användaren skapades inte.",
-    "Cannot read file" : "Kan inte läsa fil",
-    "Cannot write into \"config\" directory" : "Kan inte skriva till \"config\" katalogen",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Detta kan vanligtvis åtgärda genom att ge webbservern skrivåtkomst till konfigureringsmappen. Se %s",
-    "Cannot write into \"apps\" directory" : "Kan inte skriva till \"apps\" katalogen!",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till applikationskatalogen eller stänga av appbutiken i konfigurationsfilen.",
-    "Cannot create \"data\" directory" : "Kan inte skapa \"data\"-mapp",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Detta kan vanligtvis åtgärda genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Rättigheter kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s.",
-    "Setting locale to %s failed" : "Sätta locale till %s misslyckades",
-    "Please install one of these locales on your system and restart your webserver." : "Installera en av dessa språk på ditt system och starta om webbservern.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload är satt till \"%s\" istället för det förväntade värdet \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "För att åtgärda detta problem sätt värdet  <code> mbstring.func_overload till </ code> <code> 0 </ code> i din php.ini",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 krävs",
-    "Please upgrade your database version" : "Uppgradera din databasversion",
-    "Your data directory is readable by other users" : "Din datamapp är läsbar av andra användare",
-    "Your data directory must be an absolute path" : "Du måste specificera en korrekt sökväg till datamappen",
-    "Check the value of \"datadirectory\" in your configuration" : "Kontrollera värdet av \"datakatalog\" i din konfiguration",
-    "Your data directory is invalid" : "Din datamapp är ogiltig"
+    "Generate headline" : "Skapa rubrik",
+    "Generates a possible headline for a text." : "Genererar en möjlig rubrik för en text.",
+    "Summarize" : "Sammanfatta",
+    "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
+    "Extract topics" : "Extrahera ämnen",
+    "Extracts topics from a text and outputs them separated by commas." : "Extraherar ämnen från en text och matar ut dem separerade med kommatecken.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Inloggad användare måste vara en admin, sub-admin eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
+    "Logged in user must be an admin or sub admin" : "Inloggad användare måste vara administratör eller del-administratör",
+    "Logged in user must be an admin" : "Inloggad användare måste vara administratör",
+    "Help" : "Hjälp",
+    "Unknown user" : "Okänd användare",
+    "Enter the database username and name for %s" : "Ange databasanvändarnamn och lösenord för %s",
+    "Enter the database username for %s" : "Ange databasanvändare för %s",
+    "MySQL username and/or password not valid" : "MySQL-användarnamn och/eller lösenord är felaktigt",
+    "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
+    "Set an admin username." : "Ange ett användarnamn för administratören.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Delning av %s misslyckades eftersom detta redan är delat med användaren %s",
+    "The username is already being used" : "Användarnamnet används redan",
+    "Could not create user" : "Kunde inte skapa användare",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Endast följande tecken är tillåtna i ett användarnamn: \"a-z\", \"A-Z\", \"0-9\", mellanslag och \"_.@-'\"",
+    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
+    "Username contains whitespace at the beginning or at the end" : "Användarnamnet består av ett mellanslag i början eller i slutet",
+    "Username must not consist of dots only" : "Användarnamnet får inte innehålla enbart punkter",
+    "Username is invalid because files already exist for this user" : "Användarnamnet är ogiltigt eftersom det redan finns filer för den här användaren",
+    "User disabled" : "Användare inaktiverad",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 krävs.",
+    "Please upgrade your database version." : "Uppgradera din databasversion.",
+    "Your data directory is readable by other users." : "Din datakatalog kan läsas av andra användare.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare."
 },
 "nplurals=2; plural=(n != 1);");
