@@ -93,7 +93,6 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" uygulaması sunucu sürümüyle uyumlu olmadığından kurulamaz.",
     "__language_name__" : "Türkçe",
     "This is an automatically sent email, please do not reply." : "Bu ileti otomatik olarak gönderildiğinden lütfen yanıtlamayın.",
-    "Help" : "Yardım",
     "Appearance and accessibility" : "Görünüm ve erişilebilirlik",
     "Apps" : "Uygulamalar",
     "Personal settings" : "Kişisel ayarlar",
@@ -270,12 +269,11 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Temel içeriği kaybetmeden uzunluğunu kısaltarak metni özetler.",
     "Extract topics" : "Başlıklar ayıklansın",
     "Extracts topics from a text and outputs them separated by commas." : "Bir metindeki konuları ayıklar ve bunları virgül ile ayırarak sıralar.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "%1$s uygulamasının dosyaları doğru şekilde değiştirilmedi. Sunucu ile uyumlu dosyaların yüklü olduğundan emin olun.",
     "404" : "404",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış kullanıcı bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
     "Logged in user must be an admin or sub admin" : "Oturum açmış kullanıcı bir yönetici ya da alt yönetici olmalıdır",
     "Logged in user must be an admin" : "Oturum açmış kullanıcı bir yönetici olmalıdır",
-    "Full name" : "Tam ad",
+    "Help" : "Yardım",
     "Unknown user" : "Kullanıcı bilinmiyor",
     "Enter the database username and name for %s" : "%s için veri tabanı adını ve kullanıcı adını yazın",
     "Enter the database username for %s" : "%s için veri tabanı kullanıcı adını yazın",
@@ -292,8 +290,6 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
     "Username is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
     "User disabled" : "Kullanıcı devre dışı",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 sürümü en az 2.7.0 olmalıdır. Şu anda %s kurulu.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Bu sorunu çözmek için libxml2 sürümünüzü güncelleyin ve site sunucusunu yeniden başlatın.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 gerekli.",
     "Please upgrade your database version." : "Lütfen veri tabanı sürümünüzü yükseltin.",
     "Your data directory is readable by other users." : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir.",
